@@ -2,8 +2,7 @@
 
 set -x -e
 
-uid=$1
-gid=$2
+UID_GID=$1
 
 export MAKEFLAGS="-j8"
 cd /io && ./utils/lint.sh
@@ -11,12 +10,13 @@ cd /tmp
 
 cmake \
   -DCMAKE_UNITY_BUILD=ON -DCMAKE_UNITY_BUILD_BATCH_SIZE=32 \
-  -DCMAKE_CXX_FLAGS="-Wall -Wextra -Wpedantic -Wshadow -Werror -DPERSALYS_APPIMAGE" \
-  -DCMAKE_SWIG_FLAGS="-Werror" -DSWIG_COMPILE_FLAGS="-Wno-unused-parameter -Wno-shadow" \
+  -DCMAKE_CXX_FLAGS="-g -Wall -Wextra -Wpedantic -Wshadow -Wsuggest-override -Werror" \
+  -DCMAKE_SWIG_FLAGS="-Werror" -DSWIG_COMPILE_FLAGS="-Wno-unused-parameter -Wno-shadow -Wno-suggest-override" \
   -DPython_EXECUTABLE=/usr/local/bin/python3 \
   -DUSE_SPHINX=ON -DSPHINX_FLAGS="-W -T -j8" \
+  -DUSE_STACKTRACE=ON \
   -DCMAKE_INSTALL_PREFIX=/tmp/persalys.AppDir/usr -DCMAKE_INSTALL_LIBDIR=lib \
-  -DOPENGL_opengl_LIBRARY=/usr/lib64/libGL.so \
+  -DPERSALYS_BUILD_APPIMAGE=ON \
   -B build /io
 cd build
 make install
@@ -65,20 +65,21 @@ EOF
 cp -v /io/images/Ps-icon-32.png persalys.AppDir/persalys.png
 
 # system libs
-for libname in lapack blas quadmath xml2 gfortran ffi lzma harfbuzz mpfr mpc crypt freetype fontconfig
+for libname in lapack blas cblas quadmath xml2 gfortran ffi lzma harfbuzz mpfr mpc crypt freetype fontconfig
 do
   cp -v /usr/lib64/lib${libname}.so.[0-9] persalys.AppDir/usr/lib
 done
-cp -v /usr/lib64/libssl.so.10 /usr/lib64/libcrypto.so.10 persalys.AppDir/usr/lib
+cp -v /usr/lib64/libssl.so.1.1 /usr/lib64/libcrypto.so.1.1 persalys.AppDir/usr/lib
 cp -v /usr/lib64/libgmp.so.10 persalys.AppDir/usr/lib
-cp -v /usr/lib64/libtcl8.5.so /usr/lib64/libtk8.5.so persalys.AppDir/usr/lib
+cp -v /usr/lib64/libtcl8.6.so /usr/lib64/libtk8.6.so persalys.AppDir/usr/lib
 cp -v /usr/lib64/atlas/lib*.so.3 persalys.AppDir/usr/lib
-cp -v /usr/lib64/libpng15.so.15 persalys.AppDir/usr/lib
+cp -v /usr/lib64/libpng16.so.16 persalys.AppDir/usr/lib
 cp -v /usr/lib64/libjpeg.so.62 persalys.AppDir/usr/lib
-cp -v /usr/lib64/libicu*.so.50 persalys.AppDir/usr/lib
+cp -v /usr/lib64/libicu*.so.60 persalys.AppDir/usr/lib
 cp -v /usr/lib64/libxcb-*.so.[0-9] persalys.AppDir/usr/lib && rm persalys.AppDir/usr/lib/libxcb-dri3.so.0
 cp -v /usr/lib64/libfreebl3.so persalys.AppDir/usr/lib
 cp -v /lib64/libpcre2-16.so.0 persalys.AppDir/usr/lib
+cp -v /usr/local/lib/libbacktrace.so.0 persalys.AppDir/usr/lib
 
 # python
 sudo ln -sf /usr/local/bin/python3 /usr/local/bin/python
@@ -113,32 +114,32 @@ cp -v /usr/local/lib/libqwt.so.6.* persalys.AppDir/usr/lib
 cp -rv /usr/local/lib/qt/plugins persalys.AppDir/usr/lib
 
 # paraview libs
-cp -v /usr/local/lib/libvtk* persalys.AppDir/usr/lib
-cp -v /usr/local/lib/libpq* persalys.AppDir/usr/lib
+cp -v /usr/local/lib64/libvtk* persalys.AppDir/usr/lib
+cp -v /usr/local/lib64/libpq* persalys.AppDir/usr/lib
 mkdir -p persalys.AppDir/usr/lib/paraview/plugins
-cp -rv /usr/local/lib/paraview*/plugins/BagPlotViewsAndFilters persalys.AppDir/usr/lib/paraview/plugins
+cp -rv /usr/local/lib64/paraview*/plugins/BagPlotViewsAndFilters persalys.AppDir/usr/lib/paraview/plugins
 
 # modelica
 cp -rv /usr/local/lib64/omc persalys.AppDir/usr/lib
 cp -rv /usr/local/include/omc persalys.AppDir/usr/include
 cp -rv /usr/local/share/omc persalys.AppDir/usr/share
-cp -v /usr/lib64/liblpsolve55.so /lib64/libuuid.so.1 /lib64/libexpat.so.1 persalys.AppDir/usr/lib
 cp -v /usr/local/bin/omc persalys.AppDir/usr/bin
 cp -v /usr/local/lib/libsundials* persalys.AppDir/usr/lib
 cp -v /usr/local/lib/libfmilib* persalys.AppDir/usr/lib
 
 # gdb
 cp -v /usr/local/bin/gdb* persalys.AppDir/usr/bin
-cp -v /usr/lib64/libtinfo.so.5 /usr/lib64/libncursesw.so.5 /usr/lib64/libpanelw.so.5 persalys.AppDir/usr/lib
+cp -v /usr/lib64/libtinfo.so.6 /usr/lib64/libncursesw.so.6 /usr/lib64/libpanelw.so.6 persalys.AppDir/usr/lib
 
 LD_LIBRARY_PATH=$PWD/persalys.AppDir/usr/lib ldd persalys.AppDir/usr/lib/plugins/platforms/libqxcb.so
 LD_LIBRARY_PATH=$PWD/persalys.AppDir/usr/lib ldd persalys.AppDir/usr/bin/persalys
 
-appimagetool -v persalys.AppDir persalys-`cat /io/VERSION`-`uname -p`.AppImage
+APPIMAGE_FILE=persalys-`cat /io/VERSION`-`uname -p`.AppImage
+appimagetool -v persalys.AppDir ${APPIMAGE_FILE}
 
 # copy to host with same permission
-if test -n "${uid}" -a -n "${gid}"
+if test -n "${UID_GID}"
 then
-  sudo cp persalys*.AppImage persalys-doc.zip /io
-  sudo chown ${uid}:${gid} /io/persalys*.AppImage /io/persalys-doc.zip
+  sudo cp ${APPIMAGE_FILE} persalys-doc.zip /io
+  sudo chown ${UID_GID} /io/${APPIMAGE_FILE} /io/persalys-doc.zip
 fi
