@@ -32,16 +32,6 @@ namespace PERSALYS
 AnalysisImplementation::AnalysisImplementation()
   : PersistentObject()
   , Observable()
-  , isReliabilityAnalysis_(false)
-  , isDeterministicAnalysis_(true)
-  , informationMessage_("")
-  , warningMessage_("")
-  , stopRequested_(false)
-  , progressValue_(0)
-  , modelHtmlDescription_("")
-  , isRunning_(false)
-  , errorMessage_("")
-  , interestVariables_()
 {
 }
 
@@ -50,16 +40,6 @@ AnalysisImplementation::AnalysisImplementation()
 AnalysisImplementation::AnalysisImplementation(const String & name)
   : PersistentObject()
   , Observable()
-  , isReliabilityAnalysis_(false)
-  , isDeterministicAnalysis_(true)
-  , informationMessage_("")
-  , warningMessage_("")
-  , stopRequested_(false)
-  , progressValue_(0)
-  , modelHtmlDescription_("")
-  , isRunning_(false)
-  , errorMessage_("")
-  , interestVariables_()
 {
   setName(name);
 }
@@ -143,8 +123,10 @@ void AnalysisImplementation::initialize()
   errorMessage_ = "";
   warningMessage_ = "";
   stopRequested_ = false;
+  detachRequested_ = false;
   progressValue_ = 0;
   modelHtmlDescription_ = "";
+  elapsedTime_ = 0.0;
 
   // if the model is a PythonPhysicalModel: reset the calls number
   // do not need this operation for the other models because
@@ -168,6 +150,7 @@ Scalar AnalysisImplementation::getElapsedTime() const
 {
   return elapsedTime_;
 }
+
 void AnalysisImplementation::run()
 {
   TimeCriteria tc;
@@ -184,7 +167,7 @@ void AnalysisImplementation::run()
     elapsedTime_ = tc.getElapsedTime();
     notify("analysisFinished");
   }
-  catch (std::exception & ex)
+  catch (const std::exception & ex)
   {
     errorMessage_ +=  ex.what();
     isRunning_ = false;
@@ -232,13 +215,19 @@ bool AnalysisImplementation::canBeLaunched(String & /*errorMessage*/) const
 }
 
 
+bool AnalysisImplementation::canBeDetached() const
+{
+  return false;
+}
+
+
 String AnalysisImplementation::getPythonScript() const
 {
   return "";
 }
 
 
-String AnalysisImplementation::getHtmlDescription() const
+String AnalysisImplementation::getHTMLDescription() const
 {
   return modelHtmlDescription_;
 }
@@ -257,6 +246,19 @@ bool AnalysisImplementation::Stop(void * p)
 }
 
 
+void AnalysisImplementation::detach()
+{
+  detachRequested_ = true;
+}
+
+
+bool AnalysisImplementation::Detach(void * p)
+{
+  AnalysisImplementation * arg = (AnalysisImplementation*)p;
+  return arg->detachRequested_;
+}
+
+
 void AnalysisImplementation::UpdateProgressValue(double percent, void * data)
 {
   AnalysisImplementation * analysis = static_cast<AnalysisImplementation*>(data);
@@ -264,7 +266,7 @@ void AnalysisImplementation::UpdateProgressValue(double percent, void * data)
     return;
 
   // set progress value
-  analysis->progressValue_ = (int) percent;
+  analysis->progressValue_ = static_cast<int>(percent);
   analysis->notify("progressValueChanged");
 }
 
@@ -276,7 +278,6 @@ void AnalysisImplementation::save(Advocate & adv) const
   adv.saveAttribute("errorMessage_", errorMessage_);
   adv.saveAttribute("warningMessage_", warningMessage_);
   adv.saveAttribute("isReliabilityAnalysis_", isReliabilityAnalysis_);
-  adv.saveAttribute("isDeterministicAnalysis_", isDeterministicAnalysis_);
   adv.saveAttribute("interestVariables_", interestVariables_);
   adv.saveAttribute("modelHtmlDescription_", modelHtmlDescription_);
 }
@@ -289,14 +290,9 @@ void AnalysisImplementation::load(Advocate & adv)
   adv.loadAttribute("errorMessage_", errorMessage_);
   adv.loadAttribute("warningMessage_", warningMessage_);
   adv.loadAttribute("isReliabilityAnalysis_", isReliabilityAnalysis_);
-  adv.loadAttribute("isDeterministicAnalysis_", isDeterministicAnalysis_);
   adv.loadAttribute("interestVariables_", interestVariables_);
   adv.loadAttribute("modelHtmlDescription_", modelHtmlDescription_);
 }
 
 
-/* To be implemented in child classes. */
-void AnalysisImplementation::acceptLaunchParameters(LaunchParametersVisitor* /*visitor*/)
-{
-}
 }
