@@ -2,7 +2,7 @@
 /**
  *  @brief Class to define designs of experiments
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -245,8 +245,6 @@ void CalibrationAnalysis::launch()
       LOGWARN("Cannot build posterior residual PDF");
     }
   }
-  if (methodName_.find("Gaussian") != std::string::npos)
-    result_.isBayesian_ = true;
 }
 
 
