@@ -38,7 +38,6 @@ static Factory<PersistentCollection<CouplingStep> > Factory_PersistentCollection
 CouplingPhysicalModel::CouplingPhysicalModel(const OT::String & name,
     const CouplingStepCollection & steps)
   : PythonPhysicalModel(name)
-  , cleanupWorkDirectory_(true)
 {
   setSteps(steps);
 }
@@ -49,7 +48,6 @@ CouplingPhysicalModel::CouplingPhysicalModel(const OT::String & name,
     const OutputCollection & outputs,
     const CouplingStepCollection & steps)
   : PythonPhysicalModel(name)
-  , cleanupWorkDirectory_(true)
 {
   PhysicalModelImplementation::setInputs(inputs);
   PhysicalModelImplementation::setOutputs(outputs);
@@ -68,6 +66,17 @@ CouplingStepCollection CouplingPhysicalModel::getSteps() const
   return steps_;
 }
 
+void CouplingPhysicalModel::setSSHHostname(const String & hostname)
+{
+  SSHHostname_ = hostname;
+  updateCode();
+}
+
+String CouplingPhysicalModel::getSSHHostname() const
+{
+  return SSHHostname_;
+}
+
 String CouplingPhysicalModel::getStepsMacro(const String & offset) const
 {
   OSS oss;
@@ -86,7 +95,7 @@ String CouplingPhysicalModel::getStepsMacro(const String & offset) const
           << inputFile.getPath() << "')\n";
       oss << offset << "input_file" << j << ".setConfiguredPath(r'"
           << inputFile.getConfiguredPath() << "')\n";
-      if (inputFile.getVariableNames().getSize() > 0)
+      if (!inputFile.getVariableNames().isEmpty())
         oss << offset << "input_file" << j << ".setVariables("
             << Parameters::GetOTDescriptionStr(inputFile.getVariableNames()) << ", "
             << Parameters::GetOTDescriptionStr(inputFile.getTokens()) << ", "
@@ -113,7 +122,7 @@ String CouplingPhysicalModel::getStepsMacro(const String & offset) const
         continue;
       oss << offset << "output_file" << j << " = persalys.CouplingOutputFile(r'"
           << outputFile.getPath() << "')\n";
-      if (outputFile.getVariableNames().getSize() > 0)
+      if (!outputFile.getVariableNames().isEmpty())
         oss << offset << "output_file" << j
             << ".setVariables("
             << Parameters::GetOTDescriptionStr(outputFile.getVariableNames())
@@ -144,10 +153,8 @@ void CouplingPhysicalModel::setSteps(const CouplingStepCollection & steps)
   updateCode();
 }
 
-void CouplingPhysicalModel::updateCode()
+Description CouplingPhysicalModel::getStepsOutputNames(const CouplingStepCollection &steps) const
 {
-  CouplingStepCollection steps = getSteps();
-  Description inputNames;
   Description outputNames;
 
   // retrieve output variables
@@ -173,6 +180,13 @@ void CouplingPhysicalModel::updateCode()
           outputNames.add(step.getPPOutputs()[j]);
   }
 
+  return outputNames;
+}
+
+Description CouplingPhysicalModel::getStepsInputNames(const CouplingStepCollection &steps, const Description &outputNames) const
+{
+  Description inputNames;
+
   // retrieve input variables
   for (UnsignedInteger i = 0; i < steps.getSize(); ++ i)
   {
@@ -196,99 +210,252 @@ void CouplingPhysicalModel::updateCode()
             !outputNames.contains(step.getPPInputs()[j]))
           inputNames.add(step.getPPInputs()[j]);
   }
-  OSS code;
-  code << "import tempfile\n";
-  code << "import openturns.coupling_tools as otct\n";
-  code << "import persalys\n";
-  code << "import shutil\n";
-  code << "import os\n";
-  code << "import re\n";
-  code << "import hashlib\n";
-  code << "import struct\n\n";
-  code << "def _exec(";
-  for (UnsignedInteger i = 0; i < inputNames.getSize(); ++ i)
-  {
-    code << inputNames[i];
-    if (i < inputNames.getSize() - 1)
-      code << ", ";
-  }
-  code << "):\n";
 
-  code << getStepsMacro("    ");
-  code << "    all_vars = dict(zip(" << Parameters::GetOTDescriptionStr(inputNames) << ", [";
-  for (UnsignedInteger i = 0; i < inputNames.getSize(); ++ i)
-  {
-    code << inputNames[i];
-    if (i < inputNames.getSize() - 1)
-      code << ", ";
-  }
-  code << "]))\n";
+  return inputNames;
+}
 
-  code << "    checksum = hashlib.sha1()\n";
-  code << "    [checksum.update(hex(struct.unpack('<Q', struct.pack('<d', x))[0]).encode()) for x in all_vars.values()]\n";
-  code << "    global workdir\n";
-  if(!workDir_.empty())
-    code << "    workdir = os.path.join(r'" << workDir_ << "', 'persalys_' + checksum.hexdigest())\n";
+String CouplingPhysicalModel::pythonImports() const
+{
+  String code = R"(from tempfile import gettempdir
+import openturns.coupling_tools as otct
+import persalys
+import shutil
+import os
+import re
+import hashlib
+import struct
+from pathlib import Path, PurePosixPath
+)";
+
+  if (!SSHHostname_.empty())
+    code += "import paramiko\n";
+  
+  return code;
+}
+
+String CouplingPhysicalModel::pythonFunctions() const
+{
+  OSS stepsFunc;
+  stepsFunc << "def build_steps_list():\n";
+  stepsFunc << getStepsMacro("    ");
+  stepsFunc << "    \n";
+  stepsFunc << "    return steps\n";
+
+  OSS localDirFunc;
+  localDirFunc << "def create_local_dir(checksum):\n";
+  localDirFunc << "    global workdir\n"; // required by AnsysParser
+  if (SSHHostname_.empty() && !workDir_.empty())
+  {
+  localDirFunc << "    workdir = Path(r'" << workDir_ << "') / ('persalys_' + checksum.hexdigest())\n";
+  }
   else
-    code << "    workdir = os.path.join(tempfile.gettempdir(), 'persalys_' + checksum.hexdigest())\n";
-  code << "    if not os.path.exists(workdir):\n";
-  code << "        os.makedirs(workdir)\n";
+  {
+  localDirFunc << "    workdir = Path(gettempdir()) / ('persalys_' + checksum.hexdigest())\n";
+  }
+  localDirFunc << "    if not workdir.exists():\n";
+  localDirFunc << "        workdir.mkdir(parents=True, exist_ok=True)\n";
+
+  OSS remoteMkdirFunc;
+  remoteMkdirFunc << "def remote_mkdir_p(path: PurePosixPath, ssh):\n";
+  remoteMkdirFunc << 
+  R"(    # use Unix mkdir -p on the remote host, ensure proper quoting
+    path_str = str(path)
+    safe = path_str.replace("'", "'\\''")
+    cmd = "mkdir -p '" + safe + "'"
+    stdin, stdout, stderr = ssh.exec_command(cmd)
+    ret = stdout.channel.recv_exit_status()
+    if ret != 0:
+        raise RuntimeError(f"Remote mkdir failed for {path_str} with code {ret}: {stderr.read().decode()}")
+)";
+  
+  OSS code;
+  code << stepsFunc.str();
+  code << "\n";
+  code << localDirFunc.str();
+  if(!SSHHostname_.empty())
+  {
+    code << "\n";
+    code << remoteMkdirFunc.str();
+  }
+  
+  return code;
+}
+
+String CouplingPhysicalModel::writeCode(const Description &inputNames, const Description &outputNames) const
+{
+  const String inputNamesStr(Parameters::GetOTDescriptionStr(inputNames, false, false));
+
+  OSS code;
+  code << pythonImports();
+  code << "\n";
+  code << pythonFunctions();
+  code << "\n";
+  code << "def _exec(" << inputNamesStr << "):\n";
+  code<<R"(    FUNC_PATTERN = re.compile(r'def\s+(\w+)\(.*?\):'))" << "\n";
+  code<<R"(    ARGS_PATTERN = re.compile(r'def\s+\w+\(([\w, ]*)\):'))" << "\n";
+  code<<R"(    RETURN_PATTERN = re.compile(r'return\s+([\w, ]+)'))" << "\n";
+  code << "    \n";
+  code << "    steps = build_steps_list()\n";
+  code << "    all_vars = dict(zip(" << Parameters::GetOTDescriptionStr(inputNames) << ", [" << inputNamesStr << "]))\n";
+  code << "    def _require_var(var_name):\n";
+  code << "        if var_name not in all_vars:\n";
+  code << "            raise KeyError(f\"Variable '{var_name}' is undefined\")\n";
+  code << "        return all_vars[var_name]\n";
+  code << "    \n";
+  code << "    checksum = hashlib.sha1()\n";
+  code << "    for value in all_vars.values():\n";
+  code << "        checksum.update(hex(struct.unpack('<Q', struct.pack('<d', value))[0]).encode())\n";
+  code << "    create_local_dir(checksum)\n";
+  code << "    \n";
+  if (!SSHHostname_.empty())
+  {
+  code << "    hostname = r'" << SSHHostname_ << "'\n";
+    if (!workDir_.empty())
+    {
+  code << "    remote_base = PurePosixPath(r'" << workDir_ << "')\n";
+    }
+    else
+    {
+  code << "    remote_base = PurePosixPath('/tmp')\n";
+    }
+  code << "    remote_workdir = remote_base / ('persalys_' + checksum.hexdigest())\n";
+  code << "    \n";
+  code << "    ssh = paramiko.SSHClient()\n";
+  code << "    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())\n";
+  code << "    ssh.connect(hostname)\n";
+  code << "    sftp = ssh.open_sftp()\n";
+  code << "    remote_mkdir_p(remote_workdir, ssh)\n";
+  }
   code << "    for step in steps:\n";
   code << "        for input_file in step.getInputFiles():\n";
   code << "            if not input_file.getPath():\n";
   code << "                continue\n";
-  code << "            input_values = [all_vars[varname] for varname in input_file.getVariableNames()]\n";
+  code << "            input_values = [_require_var(varname) for varname in input_file.getVariableNames()]\n";
   code << "            formats = input_file.getFormats()\n";
   code << "            if formats.isBlank():\n";
   code << "                formats = None\n";
-  code << "            otct.replace(input_file.getPath(), os.path.join(workdir, input_file.getConfiguredPath()), input_file.getTokens(), input_values, formats=formats, encoding=step.getEncoding())\n";
+  code << "            target = workdir / input_file.getConfiguredPath()\n";
+  code << "            target.parent.mkdir(parents=True, exist_ok=True)\n";
+  code << "            otct.replace(input_file.getPath(), str(target), input_file.getTokens(), input_values, formats=formats, encoding=step.getEncoding())\n";
+  code << "\n";
+  if(!SSHHostname_.empty())
+  {
+  code << "            remote_target = remote_workdir / input_file.getConfiguredPath()\n";
+  code << "            remote_mkdir_p(remote_target.parent, ssh)\n";
+  code << "            sftp.put(str(target), str(remote_target))\n";
+  code << "\n";
+  }
   code << "        for resource_file in step.getResourceFiles():\n";
   code << "            if not resource_file.getPath():\n";
   code << "                continue\n";
-  code << "            if os.path.isfile(resource_file.getPath()):\n";
-  code << "                shutil.copy(resource_file.getPath(), os.path.join(workdir, os.path.basename(resource_file.getPath())))\n";
-  code << "            elif os.path.isdir(resource_file.getPath()):\n";
-  code << "                dest = os.path.join(workdir, os.path.basename(resource_file.getPath()))\n";
-  code << "                if os.path.exists(dest):\n";
-  code << "                    shutil.rmtree(dest)\n";
-  code << "                shutil.copytree(resource_file.getPath(), dest)\n";
+  code << "            src_path = Path(resource_file.getPath())\n";
+  code << "            \n";
+  code << "            if src_path.is_file():\n";
+  if(SSHHostname_.empty())
+  {
+  code << "                shutil.copy2(src_path, workdir / src_path.name)\n";
+  code << "            elif src_path.is_dir():\n";
+  code << "                shutil.copytree(src_path, workdir / src_path.name, dirs_exist_ok=True)\n";
+  }
+  else
+  {
+  code << "                local_res = workdir / src_path.name\n";
+  code << "                shutil.copy2(src_path, local_res)\n";
+  code << "                remote_res = remote_workdir / src_path.name\n";
+  code << "                remote_mkdir_p(remote_res.parent, ssh)\n";
+  code << "                sftp.put(str(local_res), str(remote_res))\n";
+  code << "            elif src_path.is_dir():\n";
+  code << "                dst_dir = workdir / src_path.name\n";
+  code << "                shutil.copytree(src_path, dst_dir, dirs_exist_ok=True)\n";
+  code << "                for root, dirs, files in os.walk(dst_dir):\n";
+  code << "                    rel_root = Path(root).relative_to(workdir)\n";
+  code<<R"(                    remote_root = remote_workdir / PurePosixPath(str(rel_root).replace('\\', '/')))" << "\n";
+  code << "                    remote_mkdir_p(remote_root, ssh)\n";
+  code << "                    for f in files:\n";
+  code << "                        local_f = Path(root) / f\n";
+  code << "                        remote_f = remote_root / f\n";
+  code << "                        sftp.put(str(local_f), str(remote_f))\n";
+  }
   code << "            else:\n";
-  code << "                raise ValueError('cannot handle file:', resource_file.getPath())\n";
+  code << "                raise FileNotFoundError(resource_file.getPath())\n";
+  code << "        \n";
   code << "        if len(step.getCommand()) > 0:\n";
   code << "            timeout = step.getTimeOut()\n";
   code << "            if timeout <= 0:\n";
   code << "                timeout = None\n";
+  code << "        \n";
+  if(SSHHostname_.empty())
+  {
   code << "            if len(step.getEnvironmentKeys()) == 0:\n";
-  code << "                otct.execute(step.getCommand(), cwd=workdir, shell=step.getIsShell(), capture_output=True, timeout=timeout)\n";
+  code << "                otct.execute(step.getCommand(), cwd=str(workdir), shell=step.getIsShell(), capture_output=True, timeout=timeout)\n";
   code << "            else:\n";
   code << "                env = os.environ.copy()\n";
   code << "                for key, val in zip(step.getEnvironmentKeys(), step.getEnvironmentValues()):\n";
   code << "                    env[key] = val\n";
-  code << "                otct.execute(step.getCommand(), cwd=workdir, shell=step.getIsShell(), capture_output=True, timeout=timeout, env=env)\n";
+  code << "                otct.execute(step.getCommand(), cwd=str(workdir), shell=step.getIsShell(), capture_output=True, timeout=timeout, env=env)\n";
+  }
+  else
+  {
+  code << "            cmd = step.getCommand()\n";
+  code << "            # emulate cwd and optional shell using bash -lc\n";
+  code << "            remote_cmd = f\"cd {remote_workdir} && {cmd}\"\n";
+  code << "            env = {}\n";
+  code << "            if len(step.getEnvironmentKeys()) > 0:\n";
+  code << "                for key, val in zip(step.getEnvironmentKeys(), step.getEnvironmentValues()):\n";
+  code << "                    env[key] = val\n";
+  code << "            # paramiko exec_command supports an environment dict on Unix servers\n";
+  code << "            stdin, stdout, stderr = ssh.exec_command(\n";
+  code << "                f\"sh -c '{remote_cmd}'\",\n";
+  code << "                timeout=timeout,\n";
+  code << "                environment=env,\n";
+  code << "            )\n";
+  code << "            ret = stdout.channel.recv_exit_status()\n";
+  code << "            if ret != 0:\n";
+  code << "                raise RuntimeError(f\"Remote command failed with code {ret}: {stderr.read().decode()}\\n{stdout.read().decode()}\")\n";
+  }
+  code << "        \n";
   code << "        for output_file in step.getOutputFiles():\n";
   code << "            if not output_file.getPath():\n";
   code << "                continue\n";
-  code << "            outfile = os.path.join(workdir, output_file.getPath())\n";
+  code << "            \n";
+  if(SSHHostname_.empty())
+  {
+  code << "            outfile = workdir / output_file.getPath()\n";
+  code << "            outfile_str = str(outfile)\n";
   code << "            for varname, token, skip_tok, skip_line, skip_col in zip(output_file.getVariableNames(), output_file.getTokens(), output_file.getSkipTokens(), output_file.getSkipLines(), output_file.getSkipColumns()):\n";
   code << "                token_esc = re.escape(token)\n";
-  code << "                all_vars[varname] = otct.get_value(outfile, token=token_esc, skip_token=int(skip_tok), skip_line=int(skip_line), skip_col=int(skip_col), encoding=step.getEncoding())\n";
+  code << "                all_vars[varname] = otct.get_value(outfile_str, token=token_esc, skip_token=int(skip_tok), skip_line=int(skip_line), skip_col=int(skip_col), encoding=step.getEncoding())\n";
+  }
+  else
+  {
+  code << "            remote_out = remote_workdir / output_file.getPath()\n";
+  code << "            local_out = workdir / output_file.getPath()\n";
+  code << "            local_out.parent.mkdir(parents=True, exist_ok=True)\n";
+  code << "            remote_mkdir_p(remote_out.parent, ssh)\n";
+  code << "            try:\n";
+  code << "                sftp.get(str(remote_out), str(local_out))\n";
+  code << "            except IOError:\n";
+  code << "                raise FileNotFoundError(str(remote_out))\n";
+  code << "            outfile_str = str(local_out)\n";
+  code << "            for varname, token, skip_tok, skip_line, skip_col in zip(output_file.getVariableNames(), output_file.getTokens(), output_file.getSkipTokens(), output_file.getSkipLines(), output_file.getSkipColumns()):\n";
+  code << "                token_esc = re.escape(token)\n";
+  code << "                all_vars[varname] = otct.get_value(outfile_str, token=token_esc, skip_token=int(skip_tok), skip_line=int(skip_line), skip_col=int(skip_col), encoding=step.getEncoding())\n";
+  }
+  code << "        \n";
   code << "        if step.getCode():\n";
   code << "            script = step.getCode()\n";
-
-  code << "            regexsearch = re.search(r'def (\\w*)\\(.*\\):', script)\n";
-  code << "            if regexsearch is not None:\n";
-  code << "                script_funcname = regexsearch.group(1)\n";
-  code << "            else:\n";
+  code << "            func_match = FUNC_PATTERN.search(script)\n";
+  code << "            if func_match is None:\n";
   code << "                raise RuntimeError('Could not find extra processing function name')\n";
-
-  code << "            regexsearch = re.search(r'def \\w+\\(([\\w, ]+)\\):', script)\n";
-  code << "            if regexsearch is not None:\n";
-  code << "                script_invars = regexsearch.group(1).replace(' ', '').split(',')\n";
+  code << "            script_funcname = func_match.group(1)\n";
+  code << "            args_match = ARGS_PATTERN.search(script)\n";
+  code << "            if args_match is not None and args_match.group(1):\n";
+  code << "                script_invars = [name for name in args_match.group(1).replace(' ', '').split(',') if name]\n";
   code << "            else:\n";
   code << "                script_invars = []\n";
-  code << "            regexsearch = re.search(r'return ([\\w, ]+)', script)\n";
-  code << "            if regexsearch is not None:\n";
-  code << "                script_outvars = regexsearch.group(1).replace(' ', '').split(',')\n";
+  code << "            return_match = RETURN_PATTERN.search(script)\n";
+  code << "            if return_match is not None and return_match.group(1):\n";
+  code << "                script_outvars = [name for name in return_match.group(1).replace(' ', '').split(',') if name]\n";
   code << "            else:\n";
   code << "                script_outvars = []\n";
   code << "            exec_script = script+'\\nscript_output__ = '+script_funcname+'('+ ', '.join([str(all_vars[var]) for var in script_invars]) + ')\\n'\n";
@@ -299,23 +466,44 @@ void CouplingPhysicalModel::updateCode()
   code << "                script_output__ = [script_output__]\n";
   code << "            for var, value in zip(script_outvars, script_output__):\n";
   code << "                all_vars[var] = value\n";
-
-  if (cleanupWorkDirectory_)
-    code << "    shutil.rmtree(workdir)\n";
-
+  code << "    \n";
+  if (!SSHHostname_.empty())
+  {
+  code << "    sftp.close()\n";
+    if (cleanupWorkDirectory_)
+    {
+  code << "    try:\n";
+  code<<R"(        safe_remote = str(remote_workdir).replace("'", "'\\''"))" << "\n";
+  code << "        stdin, stdout, stderr = ssh.exec_command(f\"rm -rf '{safe_remote}'\")\n";
+  code << "        stdout.channel.recv_exit_status()\n";
+  code << "    except Exception:\n";
+  code << "        pass\n";
+    }
+  code << "    ssh.close()\n";
+  }
+  if(!SSHHostname_.empty() || cleanupWorkDirectory_)
+  {
+  code << "    shutil.rmtree(workdir)\n";
+  }
   for (UnsignedInteger i = 0; i < outputNames.getSize(); ++ i)
   {
-    code << "    " << outputNames[i] << " = all_vars['" << outputNames[i] << "']\n";
+  code << "    " << outputNames[i] << " = all_vars['" << outputNames[i] << "']\n";
   }
-  code << "    return ";
-  for (UnsignedInteger i = 0; i < outputNames.getSize(); ++ i)
-  {
-    code << outputNames[i];
-    if (i < outputNames.getSize() - 1)
-      code << ", ";
-  }
-  code << "\n";
-  setCode(code);
+  code << "    \n";
+  code << "    return " << Parameters::GetOTDescriptionStr(outputNames, false, false) << "\n";
+
+  return code;
+}
+
+void CouplingPhysicalModel::updateCode()
+{
+  const CouplingStepCollection steps = getSteps();
+  const Description outputNames{getStepsOutputNames(steps)};
+  const Description inputNames{getStepsInputNames(steps, outputNames)};
+
+  const String code = writeCode(inputNames, outputNames);
+
+  PythonPhysicalModel::setCode(code);
 
   notify("stepsChanged");
 }
@@ -326,12 +514,12 @@ Function CouplingPhysicalModel::generateFunction(const Description & outputNames
 }
 
 
-String CouplingPhysicalModel::getHtmlDescription(const bool deterministic) const
+String CouplingPhysicalModel::getHTMLDescription() const
 {
   OSS oss;
-  oss << PhysicalModelImplementation::getHtmlDescription(deterministic);
+  oss << PhysicalModelImplementation::getHTMLDescription();
   oss << "<h3>Outputs</h3><p>";
-  oss << "<table style=\"width:100%\" border=\"1\" cellpadding=\"5\">";
+  oss << R"(<table style="width:100%" border="1" cellpadding="5">)";
   oss << "<tr>";
   oss << "  <th>Name</th>";
   oss << "  <th>Description</th>";
@@ -394,6 +582,7 @@ String CouplingPhysicalModel::getPythonScript() const
   oss << getName() + ".setCleanupWorkDirectory(" << (getCleanupWorkDirectory() ? "True" : "False") << ")\n";
   oss << getName() + ".setCacheFiles(r'" << getCacheInputFile()
       << "', r'" << getCacheOutputFile() << "')\n";
+  oss << getName() + ".setSSHHostname('" << getSSHHostname() << "')\n";
   oss << PhysicalModelImplementation::getCopulaPythonScript();
 
   return oss;
@@ -405,7 +594,8 @@ String CouplingPhysicalModel::__repr__() const
 {
   OSS oss;
   oss << PhysicalModelImplementation::__repr__()
-      << " steps=" << getSteps();
+      << " steps=" << getSteps()
+      << " hostname=" << SSHHostname_;
   return oss;
 }
 
@@ -423,8 +613,8 @@ Bool CouplingPhysicalModel::getCleanupWorkDirectory() const
 
 void CouplingPhysicalModel::setCacheFiles(const OT::FileName & inputFile, const OT::FileName & outputFile)
 {
-  cacheInputFile_ = inputFile;
-  cacheOutputFile_ = outputFile;
+  cacheInputFile_   = inputFile;
+  cacheOutputFile_  = outputFile;
 }
 
 void CouplingPhysicalModel::setWorkDir(const OT::FileName & workDir)
@@ -458,6 +648,7 @@ void CouplingPhysicalModel::save(Advocate & adv) const
   adv.saveAttribute("cacheInputFile_", cacheInputFile_);
   adv.saveAttribute("cacheOutputFile_", cacheOutputFile_);
   adv.saveAttribute("workDir_", workDir_);
+  adv.saveAttribute("SSHHostname_", SSHHostname_);
 }
 
 
@@ -470,6 +661,8 @@ void CouplingPhysicalModel::load(Advocate & adv)
   adv.loadAttribute("cacheInputFile_", cacheInputFile_);
   adv.loadAttribute("cacheOutputFile_", cacheOutputFile_);
   adv.loadAttribute("workDir_", workDir_);
+  if (adv.hasAttribute("SSHHostname_"))
+    adv.loadAttribute("SSHHostname_", SSHHostname_);
 }
 
 
