@@ -23,16 +23,12 @@
 #include "persalys/BaseTools.hxx"
 #include "persalys/DataAnalysis.hxx"
 
-#ifdef PERSALYS_HAVE_YACS
-#include "persalys/YACSEvaluation.hxx"
-#endif
-
 #include <openturns/PersistentObjectFactory.hxx>
-#include <openturns/SpecFunc.hxx>
 #include <openturns/BatchFailedException.hxx>
 #include <openturns/MemoizeEvaluation.hxx>
 #include <openturns/MarginalEvaluation.hxx>
 #include <openturns/SymbolicEvaluation.hxx>
+#include <openturns/OTtestcode.hxx>
 
 using namespace OT;
 namespace PERSALYS
@@ -59,6 +55,12 @@ DesignOfExperimentEvaluation::DesignOfExperimentEvaluation(const String& name, c
 {
 }
 
+DesignOfExperimentEvaluation::DesignOfExperimentEvaluation(const String &name, const PhysicalModel &physicalModel, const DataAnalysisResult &result)
+  : SimulationAnalysis(name, physicalModel)
+  , originalInputSample_(result.getDesignOfExperiment().getInputSample())
+  , result_(result)
+{
+}
 
 /* Virtual constructor */
 DesignOfExperimentEvaluation* DesignOfExperimentEvaluation::clone() const
@@ -111,12 +113,6 @@ void DesignOfExperimentEvaluation::initialize()
 }
 
 
-bool DesignOfExperimentEvaluation::StopRequested(void* state)
-{
-  DesignOfExperimentEvaluation * p_it = reinterpret_cast<DesignOfExperimentEvaluation*>(state);
-  return p_it->stopRequested_;
-}
-
 void DesignOfExperimentEvaluation::launch()
 {
   // check
@@ -155,7 +151,7 @@ void DesignOfExperimentEvaluation::launch()
   Function function(getPhysicalModel().getFunction(getInterestVariables()));
 
   // stopCallback
-  function.setStopCallback(&StopRequested, this);
+  function.setStopCallback(&AnalysisImplementation::Detach, this);
 
   // iterations
   for (UnsignedInteger i = 0; i < nbIter; ++i)
@@ -226,7 +222,7 @@ void DesignOfExperimentEvaluation::launch()
   {
     for (UnsignedInteger j = 0; j < outputSample.getDimension(); ++j)
     {
-      if (!SpecFunc::IsNormal(outputSample(i, j)))
+      if (!std::isfinite(outputSample(i, j)))
       {
         failedIndices.add(i);
         failedInputSample_.add(getOriginalInputSample()[i]);
@@ -244,7 +240,7 @@ void DesignOfExperimentEvaluation::launch()
   }
 
   if (failedInputSample_.getSize() == getOriginalInputSample().getSize())
-    throw InvalidRangeException(HERE) << "All the evaluations have failed. Check the model. " << warningMessage_;
+    throw InvalidRangeException(HERE) << "All the evaluations have failed.\n" << warningMessage_;
 
   // set design of experiments
   result_.designOfExperiment_.setInputSample(inputSample);
@@ -261,6 +257,43 @@ void DesignOfExperimentEvaluation::launch()
   result_.elapsedTime_ = timeCriteria.getElapsedTime();
 }
 
+void DesignOfExperimentEvaluation::setEvaluations(const Sample &outputSample)
+{
+  TimeCriteria tc;
+  isRunning_ = true;
+  notify("analysisLaunched");
+  initialize();
+
+  result_.designOfExperiment_.setInputSample(originalInputSample_);
+  result_.designOfExperiment_.setOutputSample(outputSample);
+
+  // time
+  TimeCriteria timeCriteria;
+
+  // compute data analysis
+  DataAnalysis dataAnalysis("", result_.designOfExperiment_);
+  dataAnalysis.setIsConfidenceIntervalRequired(false);
+  dataAnalysis.run();
+
+  // set result
+  result_ = dataAnalysis.getResult();
+  timeCriteria.incrementElapsedTime();
+  result_.elapsedTime_ = timeCriteria.getElapsedTime();
+
+  isRunning_ = false;
+  tc.incrementElapsedTime();
+  elapsedTime_ = tc.getElapsedTime();
+  notify("analysisFinished");
+
+  physicalModel_.setEvalTime(getElapsedTime());
+  modelHtmlDescription_ = physicalModel_.getHTMLDescription();
+}
+
+void DesignOfExperimentEvaluation::checkAndSetEvaluations(const DesignOfExperiment &evaluatedDoE)
+{
+  Test::assert_almost_equal(originalInputSample_, evaluatedDoE.getInputSample());
+  setEvaluations(evaluatedDoE.getOutputSample());
+}
 
 Sample DesignOfExperimentEvaluation::getNotEvaluatedInputSample() const
 {
@@ -273,7 +306,6 @@ Sample DesignOfExperimentEvaluation::getNotEvaluatedInputSample() const
   return Sample();
 }
 
-
 DataAnalysisResult DesignOfExperimentEvaluation::getResult() const
 {
   return result_;
@@ -282,8 +314,14 @@ DataAnalysisResult DesignOfExperimentEvaluation::getResult() const
 
 bool DesignOfExperimentEvaluation::canBeLaunched(String &errorMessage) const
 {
+  return DesignOfExperimentEvaluation::CanBeLaunched(errorMessage, getPhysicalModel());
+}
+
+bool DesignOfExperimentEvaluation::CanBeLaunched(String &errorMessage, const PhysicalModel &physicalModel)
+{
+  errorMessage.clear();
   // pm must have inputs
-  if (!getPhysicalModel().getInputDimension())
+  if (!physicalModel.getInputDimension())
     errorMessage = "The physical model must have inputs.";
   return errorMessage.empty();
 }
@@ -294,21 +332,24 @@ Parameters DesignOfExperimentEvaluation::getParameters() const
   Parameters param;
 
   param.add("Outputs of interest", getInterestVariables().__str__());
-  param.add("Sample size", getOriginalInputSample().getSize());
-
-  OSS values;
-  const Point minValues(getOriginalInputSample().getMin());
-  const Point maxValues(getOriginalInputSample().getMax());
-  for (UnsignedInteger i = 0; i < getOriginalInputSample().getDimension(); ++i)
+  const UnsignedInteger sampleSize = getOriginalInputSample().getSize();
+  param.add("Sample size", sampleSize);
+  if (sampleSize)
   {
-    if (minValues[i] != maxValues[i])
-      values << getOriginalInputSample().getDescription()[i] << " : [" << minValues[i] << ", " << maxValues[i] << "]";
-    else
-      values << getOriginalInputSample().getDescription()[i] << " : " << minValues[i];
-    if (i < getOriginalInputSample().getDimension() - 1)
-      values << "\n";
+    OSS values;
+    const Point minValues(getOriginalInputSample().getMin());
+    const Point maxValues(getOriginalInputSample().getMax());
+    for (UnsignedInteger i = 0; i < getOriginalInputSample().getDimension(); ++i)
+    {
+      if (minValues[i] != maxValues[i])
+        values << getOriginalInputSample().getDescription()[i] << " : [" << minValues[i] << ", " << maxValues[i] << "]";
+      else
+        values << getOriginalInputSample().getDescription()[i] << " : " << minValues[i];
+      if (i < getOriginalInputSample().getDimension() - 1)
+        values << "\n";
+    }
+    param.add("Values", values);
   }
-  param.add("Values", values);
 
   param.add("Block size", getBlockSize());
 
