@@ -30,7 +30,7 @@ namespace PERSALYS
 
 std::vector<String> DistributionDictionary::ContinuousDistributions_ =
 {
-  "Arcsine", "Beta", "ChiSquare", "Exponential", "Gamma", "Gumbel", "InverseNormal",
+  "Arcsine", "Beta", "ChiSquare", "Exponential", "Gamma", "Gumbel", "Histogram", "InverseNormal",
   "Laplace", "Logistic", "LogNormal", "LogUniform", "Normal", "Rayleigh", "SmoothedUniform", "Student",
   "Trapezoidal", "Triangular", "Uniform", "WeibullMax", "WeibullMin"
 };
@@ -83,6 +83,14 @@ Distribution DistributionDictionary::BuildDistribution(const String & distributi
     {
       return GumbelMuSigma(mu, sigma).getDistribution();
     }
+    else if (distributionName == "Histogram")
+    {
+      const Point widths = {sigma, 2*sigma};
+      const Point heights = {0.7, 0.3};
+      const Scalar first = mu - sigma;
+
+      return Histogram(first, widths, heights);
+    }
     else if (distributionName == "Hypergeometric")
     {
       return Hypergeometric(4, 1, 1);
@@ -167,8 +175,9 @@ Distribution DistributionDictionary::BuildDistribution(const String & distributi
     else if (distributionName == "UserDefined")
     {
       Sample values(2, 1);
-      values(1, 0) = 1.;
-      return UserDefined(values, Point(2, 0.5));
+      values(0, 0) = mu - sigma;
+      values(1, 0) = mu + sigma;
+      return UserDefined(values);
     }
     else if (distributionName == "WeibullMax")
     {
@@ -187,7 +196,7 @@ Distribution DistributionDictionary::BuildDistribution(const String & distributi
       throw InvalidArgumentException(HERE) << "The given distribution " << distributionName << " is not available.";
     }
   }
-  catch (InvalidArgumentException & ex)
+  catch (const InvalidArgumentException & ex)
   {
     Log::Error(OSS() << "DistributionDictionary::BuildDistribution: Error when creating the distribution " << distributionName << "\n");
     throw InvalidArgumentException(HERE) << ex.what();
@@ -235,6 +244,16 @@ Distribution::PointWithDescriptionCollection DistributionDictionary::GetParamete
     nPWithDesc.setDescription(d2.getDescription());
     nPWithDescColl.add(nPWithDesc);
   }
+  else if (distributionName == "Histogram")
+  {
+    nPWithDesc = PointWithDescription(3);
+
+    const Description description = {"first", "width", "height"};
+    nPWithDesc.setDescription(description);
+    
+    nPWithDescColl.clear();
+    nPWithDescColl.add(nPWithDesc);
+  }
   else if (distributionName == "LogNormal")
   {
     LogNormalMuSigma d1;
