@@ -55,23 +55,6 @@ FMUInfo * FMUInfo::clone() const
 }
 
 
-inline String StrOrBytesToString(PyObject * obj)
-{
-  // old pyfmi returns bytes instead of strings
-  // https://github.com/modelon/PyFMI/commit/801884fb20419f0ea9f174d4065ad87a708d83dc
-  try
-  {
-    // pyfmi >=2.5.1
-    return checkAndConvert<_PyString_, String>(obj);
-  }
-  catch (InvalidArgumentException &)
-  {
-    // pyfmi <2.5.1
-    return checkAndConvert<_PyBytes_, String>(obj);
-  }
-}
-
-
 void FMUInfo::initialize(const String & fmuType)
 {
   const Description fmuTypes = {"auto", "ME", "CS"};
@@ -132,16 +115,16 @@ void FMUInfo::initialize(const String & fmuType)
   }
 
   ScopedPyObjectPointer authorStr(PyObject_CallMethod(model.get(), const_cast<char*>("get_author"), NULL)); // new reference
-  author_ = StrOrBytesToString(authorStr.get());
+  author_ = checkAndConvert<_PyString_, String>(authorStr.get());
 
   ScopedPyObjectPointer copyrightStr(PyObject_CallMethod(model.get(), const_cast<char*>("get_copyright"), NULL)); // new reference
-  copyright_ = StrOrBytesToString(copyrightStr.get());
+  copyright_ = checkAndConvert<_PyString_, String>(copyrightStr.get());
 
   ScopedPyObjectPointer toolStr(PyObject_CallMethod(model.get(), const_cast<char*>("get_generation_tool"), NULL)); // new reference
-  tool_ = StrOrBytesToString(toolStr.get());
+  tool_ = checkAndConvert<_PyString_, String>(toolStr.get());
 
   ScopedPyObjectPointer dateTimeStr(PyObject_CallMethod(model.get(), const_cast<char*>("get_generation_date_and_time"), NULL)); // new reference
-  dateTime_ = StrOrBytesToString(dateTimeStr.get());
+  dateTime_ = checkAndConvert<_PyString_, String>(dateTimeStr.get());
 
   ScopedPyObjectPointer guidStr(PyObject_CallMethod(model.get(), const_cast<char*>("get_guid"), NULL)); // new reference
   guid_ = checkAndConvert<_PyString_, String>(guidStr.get());
@@ -150,13 +133,13 @@ void FMUInfo::initialize(const String & fmuType)
   identifier_ = checkAndConvert<_PyString_, String>(identifierStr.get());
 
   ScopedPyObjectPointer platformStr(PyObject_CallMethod(model.get(), const_cast<char*>("get_model_types_platform"), NULL)); // new reference
-  platform_ = StrOrBytesToString(platformStr.get());
+  platform_ = checkAndConvert<_PyBytes_, String>(platformStr.get());
 
   ScopedPyObjectPointer versionStr(PyObject_CallMethod(model.get(), const_cast<char*>("get_model_version"), NULL)); // new reference
-  version_ = StrOrBytesToString(versionStr.get());
+  version_ = checkAndConvert<_PyString_, String>(versionStr.get());
 
   ScopedPyObjectPointer fmiVersionStr(PyObject_CallMethod(model.get(), const_cast<char*>("get_version"), NULL)); // new reference
-  fmiVersion_ = StrOrBytesToString(fmiVersionStr.get());
+  fmiVersion_ = checkAndConvert<_PyString_, String>(fmiVersionStr.get());
 
   ScopedPyObjectPointer fmuClass(PyObject_GetAttrString(model.get(), const_cast<char*>("__class__"))); // new reference
   ScopedPyObjectPointer fmuClassName(PyObject_GetAttrString(fmuClass.get(), const_cast<char*>("__name__"))); // new reference
