@@ -22,6 +22,8 @@
 
 #include "persalys/MetaModel.hxx"
 #include "persalys/DesignOfExperimentEvaluation.hxx"
+#include "persalys/BaseTools.hxx"
+#include "persalys/Study.hxx"
 
 #include <openturns/KPermutationsDistribution.hxx>
 #include <openturns/RandomGenerator.hxx>
@@ -62,8 +64,6 @@ MetaModelAnalysis::MetaModelAnalysis(const String& name, const DesignOfExperimen
   , nbFolds_(5)
   , seedKFold_(ResourceMap::GetAsUnsignedInteger("RandomGenerator-InitialSeed"))
 {
-  if (designOfExperiment_.hasPhysicalModel() && designOfExperiment_.getPhysicalModel().hasStochasticInputs())
-    isDeterministicAnalysis_ = false;
   if (designOfExperiment_.getOutputSample().getSize())
     setInterestVariables(designOfExperiment_.getOutputSample().getDescription());
 }
@@ -82,18 +82,48 @@ MetaModelAnalysis::MetaModelAnalysis(const String& name, const Analysis& analysi
   , nbFolds_(5)
   , seedKFold_(ResourceMap::GetAsUnsignedInteger("RandomGenerator-InitialSeed"))
 {
-  DesignOfExperimentEvaluation * analysis_ptr = dynamic_cast<DesignOfExperimentEvaluation*>(analysis.getImplementation().get());
+  const auto * analysis_ptr = dynamic_cast<DesignOfExperimentEvaluation*>(analysis.getImplementation().get());
 
   if (!analysis_ptr)
   {
     throw InvalidArgumentException(HERE) << "The given analysis does not contain any design of experiments";
   }
   designOfExperiment_ = analysis_ptr->getResult().getDesignOfExperiment();
-  if (designOfExperiment_.hasPhysicalModel() && designOfExperiment_.getPhysicalModel().hasStochasticInputs())
-    isDeterministicAnalysis_ = false;
   setInterestVariables(analysis_ptr->getInterestVariables());
 }
 
+PythonPhysicalModel MetaModelAnalysis::asPythonPhysicalModel(const Study &study) const
+{
+  if (hasMoreThanOneObjectWithName(Study::GetInstances(), study.getName()))
+    throw DuplicateItemException(HERE, DuplicateItemException::ItemType::Study) << "Two or more studies are opened with the same name";
+  
+  if (hasMoreThanOneObjectWithName(study.getAnalyses(), getName()))
+    throw DuplicateItemException(HERE, DuplicateItemException::ItemType::Analysis) << "There are more than one analysis in the study with name " << getName();
+
+  if (!study.hasAnalysisNamed(getName()))
+    throw InvalidArgumentException(HERE) << "There is no analysis named " << getName()<< " in the study " << study.getName();
+
+  PhysicalModel metaModel = getMetaModel();
+
+  const String inputNamesString(Parameters::GetOTDescriptionStr(metaModel.getInputNames(), false, false));
+  const String outputNamesString(Parameters::GetOTDescriptionStr(metaModel.getOutputNames(), false, false));
+
+  OSS code;
+  code << "import persalys\n";
+  code << "\n";
+  code << "study = persalys.Study.GetInstanceByName('" << study.getName() << "')\n";
+  code << "analysis = study.getAnalysisByName('" << getName() << "').getImplementation()\n";
+  code << "metamodel_function = analysis.getResult().getMetaModel().getFunction()\n";
+  code << "\n";
+  code << "def _exec(" << inputNamesString  << "):\n";
+  code << "    " << outputNamesString  << " = metamodel_function([" << inputNamesString << "])";
+  if (metaModel.getOutputDimension() <= 1u)
+    code << "[0]";          // metamodel_function returns a Point so in dimension 1 we need to extract the value
+  code << "\n";
+  code << "    return " << outputNamesString << "\n";
+
+  return PythonPhysicalModel(getName(), metaModel.getInputs(), metaModel.getOutputs(), code.str());
+}
 
 bool MetaModelAnalysis::analyticalValidation() const
 {
@@ -303,8 +333,11 @@ void MetaModelAnalysis::buildMetaModel(MetaModelAnalysisResult& result, const Fu
     for (UnsignedInteger i = 0; i < inputsNames.getSize(); ++i)
     {
       const Distribution marginal = distribution_.getMarginal(i);
-      metaModel.setDistribution(inputsNames[i], marginal);
+      const String inputName = inputsNames[i];
+      metaModel.setDistribution(inputName, marginal);
+      metaModel.getInputByName(inputName).setValue(marginal.getMean().at(0));
     }
+    metaModel.setCopula(inputsNames, distribution_.getCopula());
   }
 
   // copula
@@ -386,7 +419,7 @@ void MetaModelAnalysis::validateMetaModelResult(MetaModelAnalysisResult& result,
     {
       computeAnalyticalValidation(result, inputSample);
     }
-    catch (std::exception & ex)
+    catch (const std::exception & ex)
     {
       warningMessage_ += OSS() << "Analytical validation failed: " << ex.what() << "\n";
     }
@@ -399,7 +432,7 @@ void MetaModelAnalysis::validateMetaModelResult(MetaModelAnalysisResult& result,
     {
       computeTestSampleValidation(result, inputSample);
     }
-    catch (std::exception & ex)
+    catch (const std::exception & ex)
     {
       warningMessage_ += OSS() << "Test sample validation failed: " << ex.what() << "\n";
     }
@@ -412,7 +445,7 @@ void MetaModelAnalysis::validateMetaModelResult(MetaModelAnalysisResult& result,
     {
       computeKFoldValidation(result, inputSample);
     }
-    catch (std::exception & ex)
+    catch (const std::exception & ex)
     {
       warningMessage_ += OSS() << "K-Fold validation failed: " << ex.what() << "\n";
     }
@@ -425,7 +458,7 @@ void MetaModelAnalysis::validateMetaModelResult(MetaModelAnalysisResult& result,
     {
       computeLOOValidation(result, inputSample);
     }
-    catch (std::exception & ex)
+    catch (const std::exception & ex)
     {
       warningMessage_ += OSS() << "Leave-one-out validation failed: " << ex.what() << "\n";
     }
@@ -616,19 +649,28 @@ void MetaModelAnalysis::computeLOOValidation(MetaModelAnalysisResult& result, co
   computeError(result.looValidation_.metaModelSample_, result.outputSample_, result.looValidation_.mse_, result.looValidation_.q2_);
 }
 
+PhysicalModel MetaModelAnalysis::getMetaModel() const
+{
+  throw NotYetImplementedException(HERE) << "This function is only defined in children classes";
+}
+
 
 bool MetaModelAnalysis::canBeLaunched(String &errorMessage) const
 {
-  const bool canBeLaunched = DesignOfExperimentAnalysis::canBeLaunched(errorMessage);
-  if (!canBeLaunched)
+  return MetaModelAnalysis::CanBeLaunched(errorMessage, designOfExperiment_);
+}
+
+
+bool MetaModelAnalysis::CanBeLaunched(String &errorMessage, const DesignOfExperiment &doe)
+{
+  if (!DesignOfExperimentAnalysis::CanBeLaunched(errorMessage, doe))
     return false;
   // doe must have in/output data
-  if (!getDesignOfExperiment().getOutputSample().getSize() || !getDesignOfExperiment().getInputSample().getSize())
+  if (!doe.getOutputSample().getSize() || !doe.getInputSample().getSize())
     errorMessage = "The design of experiments must contain data for input and output variables.";
   return errorMessage.empty();
 }
 
-
 /* String converter */
 String MetaModelAnalysis::__repr__() const
 {
