@@ -2,7 +2,7 @@
 /**
  *  @brief Optimization of a physical model
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -266,7 +266,7 @@ void OptimizationAnalysis::launch()
   problem.setMinimization(isMinimization_);
 
   // build solver
-  OptimizationAlgorithm solver(OptimizationAlgorithm::Build(solverName_));
+  OptimizationAlgorithm solver(OptimizationAlgorithm::GetByName(solverName_));
   solver.setProblem(problem);
   solver.setStartingPoint(variableInputsValues_);
   solver.setMaximumCallsNumber(getMaximumCallsNumber());
