@@ -2,7 +2,7 @@
 /**
  *  @brief Custom ResourceMap keys
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -35,8 +35,6 @@ namespace PERSALYS
     static std::once_flag flag;
     std::call_once(flag, [&]()
     {
-      // increase function cache
-      OT::ResourceMap::SetAsUnsignedInteger("Cache-MaxSize", 16384);
 #ifdef _WIN32
       // ProcessPoolExecutor startup penalty is much higher
       OT::ResourceMap::AddAsUnsignedInteger("PythonPhysicalModel-DefaultProcessNumber", 1);
