@@ -921,20 +921,23 @@ bool PhysicalModelImplementation::isValid() const
 }
 
 
-String PhysicalModelImplementation::getHtmlDescription(const bool deterministic) const
+String PhysicalModelImplementation::getHTMLDescription() const
 {
   OSS oss;
 
   oss << "<h2><center>Physical model</center></h2>";
 
   if (hasMesh_)
-    oss << meshModel_.getHtmlDescription();
-
-  if (deterministic)
+    oss << meshModel_.getHTMLDescription();
+  
+  // deterministic inputs
+  if (getInputDimension() > getStochasticInputNames().getSize())
   {
-    // Inputs
-    oss << "<h3>Inputs</h3><p>";
-    oss << "<table style=\"width:100%\" border=\"1\" cellpadding=\"5\">";
+    if(hasStochasticInputs())
+      oss << "<h3>Deterministic inputs</h3><p>";
+    else
+      oss << "<h3>Inputs</h3><p>";
+    oss << R"(<table style="width:100%" border="1" cellpadding="5">)";
     oss << "<tr>";
     oss << "  <th>Name</th>";
     oss << "  <th>Description</th>";
@@ -942,91 +945,65 @@ String PhysicalModelImplementation::getHtmlDescription(const bool deterministic)
     oss << "</tr>";
     for (UnsignedInteger i = 0; i < getInputDimension(); ++i)
     {
-      oss << "<tr>";
-      oss << "  <td>" << getInputNames()[i] << "</td>";
-      const String desc(getInputs()[i].getDescription());
-      oss << "  <td>" << (desc.empty() ? "-" : desc) << "</td>";
-      oss << "  <td>" << getInputs()[i].getValue() << "</td>";
-      oss << "</tr>";
+      if (!getInputs()[i].isStochastic())
+      {
+        oss << "<tr>";
+        oss << "  <td>" << getInputNames()[i] << "</td>";
+        const String desc(getInputs()[i].getDescription());
+        oss << "  <td>" << (desc.empty() ? "-" : desc) << "</td>";
+        oss << "  <td>" << getInputs()[i].getValue() << "</td>";
+        oss << "</tr>";
+      }
     }
 
     oss << "</table></p>";
   }
-  else
+  // Stochastic inputs
+  if (hasStochasticInputs())
   {
-    // Deterministic inputs
-    if (getInputDimension() > getStochasticInputNames().getSize())
+    oss << "<h3>Stochastic inputs</h3><p>";
+    oss << R"(<table style="width:100%" border="1" cellpadding="5">)";
+    oss << "<tr>";
+    oss << "  <th>Name</th>";
+    oss << "  <th>Description</th>";
+    oss << "  <th>Distribution</th>";
+    oss << "</tr>";
+    for (UnsignedInteger i = 0; i < getInputDimension(); ++i)
     {
-      oss << "<h3>Deterministic inputs</h3><p>";
-      oss << "<table style=\"width:100%\" border=\"1\" cellpadding=\"5\">";
-      oss << "<tr>";
-      oss << "  <th>Name</th>";
-      oss << "  <th>Description</th>";
-      oss << "  <th>Value</th>";
-      oss << "</tr>";
-      for (UnsignedInteger i = 0; i < getInputDimension(); ++i)
+      if (getInputs()[i].isStochastic())
       {
-        if (!getInputs()[i].isStochastic())
-        {
-          oss << "<tr>";
-          oss << "  <td>" << getInputNames()[i] << "</td>";
-          const String desc(getInputs()[i].getDescription());
-          oss << "  <td>" << (desc.empty() ? "-" : desc) << "</td>";
-          oss << "  <td>" << getInputs()[i].getValue() << "</td>";
-          oss << "</tr>";
-        }
+        oss << "<tr>";
+        oss << "  <td>" << getInputNames()[i] << "</td>";
+        const String desc(getInputs()[i].getDescription());
+        oss << "  <td>" << (desc.empty() ? "-" : desc) << "</td>";
+        oss << "  <td>" << getInputs()[i].getDistribution().__str__() << "</td>";
+        oss << "</tr>";
       }
-
-      oss << "</table></p>";
-    }
-
-    // Stochastic inputs
-    if (hasStochasticInputs())
-    {
-      oss << "<h3>Stochastic inputs</h3><p>";
-      oss << "<table style=\"width:100%\" border=\"1\" cellpadding=\"5\">";
-      oss << "<tr>";
-      oss << "  <th>Name</th>";
-      oss << "  <th>Description</th>";
-      oss << "  <th>Distribution</th>";
-      oss << "</tr>";
-      for (UnsignedInteger i = 0; i < getInputDimension(); ++i)
-      {
-        if (getInputs()[i].isStochastic())
-        {
-          oss << "<tr>";
-          oss << "  <td>" << getInputNames()[i] << "</td>";
-          const String desc(getInputs()[i].getDescription());
-          oss << "  <td>" << (desc.empty() ? "-" : desc) << "</td>";
-          oss << "  <td>" << getInputs()[i].getDistribution().__str__() << "</td>";
-          oss << "</tr>";
-        }
-      }
-      oss << "</table></p>";
-    }
-    // copula
-    if (!getCopula().hasIndependentCopula())
-    {
-      oss << "<h3>Dependence</h3><p>";
-      oss << "<table style=\"width:100%\" border=\"1\" cellpadding=\"5\">";
-      oss << "<tr>";
-      oss << "  <th>Group of variables</th>";
-      oss << "  <th>Copula</th>";
-      oss << "</tr>";
-      for (UnsignedInteger i = 0; i < getCopulaCollection().getSize(); ++i)
-      {
-        if (!getCopulaCollection()[i].hasIndependentCopula())
-        {
-          oss << "<tr>";
-          oss << "  <td>" << getCopulaCollection()[i].getDescription() << "</td>";
-          oss << "  <td>" << getCopulaCollection()[i].__str__() << "</td>";
-          oss << "</tr>";
-        }
-      }
-      oss << "</table></p>";
     }
+    oss << "</table></p>";
   }
-
+  // copula
+  if (!getCopula().hasIndependentCopula())
+  {
+    oss << "<h3>Dependence</h3><p>";
+    oss << R"(<table style="width:100%" border="1" cellpadding="5">)";
+    oss << "<tr>";
+    oss << "  <th>Group of variables</th>";
+    oss << "  <th>Copula</th>";
+    oss << "</tr>";
+    for (UnsignedInteger i = 0; i < getCopulaCollection().getSize(); ++i)
+    {
+      if (!getCopulaCollection()[i].hasIndependentCopula())
+      {
+        oss << "<tr>";
+        oss << "  <td>" << getCopulaCollection()[i].getDescription() << "</td>";
+        oss << "  <td>" << getCopulaCollection()[i].__str__() << "</td>";
+        oss << "</tr>";
+      }
+    }
+    oss << "</table></p>";
+  }
+  
   return oss;
 }
 
@@ -1039,11 +1016,7 @@ String PhysicalModelImplementation::getPythonScript() const
 
 void PhysicalModelImplementation::exportStandalonePythonScript(const String & fileName) const
 {
-  const String extension(fileName.substr(fileName.size() - 3));
-  String filenameXML(fileName);
-  if (extension == ".py")
-    filenameXML = fileName.substr(0, fileName.size() - 3);
-  filenameXML += ".xml";
+  String filenameXML = fileName + ".xml";
   const String basenameXML = filenameXML.substr(filenameXML.find_last_of("/\\") + 1);
 
   // write script
@@ -1090,28 +1063,14 @@ String PhysicalModelImplementation::getProbaModelPythonScript() const
       if (distributionName != "TruncatedDistribution")
       {
         oss << "dist_" << inputPythonName << " = ot." << distributionName << "(";
-        PointWithDescription parameters = distribution.getParametersCollection()[0];
-        for (UnsignedInteger j = 0; j < parameters.getSize(); ++ j)
-        {
-          oss << parameters[j];
-          if (j < parameters.getSize() - 1)
-            oss << ", ";
-        }
-        oss << ")\n";
+        oss << Parameters::GetOTPointWithDescriptionStr(distribution.getParametersCollection()[0]) <<  ")\n";
       }
       else
       {
         TruncatedDistribution truncatedDistribution = *dynamic_cast<TruncatedDistribution*>(distribution.getImplementation().get());
         distribution = truncatedDistribution.getDistribution();
         oss << "dist_" << inputPythonName << " = ot." << distribution.getImplementation()->getClassName() << "(";
-        PointWithDescription parameters = distribution.getParametersCollection()[0];
-        for (UnsignedInteger j = 0; j < parameters.getSize(); ++ j)
-        {
-          oss << parameters[j];
-          if (j < parameters.getSize() - 1)
-            oss << ", ";
-        }
-        oss << ")\n";
+        oss << Parameters::GetOTPointWithDescriptionStr(distribution.getParametersCollection()[0]) <<  ")\n";
         oss << "dist_" << inputPythonName << " = ot." << distributionName << "(";
         oss << "dist_" << inputPythonName << ", ";
 
@@ -1163,7 +1122,7 @@ String PhysicalModelImplementation::getCopulaPythonScript() const
   return oss;
 }
 
-void PhysicalModelImplementation::setEvalTime(const OT::Scalar & evalTime)
+void PhysicalModelImplementation::setEvalTime(const OT::Scalar evalTime)
 {
   evalTime_ = evalTime;
 }
@@ -1231,9 +1190,9 @@ void PhysicalModelImplementation::load(Advocate & adv)
 }
 
 
-/* Nothing to do at this level. Overloaded in child classes if needed.*/
-void PhysicalModelImplementation::acceptLaunchParameters(LaunchParametersVisitor* /*visitor*/)
+bool PhysicalModelImplementation::canBeDetached() const
 {
+  return false;
 }
 
 }
