@@ -142,7 +142,6 @@ Point PythonScriptEvaluation::operator() (const Point & inP) const
     handleExceptionTraceback();
     LastCodeHash_ = codeHash_;
   }
-
   callsNumber_.increment();
   PyObject * script = PyDict_GetItemString(dict, "_exec");
   if (script == NULL)
@@ -154,13 +153,14 @@ Point PythonScriptEvaluation::operator() (const Point & inP) const
 
   if (getOutputDimension() > 1)
   {
-    outP = convert<_PySequence_, Point>(outputList.get());
+    outP = checkAndConvert<_PySequence_, Point>(outputList.get());
   }
   else
   {
-    Scalar value = convert<_PyFloat_, Scalar>(outputList.get());
+    Scalar value = checkAndConvert<_PyFloat_, Scalar>(outputList.get());
     outP = Point(1, value);
   }
+
   return outP;
 }
 
@@ -188,9 +188,8 @@ Sample PythonScriptEvaluation::operator() (const Sample & inS) const
     if (nokIdx.getSize())
       throw BatchFailedException(HERE, nokIdx, errorDesc,
                                  nokIdx.complement(inS.getSize()), outS)
-          << (nokIdx.getSize() == 1 ? errorDesc[0] : "operator(Sample) partial fail");
+          << "Batch evaluation " << nokIdx.getSize() << "/" << size << " failed: " << errorDesc[nokIdx[0]];
     return outS;
-
   }
 
   const UnsignedInteger outDim = getOutputDimension();
@@ -229,7 +228,9 @@ Sample PythonScriptEvaluation::operator() (const Sample & inS) const
   oss << "if __name__== '__main__':\n";
   oss << "    if sys.platform == 'win32':\n";
   oss << "        mp.set_executable(os.path.join(sys.exec_prefix, 'pythonw.exe'))\n";
-  oss << "    with ProcessPoolExecutor(max_workers=" << (processNumber_ > 0 ? std::to_string(processNumber_) : "None") << ") as executor:\n";
+  oss << "    ctx = mp.get_context('fork') if sys.platform.startswith('linux') else None\n";
+  const String max_workers = (processNumber_ > 0) ? std::to_string(processNumber_) : "None";
+  oss << "    with ProcessPoolExecutor(max_workers=" << max_workers << ", mp_context=ctx) as executor:\n";
   oss << "        resu = {executor.submit(" << code_mod << "._exec, *x): x for x in X}\n";
   oss << "        for future in resu:\n";
   oss << "            try:\n";
@@ -260,7 +261,7 @@ Sample PythonScriptEvaluation::operator() (const Sample & inS) const
   PyObject * exceptionResult = PyDict_GetItemString(dict, "exception");
   if (exceptionResult == NULL)
     throw InternalException(HERE) << "no exception";
-  Description desc(convert<_PySequence_, Description>(exceptionResult));
+  Description errorDesc(convert<_PySequence_, Description>(exceptionResult));
 
   // get suceeded indices
   PyObject * okIdxResult = PyDict_GetItemString(dict, "okIdx");
@@ -280,8 +281,8 @@ Sample PythonScriptEvaluation::operator() (const Sample & inS) const
 
   // if any failed indices, throw
   if (nokIdx.getSize())
-    throw BatchFailedException(HERE, nokIdx, desc, okIdx, outputSample)
-        << (nokIdx.getSize() == 1 ? desc[0] : "operator(Sample) partial fail");
+    throw BatchFailedException(HERE, nokIdx, errorDesc, okIdx, outputSample)
+        << "Batch evaluation " << nokIdx.getSize() << "/" << size << " failed: " << errorDesc[nokIdx[0]];
 
   // check
   if (outputSample.getSize() != size)
