@@ -19,6 +19,7 @@
  *
  */
 #include "persalys/SRCAnalysis.hxx"
+#include "persalys/SobolAnalysis.hxx"
 
 #include <openturns/RandomGenerator.hxx>
 #include <openturns/CorrelationAnalysis.hxx>
@@ -40,7 +41,6 @@ SRCAnalysis::SRCAnalysis()
   , simulationsNumber_(10000)
   , result_()
 {
-  isDeterministicAnalysis_ = false;
 }
 
 
@@ -50,7 +50,6 @@ SRCAnalysis::SRCAnalysis(const String & name, const PhysicalModel & physicalMode
   , simulationsNumber_(nbSimu)
   , result_()
 {
-  isDeterministicAnalysis_ = false;
 }
 
 
@@ -220,6 +219,13 @@ void SRCAnalysis::launch()
     LOGWARN("The model does not have an independent copula, the result of the sensitivity analysis could be false.");
     warningMessage_ = "The model does not have an independent copula, the result of the sensitivity analysis could be false.";
   }
+
+  DesignOfExperiment doe;
+
+  doe.setInputSample(effectiveInputSample);
+  outputSample.setDescription(getInterestVariables());
+  doe.setOutputSample(outputSample);
+  result_.setDesignOfExperiment(doe);
 }
 
 
@@ -267,13 +273,7 @@ bool SRCAnalysis::hasValidResult() const
 
 bool SRCAnalysis::canBeLaunched(String &errorMessage) const
 {
-  const bool canBeLaunched = PhysicalModelAnalysis::canBeLaunched(errorMessage);
-  if (!canBeLaunched)
-    return false;
-  // pm must have independent copula
-  if (!getPhysicalModel().getCopula().hasIndependentCopula())
-    errorMessage = "The model must have an independent copula to compute a sensitivity analysis but here inputs are dependent.";
-  return errorMessage.empty();
+  return SobolAnalysis::CanBeLaunched(errorMessage, getPhysicalModel());
 }
 
 
