@@ -48,7 +48,6 @@ SobolAnalysis::SobolAnalysis()
   , confidenceLevel_(1 - ResourceMap::GetAsScalar("SobolSimulationAlgorithm-DefaultIndexQuantileLevel"))
   , result_()
 {
-  isDeterministicAnalysis_ = false;
 }
 
 
@@ -60,7 +59,6 @@ SobolAnalysis::SobolAnalysis(const String& name, const PhysicalModel& physicalMo
   , confidenceLevel_(1 - ResourceMap::GetAsScalar("SobolSimulationAlgorithm-DefaultIndexQuantileLevel"))
   , result_()
 {
-  isDeterministicAnalysis_ = false;
 }
 
 
@@ -237,6 +235,10 @@ void SobolAnalysis::launch()
   SobolSimulationResult sobolResult(algo.getResult());
   const UnsignedInteger outerSampling = sobolResult.getOuterSampling();
 
+  // TODO: should be fixed on OT side by 1.26
+  if (!outerSampling)
+    throw NotDefinedException(HERE) << "Could not complete 1 iteration; check the replication size";
+
   Scalar foCILength = 0.;
   Scalar toCILength = 0.;
   for (UnsignedInteger i = 0; i < nbInputs; ++i)
@@ -300,6 +302,18 @@ void SobolAnalysis::launch()
     result_.aggregatedFirstOrderIndicesInterval_ = sobolResult.getFirstOrderIndicesDistribution().computeBilateralConfidenceInterval(getConfidenceLevel());
     result_.aggregatedTotalIndicesInterval_ = sobolResult.getTotalOrderIndicesDistribution().computeBilateralConfidenceInterval(getConfidenceLevel());
   }
+
+  DesignOfExperiment doe;
+
+  Sample inSample = function.getInputHistory();
+  inSample.setDescription(function.getInputDescription());
+  doe.setInputSample(inSample);
+  Sample outSample = function.getOutputHistory();
+  outSample.setDescription(function.getOutputDescription());
+  doe.setOutputSample(outSample);
+  
+  result_.setDesignOfExperiment(doe);
+
   function.disableHistory();
 }
 
@@ -356,12 +370,19 @@ bool SobolAnalysis::hasValidResult() const
 
 bool SobolAnalysis::canBeLaunched(String &errorMessage) const
 {
-  const bool canBeLaunched = PhysicalModelAnalysis::canBeLaunched(errorMessage);
-  if (!canBeLaunched)
+  return SobolAnalysis::CanBeLaunched(errorMessage, getPhysicalModel());
+}
+
+bool SobolAnalysis::CanBeLaunched(String &errorMessage, const PhysicalModel &physicalModel)
+{
+  if (!PhysicalModelAnalysis::CanBeLaunched(errorMessage, physicalModel))
     return false;
+  if (!physicalModel.hasStochasticInputs())
+    errorMessage = "The model must have stochastic inputs.";
   // pm must have independent copula
-  if (!getPhysicalModel().getCopula().hasIndependentCopula())
+  if (!physicalModel.getCopula().hasIndependentCopula())
     errorMessage = "The model must have an independent copula to compute a sensitivity analysis but here inputs are dependent.";
+
   return errorMessage.empty();
 }
 
