@@ -181,13 +181,13 @@ Function SymbolicPhysicalModel::generateFunction(const Description & outputNames
 }
 
 
-String SymbolicPhysicalModel::getHtmlDescription(const bool deterministic) const
+String SymbolicPhysicalModel::getHTMLDescription() const
 {
   OSS oss;
 
-  oss << PhysicalModelImplementation::getHtmlDescription(deterministic);
+  oss << PhysicalModelImplementation::getHTMLDescription();
   oss << "<h3>Outputs</h3><p>";
-  oss << "<table style=\"width:100%\" border=\"1\" cellpadding=\"5\">";
+  oss << R"(<table style="width:100%" border="1" cellpadding="5">)";
   oss << "<tr>";
   oss << "  <th>Name</th>";
   oss << "  <th>Description</th>";
@@ -199,7 +199,7 @@ String SymbolicPhysicalModel::getHtmlDescription(const bool deterministic) const
     oss << "  <td>" << getOutputNames()[i] << "</td>";
     const String desc(getOutputs()[i].getDescription());
     oss << "  <td>" << (desc.empty() ? "-" : desc) << "</td>";
-    oss << "  <td>" << Tools::escapeHtml(getFormulas()[i]) << "</td>";
+    oss << "  <td>" << Tools::EscapeHTML(getFormulas()[i]) << "</td>";
     oss << "</tr>";
   }
   oss << "</table></p>";
