@@ -19,6 +19,7 @@
  *
  */
 #include "persalys/TaylorExpansionMomentsAnalysis.hxx"
+#include "persalys/MonteCarloAnalysis.hxx"
 
 #include <openturns/TaylorExpansionMoments.hxx>
 #include <openturns/PersistentObjectFactory.hxx>
@@ -36,7 +37,6 @@ static Factory<TaylorExpansionMomentsAnalysis> Factory_TaylorExpansionMomentsAna
 TaylorExpansionMomentsAnalysis::TaylorExpansionMomentsAnalysis()
   : PhysicalModelAnalysis()
 {
-  isDeterministicAnalysis_ = false;
 }
 
 
@@ -44,7 +44,6 @@ TaylorExpansionMomentsAnalysis::TaylorExpansionMomentsAnalysis()
 TaylorExpansionMomentsAnalysis::TaylorExpansionMomentsAnalysis(const String & name, const PhysicalModel & physicalModel)
   : PhysicalModelAnalysis(name, physicalModel)
 {
-  isDeterministicAnalysis_ = false;
 }
 
 
@@ -80,7 +79,11 @@ void TaylorExpansionMomentsAnalysis::launch()
   for (UnsignedInteger i = 0; i < variance.getDimension(); ++i)
     standardDeviation[i] = sqrt(variance[i]);
 
-  result_ = TaylorExpansionMomentsResult(getInterestVariables(), meanFirstOrder, meanSecondOrder, standardDeviation, variance);
+  Point importanceFactors;
+  if (getInterestVariables().getSize() == 1u)
+    importanceFactors = algoTaylorExpansionMoments.getImportanceFactors();
+
+  result_ = TaylorExpansionMomentsResult(getInterestVariables(), meanFirstOrder, meanSecondOrder, standardDeviation, variance, importanceFactors);
 }
 
 
@@ -117,9 +120,15 @@ String TaylorExpansionMomentsAnalysis::getPythonScript() const
 
 bool TaylorExpansionMomentsAnalysis::hasValidResult() const
 {
-  return getResult().getOutputNames().getSize() != 0;
+  return !getResult().getOutputNames().isEmpty();
 }
 
+bool TaylorExpansionMomentsAnalysis::canBeLaunched(String &errorMessage) const
+{
+  return MonteCarloAnalysis::CanBeLaunched(errorMessage, getPhysicalModel());
+}
+
+
 
 /* String converter */
 String TaylorExpansionMomentsAnalysis::__repr__() const
