@@ -80,7 +80,7 @@ void YACSCouplingPhysicalModel::setCode(const String & script)
   {
     evaluation_.setCode(script);
   }
-  catch (std::exception & ex)
+  catch (const std::exception & ex)
   {
     throw InvalidArgumentException(HERE) << "Error in the script:\n" << ex.what();
   }
@@ -95,6 +95,8 @@ void YACSCouplingPhysicalModel::setCode(const String & script)
     for (UnsignedInteger j = 0; j < inputFiles.getSize(); ++ j)
     {
       const CouplingInputFile inputFile(inputFiles[j]);
+      if (inputFile.getPath().empty())
+        continue;
       // yacs wants absolute paths
       inFiles.push_back(std::filesystem::absolute(inputFile.getPath()).string());
     }
@@ -102,6 +104,8 @@ void YACSCouplingPhysicalModel::setCode(const String & script)
     for (UnsignedInteger j = 0; j < resourceFiles.getSize(); ++ j)
     {
       const CouplingResourceFile resourceFile(resourceFiles[j]);
+      if (resourceFile.getPath().empty())
+        continue;
       // yacs wants absolute paths
       inFiles.push_back(std::filesystem::absolute(resourceFile.getPath()).string());
     }
@@ -109,10 +113,6 @@ void YACSCouplingPhysicalModel::setCode(const String & script)
   jobParameters().in_files(inFiles);
 }
 
-Function YACSCouplingPhysicalModel::getFunction() const
-{
-  return generateFunction(getOutputNames());
-}
 
 Function YACSCouplingPhysicalModel::generateFunction(const Description & outputNames) const
 {
@@ -247,8 +247,10 @@ void YACSCouplingPhysicalModel::load(Advocate & adv)
 }
 
 
-void YACSCouplingPhysicalModel::acceptLaunchParameters(LaunchParametersVisitor* visitor)
+bool YACSCouplingPhysicalModel::canBeDetached() const
 {
-  visitor->visitYACS(this);
+  return true;
 }
+
+
 }
