@@ -24,6 +24,8 @@
 #include <openturns/PersistentObjectFactory.hxx>
 #include <openturns/MemoizeFunction.hxx>
 
+#include <regex>
+
 using namespace OT;
 
 
@@ -36,11 +38,9 @@ static Factory<YACSPhysicalModel> Factory_YACSPhysicalModel;
 
 /* Default constructor */
 YACSPhysicalModel::YACSPhysicalModel(const String & name)
-  : PhysicalModelImplementation(name)
-  , evaluation_()
+  : PythonPhysicalModel(name)
 {
-  setCode("def _exec(X0):\n    Y0 = X0\n    return Y0");
-  updateData();
+  // Nothing to do
 }
 
 
@@ -48,11 +48,10 @@ YACSPhysicalModel::YACSPhysicalModel(const String & name)
 YACSPhysicalModel::YACSPhysicalModel(const String & name,
                                      const InputCollection & inputs,
                                      const OutputCollection & outputs,
-                                     const String & script)
-  : PhysicalModelImplementation(name, inputs, outputs)
-  , evaluation_(script)
+                                     const String & code)
+  : PythonPhysicalModel(name, inputs, outputs, "")
 {
-  updateData();
+  setCode(code);
 }
 
 
@@ -111,63 +110,27 @@ const ydefx::JobParametersProxy& YACSPhysicalModel::jobParameters()const
 }
 
 
-void YACSPhysicalModel::setJobModel(const py2cpp::PyPtr& model)
-{
-  evaluation_.setJobModel(model);
-}
-
-
-String YACSPhysicalModel::getCode() const
-{
-  return evaluation_.getCode();
-}
-
-
 void YACSPhysicalModel::setCode(const String & code)
 {
-  try
+  PythonPhysicalModel::setCode(code);
+  if (useYACS_)
   {
-    evaluation_.setCode(code);
+    try
+    {
+      evaluation_.setCode(code);
+    }
+    catch (const std::exception & ex)
+    {
+      throw InvalidArgumentException(HERE) << "Error in the script.\n" << ex.what();
+    }
   }
-  catch (std::exception & ex)
-  {
-    throw InvalidArgumentException(HERE) << "Error in the script.\n" << ex.what();
-  }
-  updateData();
-}
-
-
-void YACSPhysicalModel::updateData()
-{
-  unsigned int size = evaluation_.getInputDimension();
-  InputCollection newInputs(size);
-  for (unsigned int i = 0; i < size; ++ i)
-  {
-    const String inputName(evaluation_.getInputVariablesNames()[i]);
-    if (hasInputNamed(inputName))
-      newInputs[i] = getInputByName(inputName);
-    else
-      newInputs[i] = Input(inputName, evaluation_.getInputValues()[i]);
-  }
-  PhysicalModelImplementation::setInputs(newInputs);
-
-  size = evaluation_.getOutputDimension();
-  OutputCollection newOutputs(size);
-  for (unsigned int i = 0; i < size; ++ i)
-  {
-    const String outputName(evaluation_.getOutputVariablesNames()[i]);
-    if (hasOutputNamed(outputName))
-      newOutputs[i] = getOutputByName(outputName);
-    else
-      newOutputs[i] = Output(outputName);
-  }
-  functionCache_ = Function();
-  PhysicalModelImplementation::setOutputs(newOutputs);
 }
 
 
 Function YACSPhysicalModel::generateFunction(const Description & outputNames) const
 {
+  if (!useYACS_)
+    return PythonPhysicalModel::generateFunction(outputNames);
   if (!functionCache_.getEvaluation().getImplementation()->isActualImplementation())
   {
     YACSEvaluation anEvaluation(evaluation_);
@@ -178,50 +141,6 @@ Function YACSPhysicalModel::generateFunction(const Description & outputNames) co
 }
 
 
-void YACSPhysicalModel::ReplaceInString(String& workString,
-                                        const String& strToReplace,
-                                        const String& newValue)
-{
-  std::size_t pos = workString.find(strToReplace);
-  while( pos != std::string::npos)
-  {
-    workString.replace(pos, strToReplace.size(), newValue);
-    pos = workString.find(strToReplace, pos + newValue.size());
-  }
-}
-
-String YACSPhysicalModel::getHtmlDescription(const bool deterministic) const
-{
-  OSS oss;
-  oss << PhysicalModelImplementation::getHtmlDescription(deterministic);
-  oss << "<h3>Outputs</h3><p>";
-  oss << "<table style=\"width:100%\" border=\"1\" cellpadding=\"5\">";
-  oss << "<tr>";
-  oss << "  <th>Name</th>";
-  oss << "  <th>Description</th>";
-  oss << "</tr>";
-  for (UnsignedInteger i = 0; i < getOutputDimension(); ++i)
-  {
-    oss << "<tr>";
-    oss << "  <td>" << getOutputNames()[i] << "</td>";
-    const String desc(getOutputs()[i].getDescription());
-    oss << "  <td>" << (desc.empty() ? "-" : desc) << "</td>";
-    oss << "</tr>";
-  }
-  oss << "</table></p>";
-  oss << "</table></p>";
-  oss << "<h3>Content</h3>";
-  oss << "<pre>";
-  String code = getCode();
-  // replace all "<" by "&lt;"
-  ReplaceInString(code, "<", "&lt;");
-  oss << code;
-  oss << "</pre>";
-
-  return oss;
-}
-
-
 String YACSPhysicalModel::getPythonScript() const
 {
   OSS oss;
@@ -236,14 +155,16 @@ String YACSPhysicalModel::getPythonScript() const
   oss << "outputs = " << Parameters::GetOTDescriptionStr(getOutputNames(), false) << "\n";
 
   // replace ''' by """
-  std::string myString = getCode();
-  ReplaceInString(myString, "'''", "\"\"\"");
+  std::string code = getCode();
+  std::regex_replace(code, std::regex("'''"), "\"\"\"");
 
-  oss << "code = '''" << myString << "'''\n";
+  oss << "code = '''" << code << "'''\n";
   oss << getName()
       << " = persalys.YACSPhysicalModel('" << getName() << "'"
       << ", inputs, outputs, code)\n";
-  oss << getJobParamsPythonScript();
+  oss << getName() << ".setUseYACS(" << (useYACS_ ? "True" : "False") << ")\n";
+  if (useYACS_)
+    oss << getJobParamsPythonScript();
 
   oss << getProbaModelPythonScript();
   oss << PhysicalModelImplementation::getCopulaPythonScript();
@@ -342,11 +263,40 @@ OT::String YACSPhysicalModel::getJobParamsPythonScript() const
 }
 
 
+/* Use YACS backend or Python backend */
+void YACSPhysicalModel::setUseYACS(const Bool useYACS)
+{
+  if (useYACS != useYACS_)
+  {
+    useYACS_ = useYACS;
+    functionCache_ = Function();
+
+    if (useYACS)
+    {
+      try
+      {
+        evaluation_.setCode(getCode());
+      }
+      catch (const std::exception & ex)
+      {
+        // just to keep in sync
+      }
+    }
+  }
+}
+
+
+Bool YACSPhysicalModel::getUseYACS() const
+{
+  return useYACS_;
+}
+
+
 /** String converter */
 String YACSPhysicalModel::__repr__() const
 {
   OSS oss;
-  oss << PhysicalModelImplementation::__repr__()
+  oss << PythonPhysicalModel::__repr__()
       << " evaluation=" << evaluation_;
   return oss;
 }
@@ -355,21 +305,28 @@ String YACSPhysicalModel::__repr__() const
 /* Method save() stores the object through the StorageManager */
 void YACSPhysicalModel::save(Advocate & adv) const
 {
-  PhysicalModelImplementation::save(adv);
+  PythonPhysicalModel::save(adv);
   adv.saveAttribute("evaluation_", evaluation_);
+  adv.saveAttribute("useYACS_", useYACS_);
 }
 
 
 /* Method load() reloads the object from the StorageManager */
 void YACSPhysicalModel::load(Advocate & adv)
 {
-  PhysicalModelImplementation::load(adv);
+  PythonPhysicalModel::load(adv);
   adv.loadAttribute("evaluation_", evaluation_);
+  if (adv.hasAttribute("useYACS_"))
+    adv.loadAttribute("useYACS_", useYACS_);
+  else
+    useYACS_ = true;
 }
 
 
-void YACSPhysicalModel::acceptLaunchParameters(LaunchParametersVisitor* visitor)
+bool YACSPhysicalModel::canBeDetached() const
 {
-  visitor->visitYACS(this);
+  return useYACS_;
 }
+
+
 }
