@@ -108,7 +108,7 @@ void FileTools::ExportData(const OT::Sample& sample, QWidget * parent)
   layout->addWidget(boxPrec, row, 1);
 
   // Disable comma as numSep if already set as colSep
-  QStandardItemModel *model = qobject_cast<QStandardItemModel *>(boxNumSep->model());
+  const QStandardItemModel *model = qobject_cast<QStandardItemModel *>(boxNumSep->model());
   Q_ASSERT(model != nullptr);
 
   QStandardItem *commaItem = model->item(1);
@@ -140,7 +140,7 @@ void FileTools::ExportData(const OT::Sample& sample, QWidget * parent)
                              (OT::UnsignedInteger)boxPrec->value(),
                              "defaultfloat");
     }
-    catch (std::exception & ex)
+    catch (const std::exception & ex)
     {
       QMessageBox::warning(QApplication::activeWindow(), tr("Warning"), tr("Impossible to export the data. ") + ex.what());
     }
@@ -165,11 +165,12 @@ void FileTools::ExportData(const QString& text, QWidget * parent)
     QFile file(fileName.toLocal8Bit().data());
     try
     {
-      file.open(QIODevice::WriteOnly);
+      if (!file.open(QIODevice::WriteOnly))
+        throw OT::FileOpenException(HERE) << "Cannot open " << fileName.toStdString() << " for writing";
       QTextStream stream(&file);
       stream << text;
     }
-    catch (std::exception & ex)
+    catch (const std::exception & ex)
     {
       QMessageBox::warning(QApplication::activeWindow(), tr("Warning"), tr("Impossible to export the data. ") + ex.what());
     }
@@ -183,7 +184,7 @@ void FileTools::ExportImage(const QImage& image, QWidget * parent)
   QString fileName = QFileDialog::getSaveFileName(parent,
                      tr("Export image"),
                      GetCurrentDir() + QDir::separator() + tr("image"),
-                     tr("Images (*.bmp *.jpg *.jpeg *.png *.ppm *.xbm *.xpm *.tiff)"));
+                     tr("Images (*.png *.bmp *.jpg *.jpeg *.ppm *.xbm *.xpm *.tiff)"));
 
   if (!fileName.isEmpty())
   {
@@ -211,12 +212,19 @@ void FileTools::ExportImage(const QImage& image, QWidget * parent)
 
 QString FileTools::GetDocumentationDirectoryPath()
 {
-  // case 1: try to use an environment variable
+  // case 1: try to use the environment variable
   QString userManualDir = std::getenv("PERSALYS_HTML_PATH");
-  if (!userManualDir.isEmpty() && QDir(userManualDir).exists())
-    return userManualDir;
+  if (!userManualDir.isEmpty())
+  {
+    if (QDir(userManualDir).exists())
+      return userManualDir;
+    else
+    {
+      LOGWARN(OT::OSS() << "PERSALYS_HTML_PATH is set to a non-existing directory" << userManualDir.toStdString());
+    }
+  }
 
-  // case 2: search the path of the documentation
+  // case 2: on Windows search the path of the application
   const QString appliDirPath(QCoreApplication::applicationDirPath());
   QDir dirPath(appliDirPath);
   dirPath.cdUp();
@@ -231,6 +239,7 @@ QString FileTools::GetDocumentationDirectoryPath()
   if (!userManualDir.isEmpty() && QDir(userManualDir).exists())
     return userManualDir;
 
+  LOGWARN("Documentation directory not found in standard paths");
   return "";
 }
 
@@ -277,7 +286,7 @@ bool FileTools::OpenUrl(const QUrl& url)
       return QDesktopServices::openUrl(QUrl::fromLocalFile(fileName));
     }
   }
-#elif defined(PERSALYS_APPIMAGE) && QT_VERSION >= QT_VERSION_CHECK(5,10,0)
+#elif defined(PERSALYS_APPIMAGE)
   // the browser process fails in the inherited AppImage env
   QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
   env.remove("LD_LIBRARY_PATH");
