@@ -31,6 +31,10 @@
 #include "persalys/FunctionalChaosAnalysis.hxx"
 #include "persalys/KrigingAnalysis.hxx"
 #include "persalys/PythonPhysicalModel.hxx"
+#include "persalys/MorrisAnalysis.hxx"
+#include "persalys/MultiObjectiveOptimizationAnalysis.hxx"
+#include "persalys/SobolAnalysis.hxx"
+#include "persalys/MonteCarloAnalysis.hxx"
 
 #include <openturns/PlatformInfo.hxx>
 
@@ -110,7 +114,7 @@ void PhysicalModelDiagramItem::buildActions()
   PythonPhysicalModel * model = dynamic_cast<PythonPhysicalModel*>(getPhysicalModel().getImplementation().get());
   if (model)
   {
-    propertiesAction_ = new QAction(QIcon(":/images/documentinfo.png"), tr("Properties"), this);
+    propertiesAction_ = new QAction(QIcon(":/images/run-build.png"), tr("Properties"), this);
     propertiesAction_->setStatusTip(tr("Physical model properties"));
     connect(propertiesAction_, SIGNAL(triggered()), this, SLOT(requestOpenProperties()));
     appendAction(propertiesAction_);
@@ -169,17 +173,37 @@ void PhysicalModelDiagramItem::updateDiagramBoxesValidity()
 {
   // emit signals to PhysicalModelDiagramWindow
   // to update diagram (arrow color and button availability)
-  emit inputNumberValidityChanged(physicalModel_.getInputDimension());
-  emit twoInputsValidityChanged(physicalModel_.isValid() && physicalModel_.getInputDimension() > 1);
-  emit outputNumberValidityChanged(physicalModel_.isValid() && physicalModel_.getOutputDimension() > 1 );
-  emit physicalModelValidityChanged(physicalModel_.isValid());
-  emit probabilisticModelValidityChanged(physicalModel_.isValid() && physicalModel_.hasStochasticInputs());
-  emit dependenceValidityChanged(physicalModel_.isValid() && physicalModel_.hasStochasticInputs() && physicalModel_.getCopula().hasIndependentCopula());
-  emit doeNumberValidityChanged(physicalModel_.isValid() && doeCounter_[0] > 0);
-  emit doeEvaluationNumberValidityChanged(physicalModel_.isValid() && doeCounter_[1] > 0);
-  emit limitStateNumberValidityChanged(physicalModel_.isValid() && physicalModel_.hasStochasticInputs() && limitStateCounter_ > 0);
-  emit observationsNumberValidityChanged(physicalModel_.isValid() && physicalModel_.getInputDimension() > 1 && observationsCounter_ > 0);
-  emit metamodelNumberValidityChanged(physicalModel_.isValid() && metamodelCounter_ > 0);
+  String errorMessage;
+  QString qErrorMessage;
+  bool validity;
+  // CanBeLaunched need to be called before emit otherwise errorMessage might be sent before being modified
+  validity = PhysicalModelAnalysis::CanBeLaunched(errorMessage, physicalModel_);
+  emit physicalModelValidityChanged(validity, QString(errorMessage.c_str()));
+  validity = MorrisAnalysis::CanBeLaunched(errorMessage, physicalModel_);
+  emit twoInputsValidityChanged(validity, QString(errorMessage.c_str()));
+  validity = DesignOfExperimentEvaluation::CanBeLaunched(errorMessage, physicalModel_);
+  emit inputNumberValidityChanged(validity, QString(errorMessage.c_str()));
+  validity = MultiObjectiveOptimizationAnalysis::CanBeLaunched(errorMessage, physicalModel_);
+  emit outputNumberValidityChanged(validity, QString(errorMessage.c_str()));
+  validity = SobolAnalysis::CanBeLaunched(errorMessage, physicalModel_);
+  emit dependenceValidityChanged(validity, QString(errorMessage.c_str()));
+  validity = MonteCarloAnalysis::CanBeLaunched(errorMessage, physicalModel_);
+  emit probabilisticModelValidityChanged(validity, QString(errorMessage.c_str()));
+  validity = physicalModel_.isValid() && doeCounter_[0] > 0;
+  qErrorMessage = tr("Create at least one design of experiments and define output variables in the model");
+  emit doeNumberValidityChanged(validity, qErrorMessage);
+  validity = physicalModel_.isValid() && doeCounter_[1] > 0;
+  qErrorMessage = tr("Define at least one design of experiments which contains output values");
+  emit doeEvaluationNumberValidityChanged(validity, qErrorMessage);
+  validity = physicalModel_.isValid() && physicalModel_.hasStochasticInputs() && limitStateCounter_ > 0;
+  qErrorMessage = tr("Define output variables in the model and at least one limit state");
+  emit limitStateNumberValidityChanged(validity, qErrorMessage);
+  validity = physicalModel_.isValid() && physicalModel_.getInputDimension() > 1 && observationsCounter_ > 0;
+  qErrorMessage = tr("Define observations of the model");
+  emit observationsNumberValidityChanged(validity, qErrorMessage);
+  validity = physicalModel_.isValid() && metamodelCounter_ > 0;
+  qErrorMessage = tr("Metamodel must first be created");
+  emit metamodelNumberValidityChanged(validity, qErrorMessage);
 }
 
 
@@ -252,16 +276,10 @@ void PhysicalModelDiagramItem::requestMetaModelCreation()
 
 void PhysicalModelDiagramItem::requestMetaModelExport()
 {
-  Study study(getParentStudyItem()->getStudy());
-  for (UnsignedInteger i = 0; i < study.getAnalyses().getSize(); ++i)
-  {
-    const MetaModelAnalysis * analysis = dynamic_cast<const MetaModelAnalysis*>(study.getAnalyses()[i].getImplementation().get());
-    if (analysis && analysis->hasValidResult())
-    {
-      emit mmExportWizardRequested(getParentStudyItem(), study.getAnalyses()[i], true);
-      return;
-    }
-  }
+  const Study study{getParentStudyItem()->getStudy()};
+  // we can pass any analysis as it is just used by the wizard to get the Study observer
+  // declared in ItemFactory, connected to StudyManager
+  emit mmExportWizardRequested(getParentStudyItem(), study.getAnalyses()[0], true);
 }
 
 void PhysicalModelDiagramItem::requestOpenProperties()
@@ -371,9 +389,9 @@ void PhysicalModelDiagramItem::appendPhysicalModelItem()
 void PhysicalModelDiagramItem::appendProbabilisticModelItem()
 {
   // check
-  if (!physicalModel_.getInputDimension())
+  if(String errorMessage; !DesignOfExperimentEvaluation::CanBeLaunched(errorMessage, physicalModel_))
   {
-    emit showErrorMessageRequested(tr("The physical model must have inputs."));
+    emit showErrorMessageRequested(QString(errorMessage.c_str()));
     return;
   }
   // do nothing if the item already exists
@@ -435,21 +453,21 @@ void PhysicalModelDiagramItem::appendItem(const Analysis& analysis)
     if (newItem->getAnalysis().hasValidResult())
       ++doeCounter_[1];
 
-    emit doeNumberValidityChanged(physicalModel_.isValid() && doeCounter_[0] > 0);
-    emit doeEvaluationNumberValidityChanged(physicalModel_.isValid() && doeCounter_[1] > 0);
+    emit doeNumberValidityChanged(physicalModel_.isValid() && doeCounter_[0] > 0, tr("Create at least one design of experiments and define output variables in the model"));
+    emit doeEvaluationNumberValidityChanged(physicalModel_.isValid() && doeCounter_[1] > 0, tr("Define at least one design of experiments which contains output values"));
 
   }
   else if (analysisName == "FunctionalChaosAnalysis" ||
            analysisName == "KrigingAnalysis" ||
            analysisName == "PolynomialRegressionAnalysis")
   {
-    AnalysisItem * newItem = dynamic_cast<AnalysisItem*>(analysis.getImplementation().get()->getObserver("AnalysisItem"));
+    const auto * newItem = dynamic_cast<AnalysisItem*>(analysis.getImplementation().get()->getObserver("AnalysisItem"));
     // connections
     connect(newItem, SIGNAL(numberMetamodelChanged(int)), this, SLOT(updateMetamodelCounter(int)));
 
     if(newItem->getAnalysis().hasValidResult())
       ++metamodelCounter_;
-    emit metamodelNumberValidityChanged(physicalModel_.isValid() && metamodelCounter_ > 0);
+    emit metamodelNumberValidityChanged(physicalModel_.isValid() && metamodelCounter_ > 0, tr("Metamodel must first be created"));
 
   }
   else
@@ -479,7 +497,7 @@ void PhysicalModelDiagramItem::appendItem(const LimitState& limitState)
 
   // signal for diagram window : update diagram
   ++limitStateCounter_;
-  emit limitStateNumberValidityChanged(physicalModel_.isValid() && physicalModel_.hasStochasticInputs() && limitStateCounter_ > 0);
+  emit limitStateNumberValidityChanged(physicalModel_.isValid() && physicalModel_.hasStochasticInputs() && limitStateCounter_ > 0, tr("Define output variables in the model and at least one limit state"));
 }
 
 
@@ -498,7 +516,7 @@ void PhysicalModelDiagramItem::appendItem(const DesignOfExperiment &designOfExp)
 
   // signal for diagram window : update diagram
   ++observationsCounter_;
-  emit observationsNumberValidityChanged(physicalModel_.isValid() && observationsCounter_ > 0);
+  emit observationsNumberValidityChanged(physicalModel_.isValid() && observationsCounter_ > 0, tr("Define observations of the model"));
 }
 
 
@@ -506,7 +524,7 @@ void PhysicalModelDiagramItem::requestLimitStateRemoval()
 {
   // signal for diagram window : update diagram
   --limitStateCounter_;
-  emit limitStateNumberValidityChanged(physicalModel_.isValid() && physicalModel_.hasStochasticInputs() && limitStateCounter_ > 0);
+  emit limitStateNumberValidityChanged(physicalModel_.isValid() && physicalModel_.hasStochasticInputs() && limitStateCounter_ > 0, tr("Define output variables in the model and at least one limit state"));
 }
 
 
@@ -514,7 +532,7 @@ void PhysicalModelDiagramItem::requestObservationsRemoval()
 {
   // signal for diagram window : update diagram
   --observationsCounter_;
-  emit observationsNumberValidityChanged(physicalModel_.isValid() && observationsCounter_ > 0);
+  emit observationsNumberValidityChanged(physicalModel_.isValid() && observationsCounter_ > 0, tr("Define observations of the model"));
 }
 
 
@@ -525,7 +543,7 @@ void PhysicalModelDiagramItem::updateDesignEvaluationCounter(bool increment)
     ++doeCounter_[1];
   else
     --doeCounter_[1];
-  emit doeEvaluationNumberValidityChanged(physicalModel_.isValid() && doeCounter_[1] > 0);
+  emit doeEvaluationNumberValidityChanged(physicalModel_.isValid() && doeCounter_[1] > 0, tr("Define at least one design of experiments which contains output values"));
 }
 
 void PhysicalModelDiagramItem::updateMetamodelCounter(int increment)
@@ -533,7 +551,7 @@ void PhysicalModelDiagramItem::updateMetamodelCounter(int increment)
   metamodelCounter_ += increment;
   if (metamodelCounter_ < 0)
     metamodelCounter_ = 0;
-  emit metamodelNumberValidityChanged(physicalModel_.isValid() && metamodelCounter_ > 0);
+  emit metamodelNumberValidityChanged(physicalModel_.isValid() && metamodelCounter_ > 0, tr("Metamodel must first be created"));
 }
 
 void PhysicalModelDiagramItem::requestDesignOfExperimentRemoval(bool isValid)
@@ -543,7 +561,7 @@ void PhysicalModelDiagramItem::requestDesignOfExperimentRemoval(bool isValid)
   if (isValid)
     --doeCounter_[1];
 
-  emit doeNumberValidityChanged(physicalModel_.isValid() && doeCounter_[0] > 0);
-  emit doeEvaluationNumberValidityChanged(physicalModel_.isValid() && doeCounter_[1] > 0);
+  emit doeNumberValidityChanged(physicalModel_.isValid() && doeCounter_[0] > 0, tr("Create at least one design of experiments and define output variables in the model"));
+  emit doeEvaluationNumberValidityChanged(physicalModel_.isValid() && doeCounter_[1] > 0, tr("Define at least one design of experiments which contains output values"));
 }
 }
