@@ -75,27 +75,23 @@ void StudyItem::buildActions()
   newPythonModel_ = new QAction(tr("Python model"), this);
   connect(newPythonModel_, &QAction::triggered, [ = ]()
   {
+#ifdef PERSALYS_HAVE_YACS
+    study_.add(new YACSPhysicalModel(getModelName(tr("PythonModel_"))));
+#else
     study_.add(new PythonPhysicalModel(getModelName(tr("PythonModel_"))));
+#endif
   });
 
   newCouplingModel_ = new QAction(tr("Coupling model"), this);
-#ifdef PERSALYS_HAVE_YACS
-  newYACSModel_ = new QAction(tr("Python model on cluster"), this);
-  connect(newYACSModel_, &QAction::triggered, [ = ]()
+  connect(newCouplingModel_, &QAction::triggered, [ = ]()
   {
-    study_.add(new YACSPhysicalModel(getModelName(tr("YACSModel_"))));
+#ifdef PERSALYS_HAVE_YACS
+    study_.add(new YACSCouplingPhysicalModel(getModelName(tr("CouplingModel_"))));
+#else
+    study_.add(new CouplingPhysicalModel(getModelName(tr("CouplingModel_"))));
+#endif
   });
 
-  connect(newCouplingModel_, &QAction::triggered, [ = ]()
-  {
-    study_.add(new YACSCouplingPhysicalModel(getModelName(tr("CouplingModel_"))));
-  });
-#else
-  connect(newCouplingModel_, &QAction::triggered, [ = ]()
-  {
-    study_.add(new CouplingPhysicalModel(getModelName(tr("CouplingModel_"))));
-  });
-#endif
 #ifdef PERSALYS_HAVE_OTFMI
   newFMIModel_ = new QAction(tr("FMI model"), this);
   connect(newFMIModel_, &QAction::triggered, [ = ]()
@@ -117,16 +113,16 @@ void StudyItem::buildActions()
     study_.add(new PythonFieldModel(getModelName(tr("PythonModel_"))));
   });
 
-  newDataModel_ = new QAction(tr("Data model"), this);
+  newDataModel_ = new QAction(tr("Data set"), this);
   connect(newDataModel_, &QAction::triggered, [ = ]()
   {
-    study_.add(new DataModel(study_.getAvailableDataModelName(tr("DataModel_").toStdString())));
+    study_.add(new DataModel(study_.getAvailableDataModelName(tr("DataSet_").toStdString())));
   });
 
-  newDataFieldModel_ = new QAction(tr("Data Field model"), this);
+  newDataFieldModel_ = new QAction(tr("Field data set"), this);
   connect(newDataFieldModel_, &QAction::triggered, [ = ]()
   {
-    study_.add(DataFieldModel(study_.getAvailableDataFieldModelName(tr("DataFieldModel_").toStdString())));
+    study_.add(DataFieldModel(study_.getAvailableDataFieldModelName(tr("FieldDataSet_").toStdString())));
   });
 
   // export action
@@ -149,9 +145,6 @@ void StudyItem::buildActions()
   appendSeparator(tr("Model"));
   appendAction(newSymbolicModel_);
   appendAction(newPythonModel_);
-#ifdef PERSALYS_HAVE_YACS
-  appendAction(newYACSModel_);
-#endif
 #ifdef PERSALYS_HAVE_OTFMI
   appendAction(newFMIModel_);
 #endif
@@ -323,6 +316,42 @@ void StudyItem::appendItem(const DesignOfExperiment &dataModel)
   }
 }
 
+String StudyItem::appendMetaModelItem(PhysicalModel metaModel)
+{
+  const String symbolicName("Symbolic_"+metaModel.getName());
+  if (!study_.hasPhysicalModelNamed(symbolicName))
+  {
+    metaModel.setName(symbolicName);
+    study_.add(metaModel);
+    return symbolicName;
+  }
+  else
+  {
+    String newName(study_.getAvailablePhysicalModelName(symbolicName+"_"));
+    metaModel.setName(newName);
+    study_.add(metaModel);
+    return newName;
+  }
+}
+
+String StudyItem::appendPythonMetaModelItem(PhysicalModel metaModel)
+{
+  String originalName(metaModel.getName());
+  if (!study_.hasPhysicalModelNamed("Python_"+originalName))
+  {
+    metaModel.setName("Python_"+originalName);
+    study_.add(metaModel);
+    return "Python_"+originalName;
+  }
+  else
+  {
+    String newName(study_.getAvailablePhysicalModelName("Python_"+originalName+"_"));
+    metaModel.setName(newName);
+    study_.add(metaModel);
+    return newName;
+  }
+}
+
 
 void StudyItem::appendItem(const PhysicalModel &physicalModel)
 {
@@ -377,15 +406,6 @@ void StudyItem::appendItem(const Analysis &analysis)
     qDebug() << "In StudyItem::appendItem: No item added for the analysis named " << analysis.getName().data() << ". No found observer\n";
 }
 
-
-void StudyItem::appendMetaModelItem(PhysicalModel metaModel)
-{
-  const String availableName = metaModel.getName();
-  metaModel.setName(availableName);
-  study_.add(metaModel);
-}
-
-
 QVariant StudyItem::data(int role) const
 {
   // set icon
