@@ -75,8 +75,9 @@ void TranslationManager::InitializeCopulasNames()
   CopulasNames_.insert("FarlieGumbelMorgenstern", "Farlie-Gumbel-\nMorgenstern");
   CopulasNames_.insert("Frank", "Frank");
   CopulasNames_.insert("Gumbel", "Gumbel");
-  CopulasNames_.insert("Independent", "Independent");
+  CopulasNames_.insert("Independent", tr("Independent"));
   CopulasNames_.insert("Normal", tr("Normal"));
+  CopulasNames_.insert("Student", tr("Student"));
 }
 
 
@@ -124,7 +125,7 @@ void TranslationManager::InitializeParametersNames()
   ParametersNames_.insert("Analytical validation", tr("Analytical validation"));
   ParametersNames_.insert("Test sample validation", tr("Test sample validation"));
   ParametersNames_.insert("KFold validation", tr("KFold validation"));
-  ParametersNames_.insert("Kriging", tr("Kriging"));
+  ParametersNames_.insert("Gaussian Process", tr("Gaussian Process"));
   ParametersNames_.insert("yes", tr("yes"));
   ParametersNames_.insert("no", tr("no"));
   ParametersNames_.insert("Constant", tr("Constant"));
@@ -223,6 +224,13 @@ void TranslationManager::InitializeErrorMessages()
   ErrorMessages_.insert("The physical model must have stochastic inputs.", tr("The physical model must have stochastic inputs."));
   ErrorMessages_.insert("The model must have an independent copula to compute a sensitivity analysis but here inputs are dependent.", tr("The model must have an independent copula to compute a sensitivity analysis but here inputs are dependent."));
   ErrorMessages_.insert("The limit state is not valid.", tr("The limit state is not valid."));
+  //GridMeshModel::setParameters
+  ErrorMessages_.insert("The lower bounds must be less than the upper bounds", tr("The lower bounds must be less than the upper bounds"));
+  ErrorMessages_.insert("The mesh must contain at least two node", tr("The mesh must contain at least two nodes"));
+  // Tools
+  ErrorMessages_.insert("The file does not contain a sample and/or the file encoding is not valid (use utf-8)", tr("The file does not contain a sample and/or the file encoding is not valid (use utf-8)"));
+  ErrorMessages_.insert("Unknown data order", tr("Unknown data order"));
+  ErrorMessages_.insert("The file contains more than one row or column. It must only contain the mesh.", tr("The file contains more than one row or column. It must only contain the mesh."));
 }
 
 
