@@ -140,7 +140,7 @@ CalibrationResultWindow::CalibrationResultWindow(AnalysisItem *item, QWidget *pa
   thetaGroupBoxLayout->addWidget(thetaTableView);
   tabLayout->addWidget(thetaGroupBox, 0, Qt::AlignTop);
 
-  QString labelText = tr("Observation error standard deviation:\n");
+  QString labelText = tr("Observation error standard deviation:")+"\n";
   labelText += QString("σ = ")
     + QString::number(result_.getCalibrationResult().getObservationsError().getStandardDeviation()[0]);
 
