@@ -51,6 +51,7 @@
 #include <QTextStream>
 #include <QSplitter>
 #include <QSettings>
+#include <QPointer>
 
 using namespace OT;
 
@@ -79,8 +80,47 @@ CouplingModelWindow::CouplingModelWindow(PhysicalModelItem *item, QWidget *paren
   QGridLayout * tabLayout = new QGridLayout(tab);
   mainTabWidget->addTab(tab, tr("Definition"));
 
+  auto * sshLayout = new QHBoxLayout;
+  tabLayout->addLayout(sshLayout, 0, 0, 1, 2);
+
+  auto * runViaSshCheckBox = new QCheckBox(tr("Run via ssh"));
+  sshLayout->addWidget(runViaSshCheckBox);
+
+  auto * hostnameLabel = new QLabel(tr("Hostname"));
+  auto * hostnameLineEdit = new QLineEdit(QString::fromStdString(model_->getSSHHostname()));
+  hostnameLineEdit->setValidator(new QRegularExpressionValidator(QRegularExpression("([^\r\n]*)"), hostnameLineEdit));
+  sshLayout->addWidget(hostnameLabel);
+  sshLayout->addWidget(hostnameLineEdit);
+  sshLayout->addStretch();
+
+  const bool runViaSsh = !model_->getSSHHostname().empty();
+  runViaSshCheckBox->setChecked(runViaSsh);
+  hostnameLabel->setVisible(runViaSsh);
+  hostnameLineEdit->setVisible(runViaSsh);
+
+  connect(runViaSshCheckBox, &QCheckBox::toggled, [this, hostnameLabel, hostnameLineEdit](bool toggled)
+  {
+    hostnameLabel->setVisible(toggled);
+    hostnameLineEdit->setVisible(toggled);
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    if (!toggled)
+      model_->setSSHHostname("");
+    else
+      model_->setSSHHostname(hostnameLineEdit->text().toUtf8().constData());
+    model_->blockNotification();
+  });
+
+  connect(hostnameLineEdit, &QLineEdit::editingFinished, [this, runViaSshCheckBox, hostnameLineEdit]()
+  {
+    if (!runViaSshCheckBox->isChecked())
+      return;
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSSHHostname(hostnameLineEdit->text().toUtf8().constData());
+    model_->blockNotification();
+  });
+
   stepTabWidget_ = new DynamicTabWidget;
-  tabLayout->addWidget(stepTabWidget_, 0, 0);
+  tabLayout->addWidget(stepTabWidget_, 1, 0, 1, 2);
   connect(stepTabWidget_, &DynamicTabWidget::newTabRequested, [ = ]()
   {
     CouplingStepCollection csColl(model_->getSteps());
@@ -89,7 +129,7 @@ CouplingModelWindow::CouplingModelWindow(PhysicalModelItem *item, QWidget *paren
     model_->setSteps(csColl);
     model_->blockNotification();
     CouplingStepWidget * csWidget = new CouplingStepWidget(item, model_, csColl.getSize() - 1);
-    stepTabWidget_->addTab(csWidget, tr("Command") + " " + QString::number(stepTabWidget_->count()));
+    stepTabWidget_->addTab(csWidget, tr("Step") + " " + QString::number(stepTabWidget_->count()));
     connect(csWidget, &CouplingStepWidget::updateStepRequested, [ = ]()
     {
       updateStepTabWidget(item);
@@ -110,7 +150,7 @@ CouplingModelWindow::CouplingModelWindow(PhysicalModelItem *item, QWidget *paren
 
   CollapsibleGroupBox * advancedGroupBox = new CollapsibleGroupBox(tr("Advanced parameters"));
   QGridLayout * advancedGroupBoxLayout = new QGridLayout(advancedGroupBox);
-  tabLayout->addWidget(advancedGroupBox, 1, 0);
+  tabLayout->addWidget(advancedGroupBox, 2, 0, 1, 2);
 
   advancedGroupBoxLayout->addWidget(new QLabel(tr("Cache input file")), 0, 0);
   advancedGroupBoxLayout->addWidget(new QLabel(tr("Cache output file")), 1, 0);
@@ -260,7 +300,7 @@ void CouplingModelWindow::updateStepTabWidget(PhysicalModelItem *item)
   for (UnsignedInteger i = 0; i < model_->getSteps().getSize(); ++i)
   {
     CouplingStepWidget * csWidget = new CouplingStepWidget(item, model_, i);
-    stepTabWidget_->addTab(csWidget, tr("Command") + " " + QString::number(i + 1));
+    stepTabWidget_->addTab(csWidget, tr("Step") + " " + QString::number(i + 1));
   }
 
   if (stepTabWidget_->count() < 2)
@@ -820,8 +860,13 @@ void OutTableModel::removeLine()
 
 // Widget for Coupling Input file
 
-CouplingInputFileWidget::CouplingInputFileWidget(PhysicalModelItem *item, CouplingPhysicalModel *model, const int indStep, const int indFile, QWidget *parent)
+CouplingInputFileWidget::CouplingInputFileWidget(const PhysicalModelItem *item, 
+  CouplingPhysicalModel *model, 
+  const int indStep, 
+  const int indFile, 
+  QWidget *parent)
   : QWidget(parent)
+  , model_(model)
   , indStep_(indStep)
   , indFile_(indFile)
 {
@@ -830,14 +875,15 @@ CouplingInputFileWidget::CouplingInputFileWidget(PhysicalModelItem *item, Coupli
   int row = -1;
 
   // template file path
-  QLabel * templateFileLabel = new QLabel(tr("Template file"));
+  QLabel * templateFileLabel = new QLabel(tr("Template file (absolute)"));
   layout->addWidget(templateFileLabel, ++row, 0);
 
   FilePathWidget * templateFileLineEdit = new FilePathWidget(model->getSteps()[indStep].getInputFiles()[indFile].getPath().c_str());
+  templateFileLineEdit->checkFileExists();
   layout->addWidget(templateFileLineEdit, row, 1);
 
   // input model file path
-  QLabel * fileLabel = new QLabel(tr("Configured file"));
+  QLabel * fileLabel = new QLabel(tr("Configured file (relative)"));
   layout->addWidget(fileLabel, ++row, 0);
 
   QLineEdit * fileLineEdit = new QLineEdit;
@@ -857,51 +903,58 @@ CouplingInputFileWidget::CouplingInputFileWidget(PhysicalModelItem *item, Coupli
 
   connect(addRemoveWidget, &AddRemoveWidget::addRequested, inTableModel, &InTableModel::addLine);
   connect(addRemoveWidget, &AddRemoveWidget::removeRequested, inTableModel, &InTableModel::removeLine);
-  connect(inTableModel, SIGNAL(dataChanged(QModelIndex, QModelIndex)), item, SIGNAL(inputListDifferentiationChanged()));
+  connect(inTableModel, &InTableModel::dataChanged, item, &PhysicalModelItem::inputListDifferentiationChanged);
   connect(item, &PhysicalModelItem::outputChanged, inTableModel, &InTableModel::updateData);
 
-  connect(inTableModel, SIGNAL(dataChanged(QModelIndex, QModelIndex)), this, SIGNAL(variableListChanged()));
+  connect(inTableModel, &InTableModel::dataChanged, this, &CouplingInputFileWidget::variableListChanged); // indirectly connected to gradientTableModel->updataData at line 213
 
   inTableView->setDisabled(templateFileLineEdit->text().isEmpty() || fileLineEdit->text().isEmpty());
   addRemoveWidget->setDisabled(templateFileLineEdit->text().isEmpty() || fileLineEdit->text().isEmpty());
 
-  connect(templateFileLineEdit, &FilePathWidget::pathChanged, [ = ](const QString & text)
+  connect(templateFileLineEdit, &FilePathWidget::pathChanged, 
+    [this, templateFileLineEdit, inTableView, fileLineEdit, addRemoveWidget] (const QString & text)
   {
+    templateFileLineEdit->checkFileExists();
+
     inTableView->setDisabled(text.isEmpty() || fileLineEdit->text().isEmpty());
     addRemoveWidget->setDisabled(text.isEmpty() || fileLineEdit->text().isEmpty());
+
     // update model
-    CouplingStepCollection csColl(model->getSteps());
-    CouplingStep cs(csColl[indStep]);
+    CouplingStepCollection csColl(model_->getSteps());
+    CouplingStep cs(csColl[indStep_]);
     CouplingInputFileCollection inColl(cs.getInputFiles());
 
-    inColl[indFile].setPath(text.toUtf8().constData());
+    inColl[indFile_].setPath(text.toUtf8().constData());
     cs.setInputFiles(inColl);
-    csColl[indStep] = cs;
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
+    csColl[indStep_] = cs;
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
 
     // refresh configured path in case it was uninitialized
-    fileLineEdit->setText(inColl[indFile].getConfiguredPath().c_str());
+    fileLineEdit->setText(inColl[indFile_].getConfiguredPath().c_str());
   });
-  connect(fileLineEdit, &QLineEdit::editingFinished, [ = ]()
+
+  connect(fileLineEdit, &QLineEdit::editingFinished, 
+    [this, fileLineEdit, inTableView, templateFileLineEdit, addRemoveWidget]()
   {
     if (QFileInfo(fileLineEdit->text()).isAbsolute())
       fileLineEdit->setText(QFileInfo(fileLineEdit->text()).fileName());
 
     inTableView->setDisabled(templateFileLineEdit->text().isEmpty() || fileLineEdit->text().isEmpty());
     addRemoveWidget->setDisabled(templateFileLineEdit->text().isEmpty() || fileLineEdit->text().isEmpty());
+    
     // update model
-    CouplingStepCollection csColl(model->getSteps());
-    CouplingStep cs(csColl[indStep]);
+    CouplingStepCollection csColl(model_->getSteps());
+    CouplingStep cs(csColl[indStep_]);
     CouplingInputFileCollection inColl(cs.getInputFiles());
 
-    inColl[indFile].setConfiguredPath(fileLineEdit->text().toUtf8().constData());
+    inColl[indFile_].setConfiguredPath(fileLineEdit->text().toUtf8().constData());
     cs.setInputFiles(inColl);
-    csColl[indStep] = cs;
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
+    csColl[indStep_] = cs;
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
   });
 
   QPushButton * checkTemplateButton = new QPushButton(tr("Check template file"));
@@ -910,63 +963,66 @@ CouplingInputFileWidget::CouplingInputFileWidget(PhysicalModelItem *item, Coupli
   CollapsibleGroupBox * inputLayoutBox = new CollapsibleGroupBox(tr("Template/input comparison"));
   layout->addWidget(inputLayoutBox, ++row, 0, 1, 3);
   QHBoxLayout * inputLayout = new QHBoxLayout(inputLayoutBox);
-  QLabel * temTextLabel = new QLabel("");
-  QLabel * simTextLabel = new QLabel("");
-  temTextLabel->setTextFormat(Qt::AutoText);
-  simTextLabel->setTextFormat(Qt::AutoText);
-  inputLayout->addWidget(temTextLabel, 0, Qt::AlignTop);
-  inputLayout->addWidget(simTextLabel, 1, Qt::AlignTop);
+  temTextLabel_ = new QLabel("");
+  simTextLabel_ = new QLabel("");
+  temTextLabel_->setTextFormat(Qt::AutoText);
+  simTextLabel_->setTextFormat(Qt::AutoText);
+  inputLayout->addWidget(temTextLabel_, 0, Qt::AlignTop);
+  inputLayout->addWidget(simTextLabel_, 1, Qt::AlignTop);
   inputLayout->setStretch(0, 1);
   inputLayout->setStretch(1, 1);
 
-  connect(checkTemplateButton, &QPushButton::clicked, [ = ]()
-  {
-    temTextLabel->clear();
-    temTextLabel->setStyleSheet("");
-    simTextLabel->clear();
-    CouplingStepCollection csColl(model->getSteps());
-    CouplingStep cs(csColl[indStep]);
-    CouplingInputFileCollection inColl(cs.getInputFiles());
-
-    QFileInfo temFile(inColl[indFile].getPath().c_str());
-    QFileInfo simFile(QDir::temp().absolutePath() + "/" + inColl[indFile].getConfiguredPath().c_str());
-
-    VariableCollection varColl;
-    const InputCollection inVar = model->getInputs();
-    const OutputCollection outVar = model->getOutputs();
-
-    for(UnsignedInteger i = 0; i < inVar.getSize(); ++i)
-      varColl.add(Variable(inVar[i].getName(), inVar[i].getValue(), inVar[i].getDescription()));
-    for(UnsignedInteger i = 0; i < outVar.getSize(); ++i)
-      varColl.add(Variable(outVar[i].getName(), outVar[i].getValue(), outVar[i].getDescription()));
-
-    if(!temFile.exists())
-      temTextLabel->setText(tr("Template file not found") + "\n");
-    else if(!temFile.isReadable())
-      temTextLabel->setText(tr("Template file not readable") + "\n");
-    else
-    {
-      try
-      {
-        inColl[indFile].simulateInput(varColl);
-      }
-      catch (std::exception & ex)
-      {
-        temTextLabel->setStyleSheet("QLabel {color: red;} QLabel::disabled{color: darkgray;}");
-        temTextLabel->setText(ex.what());
-        return;
-      }
-      QString temText(readFile(temFile));
-      QString simText(readFile(simFile));
-      compareFiles(temText, simText);
-
-      temTextLabel->setText(temText);
-      simTextLabel->setText(simText);
-    }
-  });
+  connect(checkTemplateButton, &QPushButton::clicked, this, &CouplingInputFileWidget::checkTemplate);
 }
 
-void CouplingInputFileWidget::compareFiles(QString & s1, QString & s2) const
+void CouplingInputFileWidget::checkTemplate()
+{
+  temTextLabel_->clear();
+  temTextLabel_->setStyleSheet("");
+  simTextLabel_->clear();
+
+  CouplingStepCollection csColl(model_->getSteps());
+  CouplingStep cs(csColl[indStep_]);
+  CouplingInputFileCollection inColl(cs.getInputFiles());
+
+  QFileInfo temFile(inColl[indFile_].getPath().c_str());
+  QFileInfo simFile(QDir::temp().absolutePath() + "/" + inColl[indFile_].getConfiguredPath().c_str());
+
+  VariableCollection varColl;
+  const InputCollection inVar = model_->getInputs();
+  const OutputCollection outVar = model_->getOutputs();
+
+  for(UnsignedInteger i = 0; i < inVar.getSize(); ++i)
+    varColl.add(Variable(inVar[i].getName(), inVar[i].getValue(), inVar[i].getDescription()));
+  for(UnsignedInteger i = 0; i < outVar.getSize(); ++i)
+    varColl.add(Variable(outVar[i].getName(), outVar[i].getValue(), outVar[i].getDescription()));
+
+  if(!temFile.exists())
+    temTextLabel_->setText(tr("Template file not found") + "\n");
+  else if(!temFile.isReadable())
+    temTextLabel_->setText(tr("Template file not readable") + "\n");
+  else
+  {
+    try
+    {
+      inColl[indFile_].simulateInput(varColl);
+    }
+    catch (const std::exception & ex)
+    {
+      temTextLabel_->setStyleSheet("QLabel {color: red;} QLabel::disabled{color: darkgray;}");
+      temTextLabel_->setText(ex.what());
+      return;
+    }
+    QString temText(readFile(temFile));
+    QString simText(readFile(simFile));
+    compareFiles(temText, simText);
+
+    temTextLabel_->setText(temText);
+    simTextLabel_->setText(simText);
+  }
+}
+
+void CouplingInputFileWidget::compareFiles(const QString & s1, QString & s2) const
 {
   QList<QString> l1 = s1.split("\n");
   QList<QString> l2 = s2.split("\n");
@@ -976,7 +1032,7 @@ void CouplingInputFileWidget::compareFiles(QString & s1, QString & s2) const
   {
     if(l1[i] != l2[i])
     {
-      l2[i].replace(l2[i], QString("<font color=\"red\">" + l2[i].toHtmlEscaped() + "</font>"));
+      l2[i].replace(l2[i], QString("<font color=\"blue\">" + l2[i].toHtmlEscaped() + "</font>"));
       s2.append(l2[i] + "<br>");
     }
     else
@@ -986,7 +1042,7 @@ void CouplingInputFileWidget::compareFiles(QString & s1, QString & s2) const
   }
 }
 
-QString CouplingInputFileWidget::readFile(QFileInfo & fname) const
+QString CouplingInputFileWidget::readFile(const QFileInfo & fname) const
 {
   QFile file(fname.filePath());
   if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
@@ -1024,13 +1080,16 @@ CouplingResourceFileWidget::CouplingResourceFileWidget(CouplingPhysicalModel *mo
   resGroupBoxLayout->addWidget(addRemoveWidget, 1, 0, Qt::AlignRight);
 
   updateTable();
-  connect(tableWidget_, &QTableWidget::itemChanged, [ = ](QTableWidgetItem * item)
+  connect(tableWidget_, &QTableWidget::itemChanged, [=](QTableWidgetItem * item)
   {
     CouplingStepCollection csColl(model_->getSteps());
     CouplingStep cs(csColl[indStep_]);
     CouplingResourceFileCollection inColl(cs.getResourceFiles());
 
-    inColl[item->data(Qt::UserRole).toInt()].setPath(item->data(Qt::DisplayRole).toString().toUtf8().constData());
+    const QString fileName = item->data(Qt::DisplayRole).toString();
+    inColl[item->data(Qt::UserRole).toInt()].setPath(fileName.toUtf8().constData());
+    item->setData(Qt::BackgroundRole, QColor(QFile(fileName).exists() ? "white" : "orange"));
+
     cs.setResourceFiles(inColl);
     csColl[indStep_] = cs;
     model_->blockNotification("PhysicalModelDefinitionItem");
@@ -1038,7 +1097,7 @@ CouplingResourceFileWidget::CouplingResourceFileWidget(CouplingPhysicalModel *mo
     model_->blockNotification();
   });
 
-  connect(addRemoveWidget, &AddRemoveWidget::addRequested, [ = ]()
+  connect(addRemoveWidget, &AddRemoveWidget::addRequested, [=]()
   {
     CouplingStepCollection csColl(model->getSteps());
     CouplingStep cs(csColl[indStep_]);
@@ -1115,8 +1174,11 @@ void CouplingResourceFileWidget::updateTable()
         ++row;
         tableWidget_->setRowCount(row + 1);
 
-        QTableWidgetItem * newItem = new QTableWidgetItem(cs.getResourceFiles()[i].getPath().c_str());
+        const QString fileName = QString::fromStdString(cs.getResourceFiles()[i].getPath());
+        QTableWidgetItem * newItem = new QTableWidgetItem(fileName);
         newItem->setData(Qt::UserRole, int(i));
+        newItem->setData(Qt::BackgroundRole, QColor(QFile(fileName).exists() ? "white" : "orange"));
+
         tableWidget_->setItem(row, 0, newItem);
 
         QToolButton * tb = new QToolButton;
@@ -1189,7 +1251,7 @@ CouplingOutputFileWidget::CouplingOutputFileWidget(PhysicalModelItem *item, Coup
   int row = -1;
 
   // output file path
-  QLabel * outFileLabel = new QLabel(tr("Output file"));
+  QLabel * outFileLabel = new QLabel(tr("Output file (relative)"));
   layout->addWidget(outFileLabel, ++row, 0);
 
   QLineEdit * outFileLineEdit = new QLineEdit;
@@ -1260,267 +1322,275 @@ CouplingOutputFileWidget::CouplingOutputFileWidget(PhysicalModelItem *item, Coup
 
 CouplingStepWidget::CouplingStepWidget(PhysicalModelItem *item, CouplingPhysicalModel *model, const int indStep, QWidget *parent)
   : QWidget(parent)
+  , item_(item)
   , model_(model)
   , indStep_(indStep)
 {
-  QGridLayout * widgetLayout = new QGridLayout(this);
+  auto * widgetLayout = new QGridLayout(this);
 
-  // step definition
-  QScrollArea * scrollArea = new QScrollArea;
+  auto * scrollArea = new QScrollArea;
   scrollArea->setWidgetResizable(true);
   widgetLayout->addWidget(scrollArea);
 
-  QWidget * mainWidget = new QWidget;
-  QVBoxLayout * mainLayout = new QVBoxLayout(mainWidget);
+  auto * mainWidget = new QWidget;
+  auto * mainLayout = new QVBoxLayout(mainWidget);
   scrollArea->setWidget(mainWidget);
 
-  QTabWidget * stepTabWidget = new QTabWidget;
+  auto * stepTabWidget = new QTabWidget;
   mainLayout->addWidget(stepTabWidget);
 
-  // command definition
-  QWidget * tab = new QWidget;
-  stepTabWidget->addTab(tab, tr("Command"));
-
-  QGridLayout * comTabLayout = new QGridLayout(tab);
-  QLabel * commandLabel = new QLabel(tr("Command"));
-  comTabLayout->addWidget(commandLabel, 0, 0);
-
-  QLineEdit * commandLineEdit = new QLineEdit(QString::fromUtf8(model->getSteps()[indStep].getCommand().c_str()));
-  commandLineEdit->setValidator(new QRegularExpressionValidator(QRegularExpression("([^\r\n]*)")));
-  comTabLayout->addWidget(commandLineEdit, 0, 1);
-  if(!commandLineEdit->hasAcceptableInput())
-    commandLineEdit->setStyleSheet("color: red");
-  connect(commandLineEdit, &QLineEdit::editingFinished, [ = ]()
-  {
-    commandLineEdit->setStyleSheet("");
-    CouplingStepCollection csColl(model->getSteps());
-    CouplingStep cs(csColl[indStep]);
-
-    cs.setCommand(commandLineEdit->text().toUtf8().constData());
-    csColl[indStep] = cs;
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
-  });
-
-  QCheckBox * checkBox = new QCheckBox(tr("Shell command"));
-  comTabLayout->addWidget(checkBox, 1, 0, 1, 2);
-  checkBox->setChecked(model->getSteps()[indStep].getIsShell());
-  connect(checkBox, &QCheckBox::toggled, [ = ](bool toggled)
-  {
-    CouplingStepCollection csColl(model->getSteps());
-    CouplingStep cs(csColl[indStep]);
-
-    cs.setIsShell(toggled);
-    csColl[indStep] = cs;
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
-  });
-
-  QPushButton * ansysTb = new QPushButton(QIcon(":/images/workbench32X32.png"),
-                                          tr("Run ansys wizard"), this);
-  comTabLayout->addWidget(ansysTb, 2, 0);
-
-  CollapsibleGroupBox * advGroupBox = new CollapsibleGroupBox(tr("Advanced"));
-  QGridLayout * advGroupBoxLayout = new QGridLayout(advGroupBox);
-  comTabLayout->addWidget(advGroupBox, 3, 0, 1, 2);
-
-  advGroupBoxLayout->addWidget(new QLabel(tr("Timeout (s)")), 0, 0);
-  DoubleSpinBox * timeOutVal = new DoubleSpinBox();
-  timeOutVal->setMinimum(-1);
-  timeOutVal->setValue(model_->getSteps()[indStep].getTimeOut());
-  advGroupBoxLayout->addWidget(timeOutVal, 0, 1);
-  connect(timeOutVal, QOverload<double>::of(&DoubleSpinBox::valueChanged), [ = ](const double & val)
-  {
-    CouplingStepCollection csColl(model->getSteps());
-    csColl[indStep].setTimeOut(val);
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
-  });
-
-  advGroupBoxLayout->addWidget(new QLabel(tr("I/O Encoding")), 1, 0);
-  QComboBox * encodingBox = new QComboBox();
-  encodingBox->insertItem(0, QString::fromStdString("utf-8"));
-  encodingBox->insertItem(1, QString::fromStdString("latin-1"));
-  int index = encodingBox->findText(QString::fromStdString(model->getSteps()[indStep].getEncoding()));
-  if ( index != -1 )
-    encodingBox->setCurrentIndex(index);
-  advGroupBoxLayout->addWidget(encodingBox, 1, 1);
-  connect(encodingBox, &QComboBox::currentTextChanged, [ = ](const QString & enc)
-  {
-    CouplingStepCollection csColl(model->getSteps());
-    csColl[indStep].setEncoding(enc.toUtf8().constData());
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
-  });
-
-  // Environment variables table
-  QTableView * envTableView = new QTableView;
-
-  envTableView->horizontalHeader()->setStretchLastSection(true);
-  envTableView->horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
-  advGroupBoxLayout->addWidget(envTableView, 2, 0, 1, 2);
-  AddRemoveWidget * addRemoveWidget = new AddRemoveWidget;
-  advGroupBoxLayout->addWidget(addRemoveWidget, 3, 1, 1, 2, Qt::AlignRight);
-
-  CouplingStep cs(model->getSteps()[indStep]);
-  EnvironmentTableModel * envTableModel = new EnvironmentTableModel(cs, envTableView);
-  envTableView->setModel(envTableModel);
-
-  connect(addRemoveWidget, SIGNAL(addRequested()), envTableModel, SLOT(addLine()));
-  connect(addRemoveWidget, SIGNAL(removeRequested()), envTableModel, SLOT(removeLine()));
-  connect(envTableModel, &EnvironmentTableModel::stepChanged, [ = ] ()
-  {
-    CouplingStepCollection csColl(model->getSteps());
-    csColl[indStep] = envTableModel->getStep();
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
-  });
-
-  advGroupBoxLayout->setColumnStretch(1, 1);
-  advGroupBoxLayout->setRowStretch(3, 1);
-
-  comTabLayout->setColumnStretch(1, 1);
-  comTabLayout->setRowStretch(4, 1);
-
-
-  // input definition
-  tab = new QWidget;
-  stepTabWidget->addTab(tab, tr("Input"));
-
-  QVBoxLayout * inTabLayout = new QVBoxLayout(tab);
-  inTabWidget_ = new DynamicTabWidget;
-  inTabLayout->addWidget(inTabWidget_);
-  connect(inTabWidget_, &DynamicTabWidget::newTabRequested, [ = ]()
-  {
-    CouplingStepCollection csColl(model->getSteps());
-    CouplingStep cs2(csColl[indStep]);
-    CouplingInputFileCollection inColl(cs2.getInputFiles());
-
-    inColl.add(CouplingInputFile());
-    cs2.setInputFiles(inColl);
-    csColl[indStep] = cs2;
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
-    CouplingInputFileWidget * ciFileWidget = new CouplingInputFileWidget(item, model, indStep, inColl.getSize() - 1);
-    inTabWidget_->addTab(ciFileWidget, tr("File"));
-    connect(ciFileWidget, SIGNAL(variableListChanged()), this, SIGNAL(variableListChanged()));
-
-  });
-  connect(inTabWidget_, &DynamicTabWidget::removeTabRequested, [ = ](int index2)
-  {
-    CouplingStepCollection csColl(model->getSteps());
-    CouplingStep cs2(csColl[indStep]);
-    CouplingInputFileCollection inColl(cs2.getInputFiles());
-
-    inColl.erase(inColl.begin() + index2);
-    cs2.setInputFiles(inColl);
-    csColl[indStep] = cs2;
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
-    updateInputFileWidgets(item);
-  });
-
-  // resource definition
-  tab = new QWidget;
-  stepTabWidget->addTab(tab, tr("Resource"));
-
-  QGridLayout * resTabLayout = new QGridLayout(tab);
-  resourceFileWidget_ = new CouplingResourceFileWidget(model, indStep, tab);
-  resTabLayout->addWidget(resourceFileWidget_);
-  connect(resourceFileWidget_, &CouplingResourceFileWidget::couplingResourceCollectionModified, [ = ]()
-  {
-    updateInputFileWidgets(item);
-  });
-
+  setupCommandTab(stepTabWidget);
+  setupInputTab(stepTabWidget);
+  setupResourceTab(stepTabWidget);
   updateInputFileWidgets(item);
-
-  // output definition
-  tab = new QWidget;
-  stepTabWidget->addTab(tab, tr("Output"));
-  QGridLayout * outTabLayout = new QGridLayout(tab);
-
-  DynamicTabWidget * outTabWidget = new DynamicTabWidget;
-  outTabLayout->addWidget(outTabWidget);
-  connect(outTabWidget, &DynamicTabWidget::newTabRequested, [ = ]()
-  {
-    CouplingStepCollection csColl(model->getSteps());
-    CouplingStep cs2(csColl[indStep]);
-    CouplingOutputFileCollection outColl(cs2.getOutputFiles());
-
-    outColl.add(CouplingOutputFile());
-    cs2.setOutputFiles(outColl);
-    csColl[indStep] = cs2;
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
-    CouplingOutputFileWidget * outFileWidget = new CouplingOutputFileWidget(item, model, indStep, outColl.getSize() - 1);
-    outTabWidget->addTab(outFileWidget, tr("File"));
-    connect(outFileWidget, SIGNAL(variableListChanged()), this, SIGNAL(variableListChanged()));
-
-  });
-  connect(outTabWidget, &DynamicTabWidget::removeTabRequested, [ = ](int index2)
-  {
-    CouplingStepCollection csColl(model->getSteps());
-    CouplingStep cs2(csColl[indStep]);
-    CouplingOutputFileCollection outColl(cs2.getOutputFiles());
-
-    outColl.erase(outColl.begin() + index2);
-    cs2.setOutputFiles(outColl);
-    csColl[indStep] = cs2;
-    model->blockNotification("PhysicalModelDefinitionItem");
-    model->setSteps(csColl);
-    model->blockNotification();
-    item->update(0, "inputStepChanged");
-  });
-
-  tab = new QWidget(stepTabWidget);
-  stepTabWidget->addTab(tab, tr("Additional processing"));
-  QVBoxLayout * pyCodeLayout = new QVBoxLayout(tab);
-  PythonCodeWidget * pyCodeWidget = new PythonCodeWidget(item, indStep, tab);
-  pyCodeLayout->addWidget(pyCodeWidget);
-
-  // - fill in the QTabWidget
-  if (cs.getOutputFiles().getSize())
-  {
-    for (UnsignedInteger i = 0; i < cs.getOutputFiles().getSize(); ++i)
-    {
-      CouplingOutputFileWidget * outFileWidget = new CouplingOutputFileWidget(item, model, indStep, i);
-      outTabWidget->addTab(outFileWidget, tr("File"));
-    }
-  }
-  // - if no coupling output file : add an empty widget
-  if (outTabWidget->count() < 2)
-    outTabWidget->newTabRequested();
-
-  // Update step if Ansys wizard has been ran
-  connect(ansysTb, &QToolButton::clicked, [ = ]()
-  {
-    AnsysWizard * wizard = new AnsysWizard(this);
-    if(wizard->exec())
-    {
-      wizard->validateVariables();
-      wizard->validateSystems();
-
-      model->blockNotification("PhysicalModelDefinitionItem");
-      wizard->getParser()->populateCouplingStep(model, indStep);
-      model->blockNotification();
-
-      item->update(0, "inputValueChanged");
-      item->update(0, "codeChanged");
-      emit updateStepRequested();
-    }
-  });
+  setupOutputTab(stepTabWidget);
+  setupAdditionalProcessingTab(stepTabWidget);
 
   mainLayout->addStretch();
 }
 
+void CouplingStepWidget::setupCommandTab(QTabWidget *stepTabWidget)
+{
+  auto * tab = new QWidget;
+  stepTabWidget->addTab(tab, tr("Command"));
+
+  auto * comTabLayout = new QGridLayout(tab);
+  comTabLayout->addWidget(new QLabel(tr("Command")), 0, 0);
+
+  auto * commandLineEdit = new QLineEdit(QString::fromUtf8(model_->getSteps()[indStep_].getCommand().c_str()));
+  commandLineEdit->setValidator(new QRegularExpressionValidator(QRegularExpression("([^\r\n]*)")));
+  comTabLayout->addWidget(commandLineEdit, 0, 1);
+  if (!commandLineEdit->hasAcceptableInput())
+    commandLineEdit->setStyleSheet("color: red");
+  connect(commandLineEdit, &QLineEdit::editingFinished, [this, commandLineEdit]()
+  {
+    commandLineEdit->setStyleSheet("");
+    CouplingStepCollection csColl(model_->getSteps());
+    CouplingStep cs(csColl[indStep_]);
+    cs.setCommand(commandLineEdit->text().toUtf8().constData());
+    csColl[indStep_] = cs;
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
+  });
+
+  auto * checkBox = new QCheckBox(tr("Shell command"));
+  comTabLayout->addWidget(checkBox, 1, 0, 1, 2);
+  checkBox->setChecked(model_->getSteps()[indStep_].getIsShell());
+  connect(checkBox, &QCheckBox::toggled, [this](bool toggled)
+  {
+    CouplingStepCollection csColl(model_->getSteps());
+    CouplingStep cs(csColl[indStep_]);
+    cs.setIsShell(toggled);
+    csColl[indStep_] = cs;
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
+  });
+
+  auto * ansysTb = new QPushButton(QIcon(":/images/workbench32X32.png"),
+                                          tr("Run ansys wizard"), this);
+  comTabLayout->addWidget(ansysTb, 2, 0);
+
+  auto * advGroupBox = new CollapsibleGroupBox(tr("Advanced"));
+  auto * advGroupBoxLayout = new QGridLayout(advGroupBox);
+  comTabLayout->addWidget(advGroupBox, 3, 0, 1, 2);
+
+  advGroupBoxLayout->addWidget(new QLabel(tr("Timeout (s)")), 0, 0);
+  auto * timeOutVal = new DoubleSpinBox();
+  timeOutVal->setMinimum(-1);
+  timeOutVal->setValue(model_->getSteps()[indStep_].getTimeOut());
+  advGroupBoxLayout->addWidget(timeOutVal, 0, 1);
+  connect(timeOutVal, QOverload<double>::of(&DoubleSpinBox::valueChanged), [this](const double & val)
+  {
+    CouplingStepCollection csColl(model_->getSteps());
+    csColl[indStep_].setTimeOut(val);
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
+  });
+
+  advGroupBoxLayout->addWidget(new QLabel(tr("I/O Encoding")), 1, 0);
+  auto * encodingBox = new QComboBox();
+  encodingBox->insertItem(0, QString::fromStdString("utf-8"));
+  encodingBox->insertItem(1, QString::fromStdString("latin-1"));
+  int index = encodingBox->findText(QString::fromStdString(model_->getSteps()[indStep_].getEncoding()));
+  if (index != -1)
+    encodingBox->setCurrentIndex(index);
+  advGroupBoxLayout->addWidget(encodingBox, 1, 1);
+  connect(encodingBox, &QComboBox::currentTextChanged, [this](const QString & enc)
+  {
+    CouplingStepCollection csColl(model_->getSteps());
+    csColl[indStep_].setEncoding(enc.toUtf8().constData());
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
+  });
+
+  auto * envTableView = new QTableView;
+  envTableView->horizontalHeader()->setStretchLastSection(true);
+  envTableView->horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
+  advGroupBoxLayout->addWidget(envTableView, 2, 0, 1, 2);
+  auto * addRemoveWidget = new AddRemoveWidget;
+  advGroupBoxLayout->addWidget(addRemoveWidget, 3, 1, 1, 2, Qt::AlignRight);
+
+  CouplingStep cs(model_->getSteps()[indStep_]);
+  auto * envTableModel = new EnvironmentTableModel(cs, envTableView);
+  envTableView->setModel(envTableModel);
+  connect(addRemoveWidget, SIGNAL(addRequested()), envTableModel, SLOT(addLine()));
+  connect(addRemoveWidget, SIGNAL(removeRequested()), envTableModel, SLOT(removeLine()));
+  connect(envTableModel, &EnvironmentTableModel::stepChanged, [this, envTableModel]()
+  {
+    CouplingStepCollection csColl(model_->getSteps());
+    csColl[indStep_] = envTableModel->getStep();
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
+  });
+
+  advGroupBoxLayout->setColumnStretch(1, 1);
+  advGroupBoxLayout->setRowStretch(3, 1);
+  comTabLayout->setColumnStretch(1, 1);
+  comTabLayout->setRowStretch(4, 1);
+
+  connect(ansysTb, &QToolButton::clicked, [this]()
+  {
+    QPointer<AnsysWizard> wizard{new AnsysWizard(this)};
+    wizard->setAttribute(Qt::WA_DeleteOnClose);
+
+    connect(wizard, &QDialog::accepted, [this, wizard]()
+    {
+      wizard->validateVariables();
+      wizard->validateSystems();
+
+      model_->blockNotification("PhysicalModelDefinitionItem");
+      wizard->getParser()->populateCouplingStep(model_, indStep_);
+      model_->blockNotification();
+
+      item_->update(nullptr, "inputValueChanged");
+      item_->update(nullptr, "codeChanged");
+      emit updateStepRequested();
+    });
+
+    wizard->open();
+  });
+}
+
+void CouplingStepWidget::setupInputTab(QTabWidget *stepTabWidget)
+{
+  auto * tab = new QWidget;
+  stepTabWidget->addTab(tab, tr("Input"));
+
+  auto * inTabLayout = new QVBoxLayout(tab);
+  inTabWidget_ = new DynamicTabWidget;
+  inTabLayout->addWidget(inTabWidget_);
+  connect(inTabWidget_, &DynamicTabWidget::newTabRequested, [this]()
+  {
+    CouplingStepCollection csColl(model_->getSteps());
+    CouplingStep cs(csColl[indStep_]);
+    CouplingInputFileCollection inColl(cs.getInputFiles());
+    inColl.add(CouplingInputFile());
+    cs.setInputFiles(inColl);
+    csColl[indStep_] = cs;
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
+    auto * ciFileWidget = new CouplingInputFileWidget(item_, model_, indStep_, static_cast<int>(inColl.getSize()) - 1);
+    inTabWidget_->addTab(ciFileWidget, tr("File"));
+    connect(ciFileWidget, SIGNAL(variableListChanged()), this, SIGNAL(variableListChanged()));
+  });
+
+  connect(inTabWidget_, &DynamicTabWidget::removeTabRequested, [this](int index)
+  {
+    CouplingStepCollection csColl(model_->getSteps());
+    CouplingStep cs(csColl[indStep_]);
+    CouplingInputFileCollection inColl(cs.getInputFiles());
+    inColl.erase(inColl.begin() + index);
+    cs.setInputFiles(inColl);
+    csColl[indStep_] = cs;
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
+    updateInputFileWidgets(item_);
+  });
+}
+
+void CouplingStepWidget::setupResourceTab(QTabWidget *stepTabWidget)
+{
+  auto * tab = new QWidget;
+  stepTabWidget->addTab(tab, tr("Resource"));
+
+  auto * resTabLayout = new QGridLayout(tab);
+  resourceFileWidget_ = new CouplingResourceFileWidget(model_, indStep_, tab);
+  resTabLayout->addWidget(resourceFileWidget_);
+  connect(resourceFileWidget_, &CouplingResourceFileWidget::couplingResourceCollectionModified, [this]()
+  {
+    updateInputFileWidgets(item_);
+  });
+
+  updateInputFileWidgets(item_);
+}
+
+void CouplingStepWidget::setupOutputTab(QTabWidget *stepTabWidget)
+{
+  auto * tab = new QWidget;
+  stepTabWidget->addTab(tab, tr("Output"));
+
+  auto * outTabLayout = new QGridLayout(tab);
+  auto * outTabWidget = new DynamicTabWidget;
+  outTabLayout->addWidget(outTabWidget);
+  connect(outTabWidget, &DynamicTabWidget::newTabRequested, [this, outTabWidget]()
+  {
+    CouplingStepCollection csColl(model_->getSteps());
+    CouplingStep cs(csColl[indStep_]);
+    CouplingOutputFileCollection outColl(cs.getOutputFiles());
+    outColl.add(CouplingOutputFile());
+    cs.setOutputFiles(outColl);
+    csColl[indStep_] = cs;
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
+    auto * outFileWidget = new CouplingOutputFileWidget(item_, model_, indStep_, static_cast<int>(outColl.getSize()) - 1);
+    outTabWidget->addTab(outFileWidget, tr("File"));
+    connect(outFileWidget, SIGNAL(variableListChanged()), this, SIGNAL(variableListChanged()));
+  });
+
+  connect(outTabWidget, &DynamicTabWidget::removeTabRequested, [this](int index)
+  {
+    CouplingStepCollection csColl(model_->getSteps());
+    CouplingStep cs(csColl[indStep_]);
+    CouplingOutputFileCollection outColl(cs.getOutputFiles());
+    outColl.erase(outColl.begin() + index);
+    cs.setOutputFiles(outColl);
+    csColl[indStep_] = cs;
+    model_->blockNotification("PhysicalModelDefinitionItem");
+    model_->setSteps(csColl);
+    model_->blockNotification();
+    item_->update(nullptr, "inputStepChanged");
+  });
+
+  auto * cs = new CouplingStep(model_->getSteps()[indStep_]);
+  if (cs->getOutputFiles().getSize())
+  {
+    for (UnsignedInteger i = 0; i < cs->getOutputFiles().getSize(); ++i)
+    {
+      auto * outFileWidget = new CouplingOutputFileWidget(item_, model_, indStep_, i);
+      outTabWidget->addTab(outFileWidget, tr("File"));
+    }
+  }
+  if (outTabWidget->count() < 2)
+    outTabWidget->newTabRequested();
+  delete cs;
+}
+
+void CouplingStepWidget::setupAdditionalProcessingTab(QTabWidget *stepTabWidget)
+{
+  auto * tab = new QWidget(stepTabWidget);
+  stepTabWidget->addTab(tab, tr("Additional processing"));
+  auto * pyCodeLayout = new QVBoxLayout(tab);
+  auto * pyCodeWidget = new PythonCodeWidget(item_, indStep_, tab);
+  pyCodeLayout->addWidget(pyCodeWidget);
+}
 
 void CouplingStepWidget::updateInputFileWidgets(PhysicalModelItem *item)
 {
