@@ -292,7 +292,7 @@ void FMIPhysicalModelWindow::evaluateOutputs()
   {
     eval.run();
   }
-  catch (std::exception& ex)
+  catch (const std::exception& ex)
   {
     // do nothing
   }
@@ -351,7 +351,7 @@ void FMIPhysicalModelWindow::selectImportFileDialogRequested()
         fmiModel->setFMUFileName(fileName.toUtf8().data());
         errorMessageLabel_->reset();
       }
-      catch (std::exception & ex)
+      catch (const std::exception & ex)
       {
         errorMessageLabel_->setErrorMessage(ex.what());
       }
@@ -382,16 +382,9 @@ void FMIPhysicalModelWindow::loadModel(const FMUInfo & info)
 
 void FMIPhysicalModelWindow::updateFilters()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
   QRegularExpression::PatternOptions options = matchCaseCheckBox_->isChecked() ? QRegularExpression::NoPatternOption : QRegularExpression::CaseInsensitiveOption;
   QRegularExpression regExp(QRegularExpression::escape(filterTextEdit_->text()), options);
   proxyModel_->setFilterRegularExpression(regExp);
-#else
-  QRegExp::PatternSyntax syntax = QRegExp::FixedString;
-  Qt::CaseSensitivity caseSensitivity = matchCaseCheckBox_->isChecked() ? Qt::CaseSensitive : Qt::CaseInsensitive;
-  QRegExp regExp(filterTextEdit_->text(), caseSensitivity, syntax);
-  proxyModel_->setFilterRegExp(regExp);
-#endif
   proxyModel_->setFilterKeyColumn(searchFieldComboBox_->currentIndex());
 
   // filter variability
@@ -924,20 +917,38 @@ DataFilterProxyModel::DataFilterProxyModel(QObject *parent)
 
 void DataFilterProxyModel::setVariabilityFilter(const QList<int> & variabilityFilter)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+  beginFilterChange();
+  variabilityFilter_ = variabilityFilter;
+  endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
   variabilityFilter_ = variabilityFilter;
   invalidateFilter();
+#endif
 }
 
 void DataFilterProxyModel::setCausalityFilter(const QList<int> & causalityFilter)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+  beginFilterChange();
+  causalityFilter_ = causalityFilter;
+  endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
   causalityFilter_ = causalityFilter;
   invalidateFilter();
+#endif
 }
 
 void DataFilterProxyModel::setIOFilter(const QList<int> & ioFilter)
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 9, 0)
+  beginFilterChange();
+  ioFilter_ = ioFilter;
+  endFilterChange(QSortFilterProxyModel::Direction::Rows);
+#else
   ioFilter_ = ioFilter;
   invalidateFilter();
+#endif
 }
 
 bool DataFilterProxyModel::filterAcceptsRow(int sourceRow,
@@ -946,11 +957,7 @@ bool DataFilterProxyModel::filterAcceptsRow(int sourceRow,
   // matches text regex
   QModelIndex index01 = sourceModel()->index(sourceRow, filterKeyColumn(), sourceParent);
 
-#if QT_VERSION >= QT_VERSION_CHECK(5,12,0)
   const bool textMatch = sourceModel()->data(index01).toString().contains(filterRegularExpression());
-#else
-  const bool textMatch = sourceModel()->data(index01).toString().contains(filterRegExp());
-#endif
 
   // matches variability
   QModelIndex index2 = sourceModel()->index(sourceRow, 2, sourceParent);
