@@ -20,6 +20,7 @@
  */
 #include "persalys/InferenceResultWidget.hxx"
 
+#include "persalys/BaseTools.hxx"
 #include "persalys/InferenceAnalysis.hxx"
 #include "persalys/ResizableStackedWidget.hxx"
 #include "persalys/RadioButtonDelegate.hxx"
@@ -30,11 +31,13 @@
 
 #include <openturns/VisualTest.hxx>
 #include <openturns/UserDefined.hxx>
+#include <openturns/Histogram.hxx>
 
 #include <QVBoxLayout>
 #include <QGroupBox>
 #include <QHeaderView>
 #include <QDesktopServices>
+#include <QLabel>
 
 using namespace OT;
 
@@ -44,19 +47,6 @@ namespace PERSALYS
 InferenceResultWidget::InferenceResultWidget(const bool displayPDF_QQPlot, QWidget* parent)
   : QScrollArea(parent)
   , displayPDF_QQPlot_(displayPDF_QQPlot)
-  , tabWidget_(0)
-  , currentFittingTestResult_()
-  , distTableView_(0)
-  , distTableModel_(0)
-  , distParamTableView_(0)
-  , distParamTableModel_(0)
-  , infoButton_(0)
-  , analysisErrorMessageLabel_(0)
-  , pdf_cdfPlotSettingWidget_(0)
-  , pdfPlot_(0)
-  , cdfPlot_(0)
-  , qqPlot_(0)
-  , survPlot_(0)
 {
   buildInterface();
 }
@@ -66,12 +56,22 @@ void InferenceResultWidget::buildInterface()
 {
   setWidgetResizable(true);
 
-  QWidget * rightWidget = new QWidget;
-  QHBoxLayout * rightWidgetLayout = new QHBoxLayout(rightWidget);
+  auto * mainWidget = new QWidget;
+  auto * mainLayout = new QHBoxLayout(mainWidget);
+  auto * leftLayout = new QVBoxLayout;
+  mainLayout->addLayout(leftLayout);
+
+  // -- sizes table
+  auto * sizeGroupBox = new QGroupBox(tr("Sample size"));
+  sizeGroupBox->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
+  auto * sizeGroupBoxLayout = new QVBoxLayout(sizeGroupBox);
+  sizeTable_ = new ParametersTableView(QStringList{tr("Orignal sample size"), tr("Marginal sample size")}, QStringList{"",""}, true, true);
+  sizeGroupBoxLayout->addWidget(sizeTable_);
+  leftLayout->addWidget(sizeGroupBox, 0, Qt::AlignLeft);
 
   // -- distributions table
-  QGroupBox * distGroupBox = new QGroupBox(tr("Distributions"));
-  QVBoxLayout * distGroupBoxLayout = new QVBoxLayout(distGroupBox);
+  auto * distGroupBox = new QGroupBox(tr("Distributions"));
+  auto * distGroupBoxLayout = new QVBoxLayout(distGroupBox);
 
   // --- table view
   distTableView_ = new ExportableTableView;
@@ -92,7 +92,9 @@ void InferenceResultWidget::buildInterface()
 
   distGroupBoxLayout->addWidget(distTableView_);
 
-  rightWidgetLayout->addWidget(distGroupBox, 0, Qt::AlignLeft | Qt::AlignTop);
+  distGroupBox->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Maximum);
+  leftLayout->addWidget(distGroupBox, 0, Qt::AlignLeft);
+  leftLayout->addStretch();
 
   // -- distribution parameters table
   // --- table view
@@ -123,6 +125,9 @@ void InferenceResultWidget::buildInterface()
     // --- cdf
     cdfPlot_ = new PlotWidget(tr("distributionCDF"));
     pdf_cdfStackedWidget->addWidget(cdfPlot_);
+    // --- quantile function
+    quantilePlot_ = new PlotWidget(tr("distributionQuantile"));
+    pdf_cdfStackedWidget->addWidget(quantilePlot_);
     // --- survival function
     survPlot_ = new PlotWidget(tr("survivalFunction"));
     pdf_cdfStackedWidget->addWidget(survPlot_);
@@ -130,8 +135,9 @@ void InferenceResultWidget::buildInterface()
     QVector<PlotWidget*> listpdf_cdfPlot;
     listpdf_cdfPlot.append(pdfPlot_);
     listpdf_cdfPlot.append(cdfPlot_);
+    listpdf_cdfPlot.append(quantilePlot_);
     listpdf_cdfPlot.append(survPlot_);
-    pdf_cdfPlotSettingWidget_ = new PDFGraphSetting(listpdf_cdfPlot, PDFGraphSetting::Result, this);
+    pdf_cdfPlotSettingWidget_ = new PDFGraphSetting(listpdf_cdfPlot, PDFGraphSetting::Distribution, this);
     connect(pdf_cdfPlotSettingWidget_, SIGNAL(currentPlotChanged(int)), pdf_cdfStackedWidget, SLOT(setCurrentIndex(int)));
 
     scrollArea->setWidget(new WidgetBoundToDockWidget(pdf_cdfStackedWidget, pdf_cdfPlotSettingWidget_, this));
@@ -149,6 +155,12 @@ void InferenceResultWidget::buildInterface()
     // --- qq plot
     qqPlot_ = new PlotWidget(tr("qqPlot"));
     plotWidgetLayout->addWidget(qqPlot_);
+
+    qqPlotWarningLabel_ = new QLabel;
+    qqPlotWarningLabel_->setStyleSheet("QLabel { color : orange; font-weight: bold; background-color: transparent; border: 1px solid orange; }");
+    qqPlotWarningLabel_->hide();
+    plotWidgetLayout->addWidget(qqPlotWarningLabel_);
+
     // --- GraphConfigurationWidget
     SimpleGraphSetting * qqPlotSettingWidget = new SimpleGraphSetting(qqPlot_, this);
     qqPlotSettingWidget->hide();
@@ -174,7 +186,7 @@ void InferenceResultWidget::buildInterface()
     scrollArea->setWidget(paramWidget);
     tabWidget_->addTab(scrollArea, tr("Parameters"));
 
-    rightWidgetLayout->addWidget(tabWidget_);
+    mainLayout->addWidget(tabWidget_);
   }
   else
   {
@@ -185,14 +197,18 @@ void InferenceResultWidget::buildInterface()
     paramGroupBoxLayout->addWidget(analysisErrorMessageLabel_);
     paramGroupBoxLayout->addWidget(pdfPlot_);
     paramGroupBoxLayout->addStretch();
-    rightWidgetLayout->addWidget(paramGroupBox);
+    mainLayout->addWidget(paramGroupBox);
   }
-  setWidget(rightWidget);
+  setWidget(mainWidget);
 }
 
 
 void InferenceResultWidget::updateDistributionTable(const double level, const InferenceResult& result, const QString& variableName)
 {
+  
+  sizeTable_->setValueAt(0, QString::number(result.getOriginalSampleSize()));
+  sizeTable_->setValueAt(1, QString::number(result.getFittingTestResultForVariable(variableName.toStdString()).getValues().getSize()));
+
   // check
   if (!(distTableModel_ && distTableView_))
     return;
@@ -376,6 +392,7 @@ void InferenceResultWidget::updateParametersTable(QModelIndex current)
     // -- get distribution
     const QVariant variant = distTableModel_->data(distTableModel_->index(current.row(), 0), Qt::UserRole);
     distribution = currentFittingTestResult_.getTestedDistributions()[variant.value<int>()];
+    const auto histogram = dynamic_cast<Histogram*>(distribution.getImplementation().get());
 
     // -- set parameters
     distParamTableModel_->setNotEditableItem(++row, 0, tr("Parameters"));
@@ -388,16 +405,33 @@ void InferenceResultWidget::updateParametersTable(QModelIndex current)
     distParamTableModel_->setData(distParamTableModel_->index(row, 0), font, Qt::FontRole);
 
     const PointWithDescription parameters = DistributionDictionary::GetParametersCollection(distribution)[0];
-    for (UnsignedInteger i = 0; i < parameters.getSize(); ++i)
+    if (histogram)
     {
-      const QString param(TranslationManager::GetTranslatedDistributionParameterName(parameters.getDescription()[i]));
-      distParamTableModel_->setNotEditableHeaderItem(++row, 0, param);
-      distParamTableModel_->setNotEditableItem(row, 1, parameters[i]);
-      if (currentFittingTestResult_.getParamConfidenceInterval().getSize())
+      for (UnsignedInteger i = 0 ; i < 3 ; ++i)
       {
-        const Interval paramBounds = currentFittingTestResult_.getParamConfidenceInterval()[variant.value<int>()];
-        distParamTableModel_->setNotEditableItem(row, 2, paramBounds.getLowerBound()[i]);
-        distParamTableModel_->setNotEditableItem(row, 3, paramBounds.getUpperBound()[i]);
+        const QString param(TranslationManager::GetTranslatedDistributionParameterName(parameters.getDescription()[i]));
+        distParamTableModel_->setNotEditableHeaderItem(++row, 0, param);
+        if (i == 0)
+          distParamTableModel_->setNotEditableItem(row, 1, histogram->getFirst());
+        else if (i == 1)
+          distParamTableModel_->setNotEditableItem(row, 1, Parameters::GetOTPointStr(histogram->getWidth()).c_str());
+        else
+          distParamTableModel_->setNotEditableItem(row, 1, Parameters::GetOTPointStr(histogram->getHeight()).c_str());
+      }
+    }
+    else
+    {
+      for (UnsignedInteger i = 0; i < parameters.getSize(); ++i)
+      {
+        const QString param(TranslationManager::GetTranslatedDistributionParameterName(parameters.getDescription()[i]));
+        distParamTableModel_->setNotEditableHeaderItem(++row, 0, param);
+        distParamTableModel_->setNotEditableItem(row, 1, parameters[i]);
+        if (currentFittingTestResult_.getParamConfidenceInterval().getSize())
+        {
+          const Interval paramBounds = currentFittingTestResult_.getParamConfidenceInterval()[variant.value<int>()];
+          distParamTableModel_->setNotEditableItem(row, 2, paramBounds.getLowerBound()[i]);
+          distParamTableModel_->setNotEditableItem(row, 3, paramBounds.getUpperBound()[i]);
+        }
       }
     }
   }
@@ -412,7 +446,7 @@ void InferenceResultWidget::updateParametersTable(QModelIndex current)
 
   if (current.isValid())
   {
-    row = distribution.getParameterDescription().getSize() + 1;
+    row -= 4;
 
     // -- set moments
     distParamTableModel_->setNotEditableItem(++row, 1, distribution.getMean()[0]);
@@ -462,9 +496,14 @@ void InferenceResultWidget::updateGraphs(QModelIndex current)
     cdfPlot_->clear();
     qqPlot_->clear();
   }
+  if(quantilePlot_ && pdf_cdfPlotSettingWidget_)
+  {
+    pdf_cdfPlotSettingWidget_->getCurrentPlotIndex() == 2 ? quantilePlot_->show() : quantilePlot_->hide();
+    quantilePlot_->clear();
+  }
   if(survPlot_ && pdf_cdfPlotSettingWidget_)
   {
-    pdf_cdfPlotSettingWidget_->getCurrentPlotIndex() == 2 ? survPlot_->show() : survPlot_->hide();
+    pdf_cdfPlotSettingWidget_->getCurrentPlotIndex() == 3 ? survPlot_->show() : survPlot_->hide();
     survPlot_->clear();
   }
 
@@ -492,6 +531,7 @@ void InferenceResultWidget::updateGraphs(QModelIndex current)
 
   // update pdf
   pdfPlot_->plotHistogram(currentFittingTestResult_.getValues());
+
   pdfPlot_->plotPDFCurve(distribution);
   pdfPlot_->setTitle(tr("PDF") + ": " + distName);
 
@@ -546,8 +586,27 @@ void InferenceResultWidget::updateGraphs(QModelIndex current)
   cdfPlot_->setTitle(tr("CDF") + ": " + distName + " ("
                      + testName + " " + tr("statistic=%1)").arg(std::abs(KSStatistic(0, 1) - KSStatistic(1, 1))));
 
+  // -- quantile plot
+  if (quantilePlot_)
+  {
+    quantilePlot_->plotQuantileCurve(distribution);
+    quantilePlot_->setTitle(tr("Quantile function") + ": " + distName);
+  }
+
   // -- qq plot
-  Graph qqPlotGraph(VisualTest::DrawQQplot(currentFittingTestResult_.getValues(), distribution));
+  Sample sampleValues = currentFittingTestResult_.getValues();
+  if (sampleValues.getSize() > 10000)
+  {
+    sampleValues.split(10000);
+    qqPlotWarningLabel_->setText(tr("Warning: Only the first 10000 points are being displayed."));
+    qqPlotWarningLabel_->show();
+  }
+  else
+  {
+    qqPlotWarningLabel_->hide();
+  }
+
+  Graph qqPlotGraph(VisualTest::DrawQQplot(sampleValues, distribution));
   qqPlot_->setTitle(tr("Q-Q Plot") + ": " + distName);
   qqPlot_->setAxisTitle(QwtPlot::xBottom, tr("Data quantiles"));
   qqPlot_->setAxisTitle(QwtPlot::yLeft, tr("%1 theoretical quantiles").arg(distName));
