@@ -2,7 +2,7 @@
 /**
  *  @brief QWizardPage to define the design of experiments and the method of metamodel analysis
  *
- *  Copyright 2015-2024 EDF-Phimeca
+ *  Copyright 2015-2025 EDF-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -75,8 +75,8 @@ MetaModelIntroPage::MetaModelIntroPage(QWidget* parent)
   methodGroup_->addButton(buttonToChooseMethod, MetaModelIntroPage::Chaos);
   methodLayout->addWidget(buttonToChooseMethod);
 
-  // Kriging
-  buttonToChooseMethod = new QRadioButton(tr("Kriging"));
+  // GPR
+  buttonToChooseMethod = new QRadioButton(tr("Gaussian Process (kriging)"));
   methodGroup_->addButton(buttonToChooseMethod, MetaModelIntroPage::Kriging);
   methodLayout->addWidget(buttonToChooseMethod);
 
