@@ -34,12 +34,16 @@
 #include "persalys/KrigingAnalysis.hxx"
 #include "persalys/FunctionalChaosAnalysis.hxx"
 #include "persalys/PythonPhysicalModel.hxx"
-#include "persalys/PropertiesDialog.hxx"
+#include "persalys/PythonPhysicalModelPropertiesDialog.hxx"
+#include "persalys/ImportEvaluationsWizard.hxx"
 
 #include <QFileDialog>
 #include <QApplication>
 #include <QMessageBox>
 #include <QDebug>
+#include <QPointer>
+
+#include <openturns/OTtestcode.hxx>
 
 using namespace OT;
 
@@ -102,13 +106,16 @@ void StudyManager::openAnalysisWizard(StudyItem *item, const Analysis &analysis,
     return;
   }
 
-  AnalysisWizard * wizard = WindowFactory::GetAnalysisWizard(analysis, isGeneralWizard, mainWidget_);
+  QPointer<AnalysisWizard> wizard{WindowFactory::GetAnalysisWizard(analysis, isGeneralWizard, mainWidget_)};
 
   if (wizard)
   {
-    if (wizard->exec())
+    wizard->setAttribute(Qt::WA_DeleteOnClose);
+    connect(wizard, &QDialog::accepted, [item, wizard]() {
       item->getStudy().add(wizard->getAnalysis());
-    delete wizard;
+    });
+
+    wizard->open();
   }
 }
 
@@ -116,13 +123,16 @@ void StudyManager::openAnalysisWizard(StudyItem *item, const Analysis &analysis,
 void StudyManager::modifyAnalysis(AnalysisItem* item)
 {
   Q_ASSERT(item);
-  AnalysisWizard * wizard = WindowFactory::GetAnalysisWizard(item->getAnalysis(), false, mainWidget_);
+  QPointer<AnalysisWizard> wizard{WindowFactory::GetAnalysisWizard(item->getAnalysis(), false, mainWidget_)};
 
   if (wizard)
   {
-    if (wizard->exec())
+    wizard->setAttribute(Qt::WA_DeleteOnClose);
+    connect(wizard, &QDialog::accepted, [item, wizard]() {
       item->updateAnalysis(wizard->getAnalysis());
-    delete wizard;
+    });
+
+    wizard->open();
   }
 }
 
@@ -139,6 +149,50 @@ void StudyManager::openDesignOfExperimentEvaluationWizard(const Analysis& analys
   }
 }
 
+void StudyManager::openImportEvaluationsWizard(const StudyItem *item, const Analysis &analysis)
+{
+
+  QPointer<ImportEvaluationsWizard> wizard(new ImportEvaluationsWizard(analysis, mainWidget_));
+  wizard->setAttribute(Qt::WA_DeleteOnClose);
+
+  connect(wizard, &QDialog::accepted, [item, analysis, wizard](){
+      const auto * implementation = dynamic_cast<DesignOfExperimentEvaluation*>(analysis.getImplementation().get());
+      Analysis newAnalysis(wizard->getAnalysis());
+      const auto * newImplementation = dynamic_cast<DesignOfExperimentEvaluation*>(newAnalysis.getImplementation().get());
+
+      DesignOfExperimentEvaluation * modifiedImplementation(implementation->clone());
+      try
+      {
+        modifiedImplementation->checkAndSetEvaluations(newImplementation->getResult().getDesignOfExperiment());
+        Analysis modifiedAnalysis(modifiedImplementation);
+        item->getStudy().remove(analysis);
+        item->getStudy().add(modifiedAnalysis);
+      }
+      catch (const InvalidArgumentException &e)
+      {
+        const QString message{e.what()};
+        if (message.contains("The physical model does not contain an output named"))
+          QMessageBox::warning(QApplication::activeWindow(),
+            tr("Select corresponding output"),
+            tr("Please select which column corresponds to which output.")
+          );
+        else
+          QMessageBox::warning(QApplication::activeWindow(),
+            tr("Invalid dimension"),
+            tr("The sample contained in the CSV must have the same size and dimension as the one contained in this design of experiment.")
+          );
+      }
+      catch (const Test::TestFailed&)
+      {
+        QMessageBox::warning(QApplication::activeWindow(),
+          tr("Wrong values"),
+          tr("The input values contained in the CSV file do not match the values of this design of experiments.")
+        );
+      }
+  });
+
+  wizard->open();
+}
 
 void StudyManager::openObservationsWizard(StudyItem *item, const DesignOfExperiment &designOfExp)
 {
@@ -169,49 +223,54 @@ void StudyManager::openExtractDataFieldWizard(StudyItem *item, const Analysis &a
 
 void StudyManager::openMetamodelExportWizard(StudyItem *item, const Analysis& analysis, const bool isGeneralWizard)
 {
-  MetaModelExportWizard * wizard = new MetaModelExportWizard(analysis, isGeneralWizard, mainWidget_);
+  QPointer<MetaModelExportWizard> wizard(new MetaModelExportWizard(analysis, isGeneralWizard, mainWidget_));
+  wizard->setAttribute(Qt::WA_DeleteOnClose);
 
-  if (wizard)
-  {
-    if (wizard->exec())
-    {
-      FunctionalChaosAnalysis * chaos = dynamic_cast<FunctionalChaosAnalysis*>(wizard->getAnalysis().getImplementation().get());
-      if (chaos)
-        item->appendMetaModelItem(chaos->getResult().getMetaModel());
-      KrigingAnalysis * kriging = dynamic_cast<KrigingAnalysis*>(wizard->getAnalysis().getImplementation().get());
-      if(kriging)
-        item->appendMetaModelItem(kriging->getResult().getMetaModel());
-      PolynomialRegressionAnalysis * linear = dynamic_cast<PolynomialRegressionAnalysis*>(wizard->getAnalysis().getImplementation().get());
-      if (linear)
-        item->appendMetaModelItem(linear->getResult().getMetaModel());
-    }
-    delete wizard;
-  }
+  connect(wizard, &QDialog::accepted, [item, wizard](){
+    const auto * metaModelAnalysis = dynamic_cast<MetaModelAnalysis*>(wizard->getAnalysis().getImplementation().get());
+    const MetaModelExportWizard::ExportType exportType = wizard->getExportType();
+    if (exportType == MetaModelExportWizard::Symbolic)
+      item->appendMetaModelItem(metaModelAnalysis->getMetaModel());
+    else
+      item->appendPythonMetaModelItem(metaModelAnalysis->asPythonPhysicalModel(item->getStudy()));
+  });
+
+  wizard->open();
 }
 
 
-void StudyManager::openProperties(Item* item)
+void StudyManager::openProperties(Item* item) const
 {
-  PhysicalModelItem * pmItem = dynamic_cast<PhysicalModelItem*>(item);
+  const PhysicalModelItem * pmItem = dynamic_cast<PhysicalModelItem*>(item);
   if (pmItem)
   {
     PythonPhysicalModel * model = dynamic_cast<PythonPhysicalModel*>(pmItem->getPhysicalModel().getImplementation().get());
     if (model)
     {
-      PropertiesDialog * propertiesDialog = new PropertiesDialog;
-      propertiesDialog->setWindowTitle(QString(model->getName().c_str()));
-      propertiesDialog->setProcessNumber(model->getProcessNumber());
-      connect(propertiesDialog, &QDialog::accepted, [ = ]()
-      {
-        model->setProcessNumber(propertiesDialog->getProcessNumber());
-        model->setParallel(propertiesDialog->getProcessNumber() != 1);
-      });
+      PythonPhysicalModelPropertiesDialog * propertiesDialog = new PythonPhysicalModelPropertiesDialog(model);
       propertiesDialog->open();
     }
   }
 }
 
 
+// --------------- OPEN ANALYSIS WINDOW ---------------
+
+void StudyManager::openAnalysisWindow(StudyItem *item, const Analysis &analysis)
+{
+  Q_ASSERT(item);
+  String errorMessage = "";
+  if (!analysis.canBeLaunched(errorMessage))
+  {
+    showErrorMessage(TranslationManager::GetTranslatedErrorMessage(errorMessage));
+  }
+  else
+  {
+    item->getStudy().add(analysis);
+  }
+}
+
+
 // --------------- WINDOW CREATION ---------------
 
 
@@ -232,6 +291,8 @@ void StudyManager::createWindow(Item *item)
   });
   connect(item, SIGNAL(wizardRequested(StudyItem*, DesignOfExperiment)), this, SLOT(openObservationsWizard(StudyItem*, DesignOfExperiment)));
 
+  connect(item, SIGNAL(analysisRequested(StudyItem*, Analysis)), this, SLOT(openAnalysisWindow(StudyItem*, Analysis)));
+
   connect(item, SIGNAL(windowRequested(Item*)), this, SLOT(createWindow(Item*)));
   connect(item, SIGNAL(windowRequested(AnalysisItem*)), this, SLOT(createAnalysisWindow(AnalysisItem*)));
 
@@ -261,6 +322,7 @@ void StudyManager::createAnalysisWindow(AnalysisItem* item, const bool createCon
     connect(item, SIGNAL(wizardRequested(StudyItem*, Analysis)), this, SLOT(openAnalysisWizard(StudyItem*, Analysis)));
     connect(item, SIGNAL(doeEvaluationWizardRequested(Analysis)), this, SLOT(openDesignOfExperimentEvaluationWizard(Analysis)));
     connect(item, SIGNAL(pythonMetamodelExportRequested(PhysicalModel)), this, SLOT(exportMetamodelPython(PhysicalModel)));
+    connect(item, &AnalysisItem::evaluationsImportRequested, this,  &StudyManager::openImportEvaluationsWizard);
   }
 
   // do removeSubWindow if the analysis run method has been launched from a Python script
@@ -275,9 +337,14 @@ void StudyManager::createAnalysisWindow(AnalysisItem* item, const bool createCon
     if (window)
       updateView(window);
   }
-  catch (std::exception& ex)
+  catch (const Exception &e)
   {
-    qDebug() << "Error when building the analysis window : " << ex.what();
+    qDebug() << e.where() << ": " << e.what();
+    message = tr("Impossible to create a result window");
+  }
+  catch (const std::exception& ex)
+  {
+    qDebug() << "Error when building the analysis window: " << ": " << ex.what();
     message = tr("Impossible to create a result window");
   }
 
@@ -375,7 +442,18 @@ void StudyManager::exportPythonScript()
                            tr("Python source files (*.py)"));
 
   if (!fileName.isEmpty())
-    item->exportPythonScript(fileName);
+    try
+    {
+      item->exportPythonScript(fileName);
+    }
+    catch (const std::exception &ex)
+    {
+      showErrorMessage(tr("An error occurred during export:\n%1").arg(ex.what()));
+    }
+    catch (...)
+    {
+      showErrorMessage(tr("An unknown error occurred during export."));
+    }
 }
 
 
@@ -390,11 +468,15 @@ void StudyManager::exportMetamodelPython(const PhysicalModel & metamodel)
     return;
   }
 
-  const QString fileName = QFileDialog::getSaveFileName(mainWidget_,
+  QString fileName = QFileDialog::getSaveFileName(mainWidget_,
                            tr("Export Python..."),
                            FileTools::GetCurrentDir() + QDir::separator() + item->data(Qt::DisplayRole).toString() + QString(".py"),
                            tr("Python source files (*.py)"));
 
+  const QFileInfo fi(fileName);
+  if (fi.suffix().isEmpty())
+    fileName += ".py";
+
   if (!fileName.isEmpty())
     metamodel.exportStandalonePythonScript(fileName.toStdString());
 }
@@ -510,7 +592,7 @@ void StudyManager::open(const QString& recentFileName)
     emit recentFilesListChanged(fileName);
     QApplication::restoreOverrideCursor();
   }
-  catch (std::exception & ex)
+  catch (const std::exception & ex)
   {
     QApplication::restoreOverrideCursor();
     showErrorMessage(tr("An error has occurred when reading the file '%1'. \nMaybe objects are not opened.\n").arg(fileName) + ex.what());
