@@ -91,14 +91,6 @@ void StudyWindow::buildInterface()
   connect(button, SIGNAL(clicked()), studyItem_->newPythonModel_, SIGNAL(triggered()));
   layout->addWidget(button, ++row, 0, Qt::AlignTop);
 
-#ifdef PERSALYS_HAVE_YACS
-  button = new DiagramPushButton(tr("Python model on cluster"));
-  button->setStatusTip(tr("Create a physical model defined with a Python script intended to run on a cluster"));
-  connect(button, SIGNAL(clicked()), studyItem_->newYACSModel_, SIGNAL(triggered()));
-  layout->addWidget(button, ++row, 0, Qt::AlignTop);
-  ++nbModels;
-#endif
-
 #ifdef PERSALYS_HAVE_OTFMI
   button = new DiagramPushButton(tr("FMI model"));
   button->setStatusTip(tr("Create a physical model defined with a FMU file"));
@@ -179,22 +171,23 @@ void StudyWindow::buildInterface()
   hLayout->addWidget(hLineFrame, 1);
   layout->addLayout(hLayout, ++row, 0, 1, 2);
 
-  button = new DiagramPushButton(tr("Data model"));
+  button = new DiagramPushButton(tr("Data set"));
   button->setStatusTip(tr("Import a sample to create a model"));
   connect(button, SIGNAL(clicked()), studyItem_->newDataModel_, SIGNAL(triggered()));
   layout->addWidget(button, ++row, 0, Qt::AlignTop);
 
   // functionalities list
   textEdit = new QLabel;
-  text = QString("- %1\n- %2\n- %3\n- %4")
+  text = QString("- %1\n- %2\n- %3\n- %4\n- %5")
          .arg(tr("Data analysis"))
+         .arg(tr("Sensitivity analysis"))
          .arg(tr("Marginals inference"))
          .arg(tr("Dependence inference"))
          .arg(tr("Metamodel"));
   textEdit->setText(text);
   layout->addWidget(textEdit, row, 1, 2, 1, Qt::AlignLeft | Qt::AlignTop);
 
-  button = new DiagramPushButton(tr("Data Field model"));
+  button = new DiagramPushButton(tr("Field data set"));
   button->setStatusTip(tr("Import a process sample to create a field model"));
   connect(button, SIGNAL(clicked()), studyItem_->newDataFieldModel_, SIGNAL(triggered()));
   layout->addWidget(button, ++row, 0, Qt::AlignTop);
