@@ -170,11 +170,7 @@ int CodeEditor::lineNumberAreaWidth()
     max /= 10;
     ++digits;
   }
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
   int space = 3 + fontMetrics().horizontalAdvance(QLatin1Char('9')) * digits;
-#else
-  int space = 3 + fontMetrics().width(QLatin1Char('9')) * digits;
-#endif
   return space;
 }
 
