@@ -40,14 +40,15 @@ public:
     setFocusPolicy(Qt::ClickFocus);
   }
 
-  virtual void wheelEvent(QWheelEvent *e)
+  void wheelEvent(QWheelEvent *e) override
   {
     // if no focus : no signal currentIndexChanged emitted -> wrong behavior
     // so if no focus : do nothing
     if (hasFocus() && !neverWheelEvent_)
       QComboBox::wheelEvent(e);
   }
-  virtual void keyPressEvent(QKeyEvent *e)
+
+  void keyPressEvent(QKeyEvent *e) override
   {
     QKeyEvent *keyEvent = static_cast<QKeyEvent *>(e);
     if (keyEvent->key() == Qt::Key_Down || keyEvent->key() == Qt::Key_Up ||
@@ -87,11 +88,7 @@ void ComboBoxWithSeparatorDelegate::paint(QPainter *painter, const QStyleOptionV
   else if (index.data(Qt::AccessibleDescriptionRole).toString() == QLatin1String("child"))
   {
     QStyleOptionViewItem childOption = option;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
     int indent = option.fontMetrics.horizontalAdvance(QString(4, QChar(' ')));
-#else
-    int indent = painter->fontMetrics().width(QString(4, QChar(' ')));
-#endif
     childOption.rect.adjust(indent, 0, 0, 0);
     childOption.textElideMode = Qt::ElideNone;
     QItemDelegate::paint(painter, childOption, index);
@@ -188,11 +185,7 @@ QWidget *ComboBoxDelegate::createEditor(QWidget * parent, const QStyleOptionView
   // set Background color
   const QString defaultColor = index.model()->data(index, Qt::BackgroundRole).value<QColor>().name();
   editor->lineEdit()->setStyleSheet("QLineEdit {background: " + defaultColor + ";}");
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
   connect(editor, SIGNAL(textActivated(QString)), this, SLOT(emitCommitData()));
-#else
-  connect(editor, SIGNAL(activated(QString)), this, SLOT(emitCommitData()));
-#endif
   return editor;
 }
 
