@@ -87,11 +87,11 @@ void ImportSampleWidget::buildInterface()
 
     mainGridLayout->addLayout(buttonsLayout, row++, 0, 1, 3);
 
-    connect(orderButtonGroup_, &QButtonGroup::idClicked, [=] (int) {
+    connect(orderButtonGroup_, &QButtonGroup::idClicked, [this] (int) {
       setData(filePathLineEdit_->text());
     });
 
-    connect(filePathLineEdit_, &QLineEdit::textChanged, [=] (QString) {
+    connect(filePathLineEdit_, &QLineEdit::textChanged, [this] (QString) {
       orderButtonGroup_->button(0)->setEnabled(QFile(filePathLineEdit_->text()).exists());
       orderButtonGroup_->button(1)->setEnabled(QFile(filePathLineEdit_->text()).exists());
     });
@@ -159,7 +159,7 @@ void ImportSampleWidget::setData(const QString& fileName)
     emit updateTableRequested(fileName);
     tableValidity_ = true;
   }
-  catch (std::exception & ex)
+  catch (const std::exception & ex)
   {
     dataPreviewTableView_->setModel(0);
     // DOE size
@@ -230,18 +230,14 @@ Indices ImportSampleWidget::getColumns(const Description &names) const
     }
   }
   if (addedVars.size())
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     if ((UnsignedInteger)QSet<QString>(addedVars.begin(), addedVars.end()).size() != columns.getSize())
-#else
-    if ((UnsignedInteger)addedVars.toSet().size() != columns.getSize())
-#endif
       throw InvalidArgumentException(HERE) << "Each variable must be present only once";
   return columns;
 }
 
 Sample ImportSampleWidget::getData() const
 {
-  SampleTableModel * model = dynamic_cast<SampleTableModel*>(dataPreviewTableView_->model());
+  const SampleTableModel * model = dynamic_cast<SampleTableModel*>(dataPreviewTableView_->model());
   if (model)
     return model->getSample();
   else
