@@ -28,9 +28,9 @@ namespace PERSALYS
 {
 
 ParametersTableView::ParametersTableView(const QStringList names,             // parameters names
-    const QStringList values,            // parameters values
-    const bool showGrid,         // show the grid of the table
-    const bool namesHasHeaderType, // parameters names display has table header
+    const QStringList values,                                                 // parameters values
+    const bool showGrid,                                                      // show the grid of the table
+    const bool namesHasHeaderType,                                            // parameters names display has table header
     const bool splitLongLines,
     QWidget * parent)
   : CopyableTableView(parent)
@@ -43,24 +43,24 @@ ParametersTableView::ParametersTableView(const QStringList names,             //
   verticalHeader()->hide();
 
   // table model
-  CustomStandardItemModel * tableModel = new CustomStandardItemModel(names.size(), 2, this);
+  tableModel_ = new CustomStandardItemModel(names.size(), 2, this);
   if (splitLongLines)
   {
-    LongStringProxy* proxy = new LongStringProxy(1, 50, this);
-    proxy->setSourceModel(tableModel);
+    auto * proxy = new LongStringProxy(1, 50, this);
+    proxy->setSourceModel(tableModel_);
     setModel(proxy);
   }
   else
-    setModel(tableModel);
+    setModel(tableModel_);
 
   // vertical header
   for (int i = 0; i < names.size(); ++i)
   {
     if (namesHasHeaderType)
-      tableModel->setNotEditableHeaderItem(i, 0, names[i]);
+      tableModel_->setNotEditableHeaderItem(i, 0, names[i]);
     else
-      tableModel->setNotEditableItem(i, 0, names[i]);
-    tableModel->setNotEditableItem(i, 1, values[i]);
+      tableModel_->setNotEditableItem(i, 0, names[i]);
+    tableModel_->setNotEditableItem(i, 1, values[i]);
   }
 
   // show grid
@@ -70,6 +70,13 @@ ParametersTableView::ParametersTableView(const QStringList names,             //
   resizeToContents();
 }
 
+void ParametersTableView::setValueAt(int row, const QString &value, const QColor bgColor)
+{
+  if (!tableModel_) return;
+  tableModel_->setNotEditableItem(row, 1, value, QColor(), bgColor);
+  resizeToContents();
+}
+
 QVariant LongStringProxy::data(const QModelIndex & index, int role) const
 {
   QVariant val = QIdentityProxyModel::data(index, role);
