@@ -10,6 +10,7 @@
 #include <openturns/Uniform.hxx>
 #include <openturns/ParametricFunction.hxx>
 #include <openturns/NormalCopula.hxx>
+#include <openturns/JointDistribution.hxx>
 
 #include <QtTest/QtTest>
 
@@ -49,8 +50,12 @@ public:
     const int sampleSize = 100;
     Sample strainSample(eps.getDistribution().getSample(sampleSize));
     strainSample.setDescription(Description(1, "epsilon"));
-    Indices ind(3); ind.fill();
-    Point values(3); values[0] = 750e6; values[1] = 2750e6; values[2] = 10.;
+    Indices ind(3);
+    ind.fill();
+    Point values(3);
+    values[0] = 750e6;
+    values[1] = 2750e6;
+    values[2] = 10.;
     Function f(model.getFunction("sigma"));
     Sample outputStress(ParametricFunction(f, ind, values)(strainSample));
     int stressObservationNoiseSigma = 40.e6; // (Pa)
@@ -73,17 +78,17 @@ private slots:
     Description calibratedIn(2);
     calibratedIn[0] = "R";
     calibratedIn[1] = "C";
-    ComposedDistribution::DistributionCollection coll(2, Normal(5., 0.2));
+    JointDistribution::DistributionCollection coll(2, Normal(5., 0.2));
     CorrelationMatrix R(2);
     R(0, 0) = 0.2;
-    analysis.setCalibratedInputs(calibratedIn, ComposedDistribution(coll, NormalCopula(R)), Description(1, "gam"), Point(1, 7.5));
+    analysis.setCalibratedInputs(calibratedIn, JointDistribution(coll, NormalCopula(R)), Description(1, "gam"), Point(1, 7.5));
     analysis.setConfidenceIntervalLength(0.99);
     analysis.setBootStrapSize(50);
     CorrelationMatrix R2(1);
     R2(0, 0) = 0.2;
     analysis.setErrorCovariance(R2);
     OptimizationAlgorithm optimAlgo(analysis.getOptimizationAlgorithm());
-    optimAlgo.setMaximumEvaluationNumber(75);
+    optimAlgo.setMaximumCallsNumber(75);
     optimAlgo.setMaximumAbsoluteError(1e-4);
     analysis.setOptimizationAlgorithm(optimAlgo);
 
@@ -92,7 +97,7 @@ private slots:
     wizard.show();
 
     // checks
-    QVERIFY2(wizard.getAnalysis().getParameters()==analysis.getParameters(), "The two CalibrationAnalysis must be equal");
+    QVERIFY2(wizard.getAnalysis().getParameters() == analysis.getParameters(), "The two CalibrationAnalysis must be equal");
   }
 
 
@@ -110,7 +115,7 @@ private slots:
     // - first page
     QButtonGroup * buttonGroup = wizard.introPage_->findChild<QButtonGroup*>();
     QVERIFY2(buttonGroup->checkedId() == CalibrationIntroPage::LinearLeastSquares, "Checked button must be LinearLeastSquares");
-    bool analysisEquality = wizard.getAnalysis().getParameters()==analysis.getParameters();
+    bool analysisEquality = wizard.getAnalysis().getParameters() == analysis.getParameters();
     QVERIFY2(analysisEquality, "The two CalibrationAnalysis must be equal");
 
     wizard.next();
@@ -121,17 +126,17 @@ private slots:
     buttonGroup->button(CalibrationIntroPage::NonlinearLeastSquares)->click();
     QVERIFY2(wizard.nextId() == CalibrationAnalysisWizard::Page_Param, "Next page ID must be Page_Param");
     analysis.setMethodName("LeastSquaresNonlinear");
-    QVERIFY2(wizard.getAnalysis().getParameters()==analysis.getParameters(), "The two CalibrationAnalysis must be equal");
+    QVERIFY2(wizard.getAnalysis().getParameters() == analysis.getParameters(), "The two CalibrationAnalysis must be equal");
 
     buttonGroup->button(CalibrationIntroPage::LinearGaussian)->click();
     QVERIFY2(wizard.nextId() == CalibrationAnalysisWizard::Page_PriorDist, "Next page ID must be Page_PriorDist");
     analysis.setMethodName("GaussianLinear");
-    QVERIFY2(wizard.getAnalysis().getParameters()==analysis.getParameters(), "The two CalibrationAnalysis must be equal");
+    QVERIFY2(wizard.getAnalysis().getParameters() == analysis.getParameters(), "The two CalibrationAnalysis must be equal");
 
     buttonGroup->button(CalibrationIntroPage::NonlinearGaussian)->click();
     QVERIFY2(wizard.nextId() == CalibrationAnalysisWizard::Page_PriorDist, "Next page ID must be Page_PriorDist");
     analysis.setMethodName("GaussianNonlinear");
-    QVERIFY2(wizard.getAnalysis().getParameters()==analysis.getParameters(), "The two CalibrationAnalysis must be equal");
+    QVERIFY2(wizard.getAnalysis().getParameters() == analysis.getParameters(), "The two CalibrationAnalysis must be equal");
   }
 
 
@@ -210,7 +215,7 @@ private slots:
     QVERIFY2(wizard.validateCurrentPage(), "Page must be valid");
     QVERIFY2(wizard.refPointPage_->errorMessageLabel_->text().isEmpty(), "Label must be empty");
 
-    QTest::mousePress(headerView->viewport(), Qt::LeftButton, Qt::NoModifier, headerView->viewport()->rect().bottomLeft()+QPoint(5,2));
+    QTest::mousePress(headerView->viewport(), Qt::LeftButton, Qt::NoModifier, headerView->viewport()->rect().bottomLeft() + QPoint(5, 2));
     QVERIFY2(!wizard.validateCurrentPage(), "Page must be not valid");
     QVERIFY2(!wizard.refPointPage_->errorMessageLabel_->text().isEmpty(), "Label must be not empty");
     QVERIFY2(QtOT::DescriptionToStringList(wizard.refPointPage_->getFixedValues().getDescription()).join(",").toStdString() == "R,C,gam", "wrong fixed input names");
@@ -222,8 +227,8 @@ private slots:
     QVERIFY2(QtOT::DescriptionToStringList(wizard.refPointPage_->getFixedValues().getDescription()).join(",").toStdString() == "C,gam", "wrong fixed input names");
     QVERIFY2(wizard.priorDistPage_->getDistribution().getDescription() == Description(1, "R"), "wrong calibrated input names");
 
-    QTest::mousePress(headerView->viewport(), Qt::LeftButton, Qt::NoModifier, headerView->viewport()->rect().bottomLeft()+QPoint(5,2));
-    bool analysisEquality = wizard.getAnalysis().getParameters()==analysis.getParameters();
+    QTest::mousePress(headerView->viewport(), Qt::LeftButton, Qt::NoModifier, headerView->viewport()->rect().bottomLeft() + QPoint(5, 2));
+    bool analysisEquality = wizard.getAnalysis().getParameters() == analysis.getParameters();
     QVERIFY2(analysisEquality, "The two CalibrationAnalysis must be equal");
   }
 };
