@@ -27,21 +27,12 @@
 #include <boost/process.hpp>
 #include <boost/program_options.hpp>
 
-#ifdef _MSC_VER
-#include <experimental/filesystem>
-#else
 #include <filesystem>
-#endif
 #include <cstdlib>
 #include <iostream>
 
 namespace po = boost::program_options;
-#ifdef _MSC_VER
-namespace fs = std::experimental::filesystem;
-#else
 namespace fs = std::filesystem;
-#endif
-
 namespace bp = boost::process;
 
 int main(int argc, char *argv[])
@@ -77,14 +68,8 @@ int main(int argc, char *argv[])
 
 #if BOOST_VERSION >= 108800
   std::unordered_map<std::string, std::string> env;
-  for (const auto ke : boost::process::environment::current())
-  {
-    const std::string key = std::get<0>(ke).string();
-    const std::string value = std::get<1>(ke).string();
-    env[key] = value;
-    if (verbose)
-      std::cout << key << "=" << value << std::endl;
-  }
+  for (const auto entry : boost::process::environment::current())
+    env.emplace(entry.key().string(), entry.value().string());
 #else
   boost::process::environment env = boost::this_process::environment();
 #endif
