@@ -10,8 +10,10 @@ myStudy = persalys.Study("myStudy")
 # Model
 filename = "data2.csv"
 ot.RandomGenerator.SetSeed(0)
-sample = ot.Normal(3).getSample(300)
-sample.stack(ot.Gumbel().getSample(300))
+R = ot.CorrelationMatrix(4)
+R[0, 3] = 0.9
+distribution = ot.JointDistribution([ot.Normal(), ot.Normal(), ot.Normal(), ot.Gumbel()], ot.NormalCopula(R))
+sample = distribution.getSample(300)
 sample.setDescription(["X0", "X1", "X2", "X3"])
 sample.exportToCSVFile(filename, ",")
 columns = [0, 2, 3]
@@ -23,7 +25,11 @@ print(model)
 # Dependencies inference analysis ##
 analysis = persalys.CopulaInferenceAnalysis("analysis", model)
 variables = ["X0", "X3"]
-factories = [ot.NormalCopulaFactory(), ot.GumbelCopulaFactory()]
+factories = [ot.ClaytonCopulaFactory(),
+             ot.FrankCopulaFactory(),
+             ot.GumbelCopulaFactory(),
+             ot.NormalCopulaFactory(),
+             ot.StudentCopulaFactory()]
 analysis.setDistributionsFactories(variables, factories)
 myStudy.add(analysis)
 print(analysis)
@@ -31,8 +37,8 @@ print(analysis)
 analysis.run()
 
 result = analysis.getResult()
-print("result=", result)
-print(result.getCopulaInferenceSetResult(variables))
+inferenceSet = result.getCopulaInferenceSetResult(variables)
+print(inferenceSet.getBICResults())
 
 # script
 script = myStudy.getPythonScript()
