@@ -21,6 +21,9 @@ case $variant in
   "3" | "salome")
     variant="salome"
     ;;
+  "4" | "fedora")
+    variant="fedora"
+    ;;
   *)
     echo "sorry?"
     exit 1
@@ -36,4 +39,4 @@ else
   docker pull ${img}
 fi
 
-docker run --rm --volume `pwd`:/io ${img} sh -c "/io/docker/${variant}/run_docker_build.sh `id -u` `id -g`"
+docker run --rm --volume `pwd`:/io ${img} sh -c "/io/docker/${variant}/run_docker_build.sh `id -u`:`id -g`"
